/**
 * @create date  2018/04/27.
 * @author       Front coding
 * @project     omara
 */

;(function ($) {
    /* 公共函数* start* */
    var propess_t;
    var propess;
    var omara_func = {
        reg: {
            /**
             * @method {function}  is_mobile()  验证手机号格式
             * @param  {string}    str  需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  is_mobile('13785478451')
             */
            is_mobile: function (str) {
                return /^(86)?1[3,4,5,7,8,9]\d{9}$/.test(str);
            },
            /**
             * 验证邮箱格式
             * @param str
             * @returns {boolean}
             */
            is_email: function (str) {
                return /^\w+((-\w+)|(\.\w+))*\@[A-Za-z0-9]+((\.|-)[A-Za-z0-9]+)*\.[A-Za-z0-9]+$/.test(str);
            },
            /**
             *@method  {function} isup_img() 验证上传图片格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_img('1.jpg')
             */
            isup_img: function (str) {
                return /^(.*).(jpg|JPG|png|PNG|jpeg|gif|GIF|svg)$/.test(str);
            },
            /**
             *@method  {function} isup_svg() 验证上传图片格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_svg('1.svg')
             */
            isup_svg: function (str) {
                return /^(.*).(svg)$/.test(str);
            },
            /**
             *@method  {function} isup_db() 验证上传文件格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_db('1.jpg')
             */
            isup_db: function (str) {
                return /^(.*).(rar|gz)$/.test(str);
            },
            /**
             *@method  {function} isup_ini() 验证上传文件格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_ini('1.jpg')
             */
            isup_ini: function (str) {
                return /^(.*).(ini)$/.test(str);
            },
            /**
             *@method  {function} isup_xls() 验证上传excel文件格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_xls('1.xls')
             */
            isup_excel: function (str) {
                return /^(.*).(xls|xlsx|docx|xlsm)$/.test(str);
            },
            /**
             *@method  {function} isup_xls() 验证上传excel文件格式
             * @param   {string}  str       需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  isup_word('1.xls')
             */
            isup_word: function (str) {
                return /^(.*).(xls|xlsx|docx|doc|xlsm|PDF|pdf)$/.test(str);
            },
            /**
             *@method   {function} is_num()  数字验证码
             * @param   {string}   str     需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  is_num('123')
             * */
            is_num: function (str) {
                return /^[0-9]{6}$/.test(str);
            },
            /**
             *@method   {function} is_number()  数字
             * @param   {string}   str     需要验证的数值
             * @returns {boolean}  true/false  返回值
             * @example  is_number('123')
             * */
            is_number: function (str) {
                return /^[0-9]\d*(\.\d{1,2})?$/.test(str);
            },
            /**
             * 用户名  支持字母、数字、下划线、中划线
             */
            is_realName: function (str) {
                return /^[A-Za-z0-9\-\_]{4,16}$/.test(str);
            },
            /**
             * 密码 支持字母、数字、下划线、中划线、特殊符号
             */
            is_pwd: function (str) {
                return /^[\@A-Za-z0-9\!\#\$\%\@\^\&\*\.\~\-\_]{4,32}$/.test(str);
            },
            /**
             * 验证IP地址
             * */
            is_ip: function (str) {
                return /^((2[0-4]\d|25[0-5]|[01]?\d\d?)\.){3}(2[0-4]\d|25[0-5]|[01]?\d\d?)$/.test(str);
            },
            /**
             * 验证端口号
             * */
            is_post: function (str) {
                return /^([0-9]|[1-9]\d{1,3}|[1-5]\d{4}|6[0-5]{2}[0-3][0-5])$/.test(str);
            }
        },
        character: function (index) {
            var character = new Array("A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "X", "Y", "Z");
            return character[index];
        },
        /**
         * 验证  上传图片格式
         */
        isup_img: function (str) {
            return /^(.*).(jpg|JPG|png|PNG|jpeg|gif|GIF|svg)$/.test(str);
        },
        /*
         * 验证上传文件
         * */
        is_file: function (obj) {
            if ($(obj.dom).val() == "") {
                omara_func.dialog_tips({show_text: "请选择文件", show_time: 2000});
                $(obj.dom).addClass("err");
            } else if (obj.reg) {
                omara_func.dialog_tips({show_text: obj.errtypemsg, show_time: 2000});
                $(obj.dom).addClass("err");
            } else {
                $(obj.dom).removeClass("err");
            }

        },
        /**
         *@method   {function}    is_validity() 数据合法性验证
         *@data     {object/array} obj        传入参数对象
         **@param   {string}       dom        需要选择的dom
         *@param    {boolean}      reg        输入值正则验证是否通过
         *@param    {boolean}      reglength  输入值是否验证长度，true需要验证，false不需要
         *@param    {number}       length     输入值长度
         *@example   is_validity({dom:'.text',reg:true,reglength:true,length:50})
         * */
        is_validity: function (obj) {
            if ($(obj.dom).is(":visible")) {
                if ($.trim($(obj.dom).val()) == "") {
                    $(obj.dom).addClass("error");
                    $(obj.dom).parent().addClass("err");
                } else if (obj.reg && $(obj.dom).is(":visible")) {
                    $(obj.dom).removeClass("error");
                    $(obj.dom).addClass("regerr");
                } else if (obj.reglength && $(obj.dom).val().length > obj.length) {
                    $(obj.dom).removeClass("regerr");
                    $(obj.dom).addClass("regerrlength");
                } else {
                    $(obj.dom).removeClass("error regerr regerrlength");
                    $(obj.dom).siblings(".tips").text("");
                }
            }

        },
        /**
         * @method  {function}        is_validity_mul()    数据合法性验证  多个相同的输入框
         *@data     {object/array}    o                    传入参数对象
         *@param    {object}          dom                  需要选择的dom
         *@param    {boolean}         reg                  输入值正则验证是否通过
         **@param   {boolean}         reglength            输入值是否验证长度，true需要验证，false不需要
         *@param    {number}          length               输入值长度
         *@example   is_validity_mul({dom:$('.text'),reg:true,reglength:true,length:50})
         * */
        is_validity_mul: function (o) {
            if (o.dom.val() == "") {
                o.dom.addClass("error");
            } else if (o.reg) {
                o.dom.addClass("error");
            } else if (o.reglength && o.dom.val().length > o.length && o.dom.is(":visible")) {
                o.dom.removeClass("error");
                o.dom.addClass("regerrlength");
            } else {
                o.dom.removeClass("error regerrlength");
            }
        },
        /**
         *@method   {function}     interVal   验证码倒计时操作
         *@data     {object/array} obj        传入参数对象
         *@param    {string}       dom        发送验证码的按钮
         *@param    {number}       time       验证码倒计时长短
         * @example interVal({time:60,dom:'.send-code'})
         */
        interVal: function (obj) {
            var that = this;
            var _secs = obj.time;
            $(obj.dom).text(_secs + "s").attr("disabled", true);
            that = setInterval(function () {
                _secs--;
                $(obj.dom).text(_secs + "s");
                if (_secs <= 0) {
                    $(obj.dom).text("重新发送").removeAttr("disabled");
                    $(obj.dom).removeAttr("style");
                    clearInterval(that);
                }
            }, 1000);
        },
        /**
         * @method   {function}     getQueryVariable      获取地址栏某参数
         * @data     {string}       variable              传入参数 返回值false表示没有参数，不是false表示地址栏有该参数
         * @param    {string}       url            请求地址
         * @example  getQueryVariable({
         *                          variable : 'wwww',
         *                          })
         */
        getQueryVariable: function (variable) {
            var query = window.location.search.substring(1);
            var vars = query.split("&");
            for (var i = 0; i < vars.length; i++) {
                var pair = vars[i].split("=");
                if (pair[0] == variable) {
                    return pair[1];
                }
            }
            return (false);
        },
        /**
         * @method   {function}     dialog_tips    提示语弹窗
         * @data     {object/array} obj            传入参数对象
         * @param    {string}       show_text      显示的提示语文本
         * @param    {number}       show_time      弹窗显示的时间长短
         * @example  dialog_tips({show_text : '操作有误', show_time : 1000})
         */
        dialog_tips: function (obj) {
            var html = '<div class="dialog-tips" id="dialog-tips">' +
                '    <div class="content">' + obj.show_text + '</div>' +
                '</div>';

            $("body").append(html);
            setTimeout(function () {
                $("#dialog-tips").remove();
            }, obj.show_time);
        },
        /**
         * @method        {function}     dialog_confirm    确认弹窗
         * @data         {object/array}  obj               传入参数对象
         * @param        {string}        show_text         显示的提示语文本
         * @callback    {function}       callback()         点击确定之后要执行的操作
         * @canel_callback {function} canel_callback()     点击取消按钮要执行的操作
         * @example  dialog_confirm({
         *                          show_text : '操作有误',
         *                          confirm:function () {
         *                              alert(111);
         *                              }
         *                          },
         *                          canel_callback:function () {}
         *                          )
         */
        dialog_confirm: function (obj) {
            var html = '<div class="dialog-confirm" id="' + obj.dialog_id + '">' +
                '    <div class="content-confirm">' +
                '        <div class="content">' + obj.show_text + '</div>' +
                '        <div class="confirm-btn clearfix">' +
                '            <button type="button" class="btn-confirm" id="btn-confirm">确定</button>' +
                '            <button type="button" class="btn-cancel" id="btn-cancel">取消</button>' +
                '        </div>' +
                '    </div>' +
                '</div>';
            $("body").append(html);
        },
        /**
         * @method   {function}     ajax_data      数据请求
         * @data     {object/array} obj            传入参数对象集合
         * @param    {string}       url            请求地址
         * @param    {json/object}  data           ajax请求的参数集合
         * @callback {function}     callback()     成功回调函数
         * @callback {function}     error()        失败回调函数
         * @example  ajax_data({
         *                          url : "wwww",
         *                          data:{id:1},
         *                          callback:obj.callback()
         *                          })
         */
        ajax_data: function (obj) {
            var error = function () {
                if ((typeof obj.error()) == "function") {
                    obj.error();
                }
            };
            $.ajax({
                url: obj.url,
                dataType: "json",
                type: "post",
                data: obj.data,
                success: function (data) {
                    if (data.status == "OK") {
                        obj.callback(data);
                    } else {
                        error();

                    }
                    omara_func.clearInterval();
                    data.msg != "" ? omara_func.dialog_tips({show_text: data.msg, show_time: 1500}) : "";
                }
            });
        },
        /**
         * @method   {function}     refresh_page() 刷新当前页
         * @data     {object/array} obj            传入参数对象
         * @param    {number}       time           等待刷新的时长
         * @example  refresh_page({
         *                          time : 1000,
         *                          })
         */
        refresh_page: function (obj) {
            setTimeout(function () {
                location.href = window.document.location.href;
            }, obj.time);
        },
        /*图表初始化*/
        charts: function (o) {
            Highcharts.setOptions({
                global: {
                    useUTC: false,
                    timezone: 'Asia/Shanghai'
                },
                lang: {
                    noData: '暂无数据',
                    loading: '<img src="/static/images/loading.svg" height="48"/>',
                    months: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
                    weekdays: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
                    shortMonths: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
                }
            });
            var chart = Highcharts.chart(o.dom, {
                // Highcharts 配置
                chart: {
                    type: o.type,
                    zoomType: 'x',
                    width: o.width,
                    marginTop: 35,
                    marginBottom: 25,
                    backgroundColor: o.backgroundColor
                },
                rangeSelector: {
                    selected: 4,
                    inputEnabled: false,
                },
                tooltip: {
                    valueDecimals: 2,
                },
                navigation: {
                    adaptToUpdatedData: false,
                    buttonOptions: {
                        enabled: false
                    }
                },
                plotOptions: {
                    series: {
                        turboThreshold: 0//larger threshold or set to 0 to disable
                    },
                    area: {
                        fillColor: {
                            linearGradient: {
                                x1: 0,
                                y1: 0,
                                x2: 0,
                                y2: 1
                            },
                            stops: [
                                [0, Highcharts.getOptions().colors[0]],
                                [1, Highcharts.Color(Highcharts.getOptions().colors[0]).setOpacity(0).get('rgba')]
                            ]
                        },
                        marker: {
                            radius: 2
                        },
                        lineWidth: 1,
                        states: {
                            hover: {
                                lineWidth: 1
                            }
                        },
                        threshold: null
                    }
                },
                credits: {
                    enabled: false
                },
                legend: {
                    enabled: o.legend,
                    verticalAlign: o.verticalAlign,
                    align: 'center',
                    symbolRadius: 0
                },
                noData: {
                    style: {
                        fontWeight: 'bold',
                        fontSize: '15px',
                        color: '#303030'
                    },
                    useHTML: '暂无数据'
                },
                yAxis: {
                    title: {
                        text: o.yval
                    },
                    min: (typeof o.min == 'undefined' ? null : o.min),
                    max: (typeof o.max == 'undefined' ? null : o.max),
                    lineWidth: 1,
                    opposite: false,
                },
                xAxis: {
                    type: o.xtype,//时间轴要加上这个type，默认是linear
                    maxPadding: 0.05,
                    minPadding: 0.05,
                    //tickInterval : 24 * 3600 * 1000 * 2,//两天画一个x刻度
                    //或者150px画一个x刻度，如果跟上面那个一起设置了，则以最大的间隔为准
                    tickPixelInterval: 150,
                    lineWidth: 1,//自定义x轴宽度
                    gridLineWidth: 1,//默认是0，即在图上没有纵轴间隔线
                    //自定义x刻度上显示的时间格式，根据间隔大小，以下面预设的小时/分钟/日的格式来显示
                    dateTimeLabelFormats:
                        {
                            second: '%H:%M:%S',
                            minute: '%b%e日 %H:%M',
                            hour: '%b%e日 %H:%M',
                            day: '%b%e日',
                            week: '%e. %b',
                            month: '%b %y',
                            year: '%Y'
                        }
                },
                scrollbar: {
                    enabled: true
                },
                title: {
                    text: o.title,
                    margin: 0
                },
                series: o.data
            });
            chart.showLoading();
            return chart;
        },
        charts_gauge: function (o) {
            var charts_gauge = Highcharts.chart(o.id, {
                chart: {
                    type: 'gauge',
                    alignTicks: false,
                    plotBackgroundColor: null,
                    plotBackgroundImage: '/static/images/gauge.png',
                    plotBorderWidth: 0,
                    plotShadow: false
                },
                lang: {
                    noData: '',
                },
                navigation: {
                    adaptToUpdatedData: false,
                    buttonOptions: {
                        enabled: false
                    }
                },
                xAxis: {
                    visible: false
                },
                legend: {
                    enabled: false
                },
                credits: {
                    enabled: false
                },
                title: {
                    text: '',
                },
                pane: {
                    center: ['50%', '80%'],
                    size: '153%',
                    startAngle: -90,
                    endAngle: 90,
                    background: {
                        innerRadius: '100%',
                        outerRadius: '100%',
                        shape: 'arc'
                    }
                },
                plotOptions: {
                    gauge: {
                        dial: {
                            backgroundColor: '#f30',
                            radius: '80%',
                            baseWidth: 3
                        },
                        pivot: {
                            backgroundColor: "#000",
                            baseWidth: 10
                        },
                        x: 0,
                        y: 30
                    }
                },
                yAxis: [{
                    min: o.min,
                    max: o.max,
                    tickPosition: 'inside',
                    lineColor: '#fff',
                    lineWidth: 2,
                    minorTickPosition: 'inside',
                    tickColor: '#000',
                    minorTickColor: '#000',
                    tickLength: 10,
                    minorTickLength: 5,
                    labels: {
                        distance: -20,
                        rotation: 'auto',
                        style: {
                            fontSize: '10px',
                        }
                    },
                    offset: 0,
                    endOnTick: false
                }],
                series: [{
                    name: o.name,
                    data: o.data,
                    dataLabels: {
                        format: '<div style="text-align:center;"><span style="font-size:18px;color:black;">' + o.spec1.toString() + '</span><br/>' +
                            '<span> ' + o.spec2.toString() + ' </span></div>',
                        y: 10,
                        borderColor: 'rgbs(255,255,255,0)',
                    },
                    tooltip: {
                        valueSuffix: o.spec1
                    }
                }]
            });
            return charts_gauge;
        },
        charts_pieequip: function (o) {
            var charts = Highcharts.chart(o.id, {
                chart: {
                    // spacing : [40, 0 , 40, 0]
                    type: 'pie',
                },
                title: {
                    floating: true,
                    text: o.text
                },
                legend: {
                    enabled: false
                },
                navigation: {
                    adaptToUpdatedData: false,
                    buttonOptions: {
                        enabled: false
                    }
                },
                credits: {
                    enabled: false
                },
                tooltip: {
                    enabled: false,
                    pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
                },
                plotOptions: {
                    pie: {
                        allowPointSelect: false,
                        // cursor: 'pointer',
                        dataLabels: {
                            enabled: false,
                        },
                        point: {},
                    }
                },
                series: [{
                    type: 'pie',
                    innerSize: '80%',
                    size: '160%',
                    name: '',
                    data: [
                        {name: '', y: o.y1, color: o.color},
                        {name: '', y: o.y2, color: '#E1E6DF'},
                    ]
                }]
            }, function (c) { // 图表初始化完毕后的会掉函数
                // 环形图圆心
                var centerY = c.series[0].center[1],
                    titleHeight = parseInt(c.title.styles.fontSize);
                // 动态设置标题位置
                c.setTitle({
                    y: centerY + titleHeight / 2
                });
            });
            return charts;
        },
        charts_graph: function (o) {
            Highcharts.setOptions({
                global: {
                    useUTC: false,
                    timezone: 'Asia/Shanghai'
                },
                lang: {
                    noData: '暂无数据',
                    loading: '<img src="/static/images/loading.svg" height="48"/>',
                    months: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
                    weekdays: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
                    shortMonths: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
                }
            });
            var charts_graph = Highcharts.chart(o.id, {
                chart: {
                    renderTo: o.id,
                    type: 'column'
                },
                title: {
                    text: '',
                    enabled: false
                },
                subtitle: {
                    text: '',
                    enabled: false
                },
                legend: {
                    enabled: true,
                    verticalAlign: 'top',
                    align: 'center',
                    symbolRadius: 0
                },
                credits: {
                    enabled: false
                },
                xAxis: {
                    categories: o.categories,
                    crosshair: true,
                    gridLineWidth: 1,//默认是0，即在图上没有纵轴间隔线
                },
                yAxis: {
                    min: 0,
                    title: {
                        text: ''
                    },
                    enabled: false,
                },
                dataLabels: {
                    enabled: true,
                    format: '{point.y:.1f}'
                },
                navigation: {
                    adaptToUpdatedData: false,
                    buttonOptions: {
                        enabled: false
                    }
                },
                tooltip: {
                    // head + 每个 point + footer 拼接成完整的 table
                    headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
                    pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
                        '<td style="padding:0"><b>{point.y:.1f}</b></td></tr>',
                    footerFormat: '</table>',
                    shared: true,
                    useHTML: true
                },
                noData: {
                    style: {
                        fontWeight: 'bold',
                        fontSize: '15px',
                        color: '#303030'
                    },
                    useHTML: '暂无数据'
                },
                plotOptions: {
                    column: {
                        dataLabels: {
                            enabled: true,
                            color: '#000',
                        }
                    }
                },
                series: o.data,
            });
            return charts_graph;
        },
        charts_pie: function (o) {
            Highcharts.setOptions({
                global: {
                    useUTC: false,
                    timezone: 'Asia/Shanghai'
                },
                lang: {
                    noData: '暂无数据',
                    loading: '<img src="/static/images/loading.svg" height="48"/>',
                    months: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
                    weekdays: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
                    shortMonths: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
                }
            });
            var pie = Highcharts.chart(o.id, {
                noData: {
                    style: {
                        fontWeight: 'bold',
                        fontSize: '15px',
                        color: '#303030'
                    },
                    useHTML: '暂无数据'
                },
                chart: {
                    plotBackgroundColor: null,
                    plotBorderWidth: null,
                    plotShadow: false,
                    type: 'pie',
                    backgroundColor: 'rgba(255,255,255,0)'
                },
                title: {
                    text: '',
                    enabled: true,
                },
                tooltip: {
                    headerFormat: '<b>' + o.piename + '</b>',
                    pointFormat: '<br/><b>{point.name}: {point.y}({point.percentage:.1f}%)</b>',
                },
                credits: {
                    enabled: false
                },
                plotOptions: {
                    pie: {
                        allowPointSelect: true,
                        cursor: 'pointer',
                        showInLegend: true,
                        dataLabels: {
                            enabled: false,
                            format: '{point.name}',
                            style: {
                                color: (Highcharts.theme && Highcharts.theme.contrastTextColor) || 'black'
                            }
                        }
                    }
                },
                series: [{
                    size: o.size,
                    name: o.piename,
                    colorByPoint: true,
                    data: o.datas
                }]
            });
            return pie;
        },
        charts_gauge_pue: function (o) {
            var gauge_pue = Highcharts.chart(o.id, {
                chart: {
                    type: 'gauge',
                    alignTicks: false,
                    plotBackgroundColor: null,
                    plotBackgroundImage: null,
                    plotBorderWidth: 0,
                    plotShadow: false,
                    backgroundColor: 'rgba(255,255,255,0)'
                },
                title: {
                    text: ''
                },
                pane: {
                    startAngle: -150,
                    endAngle: 150
                },
                navigation: {
                    adaptToUpdatedData: false,
                    buttonOptions: {
                        enabled: false
                    }
                },
                plotOptions: {
                    series: {
                        turboThreshold: 0//larger threshold or set to 0 to disable
                    }
                },
                credits: {
                    enabled: false
                },
                tooltip: {
                    valueSuffix: o.valueSuffix
                },
                yAxis: [{
                    min: 0,
                    max: 5,
                    lineColor: '#' + o.lineColor,
                    tickColor: '#' + o.lineColor,
                    minorTickColor: '#' + o.lineColor,
                    offset: -15,
                    lineWidth: 2,
                    labels: {
                        distance: -20,
                        rotation: 'auto'
                    },
                    tickLength: 5,
                    minorTickLength: 5,
                    endOnTick: false
                }],
                series: [{
                    name: o.name,
                    data: [o.pue],
                    dataLabels: {
                        formatter: function (e) {
                            return o.pue + o.valueSuffix;
                        },
                        backgroundColor: {
                            linearGradient: {
                                x1: 0,
                                y1: 0,
                            },
                            stops: [
                                [0, '#DDD'],
                            ]
                        },
                        y: o.y
                    },
                    tooltip: {
                        valueSuffix: o.valueSuffix
                    }
                }]
            });
            return gauge_pue;
        },
        /**
         * @method    {function}    charts_label()     给图表加标注
         * @data      {object/array} o                 传入参数对象
         * @param     {object}       chart             图表对象
         * @example  charts_label({
         *                          chart : chart,
         *                          })
         * */
        charts_label: function (o) {
            var minLabel = null,
                maxLabel = null;
            var render = function (chart, point, text, unit, color) {
                return chart.renderer.label(point.y + unit, point.plotX + chart.plotLeft - 20, point.plotY + chart.plotTop - 45, 'callout', point.plotX + chart.plotLeft, point.plotY + chart.plotTop)
                    .css({
                        color: '#FFFFFF',
                        align: 'center',
                    })
                    .attr({
                        fill: color,
                        padding: 8,
                        r: 5,
                        zIndex: 6
                    })
                    .add();
            };

            if (minLabel) {
                minLabel.destroy();
            }
            if (maxLabel) {
                maxLabel.destroy();
            }
            if (o.chart.series.length > 0) {
                var min = 1000,
                    max = 0,
                    pointsToShow = [0, 0],
                    points = o.chart.series;
                Highcharts.each(points, function (p) {
                    Highcharts.each(p.points, function (res) {

                        if (res.y > max) {
                            pointsToShow[0] = res.index;
                            max = res.y;
                        }
                        if (res.y < min) {
                            pointsToShow[1] = res.index;
                            min = res.y;
                        }
                    });
                    if (o.maxshow) {
                        maxLabel = render(o.chart, p.points[pointsToShow[0]], '最大值', p.options.tooltip.valueSuffix, p.color);
                    }
                    if (o.minshow) {
                        maxLabel = render(o.chart, p.points[pointsToShow[1]], '最小值', p.options.tooltip.valueSuffix, p.color);
                    }
                });

            }

        },
        /**
         * @method    {function}    proccess()     按钮进度条
         * @data      {object/array} obj            传入参数对象
         * @param     {object}       dom            进度条对象
         * @example  proccess({
         *                          dom : $('.dom'),
         *                          })
         * */
        proccess: function (obj) {
            var propess_t = 0;
            propess = this;
            var _secs = 100;
            if (obj.dom.attr('data-disabled') == 'false' || obj.dom.attr('data-disabled') == undefined) {
                obj.dom.attr('data-disabled', true);
                propess = setInterval(function () {
                    propess_t += 5;
                    _secs--;
                    if (propess_t > 100) {
                        propess_t = 0;
                    }
                    obj.dom.find('.btn-shadow').css({width: propess_t + '%'});
                    obj.dom.attr('data-disabled', true);
                    if (propess_t >= 100) {
                        // clearInterval(propess);
                    }
                }, 100);
            }
        },
        clearInterval: function () {
            clearInterval(propess);
            $(".btn-submit").attr("data-disabled", false).children(".btn-shadow").removeAttr("style");
        },
        /**
         *@method       {function}     select_checked()  select默认选中
         *@data         {object/array} obj               传入参数对象
         *@param        {string}       select            select对象
         *@param        {string}       parameter         对比的数值
         ** @example    select_checked({
         *                          select : '.dom',
         *                          parameter:'hggf'
         *                          })
         */
        select_checked: function (obj) {
            for (var a = 0; a < $(obj.select).find("option").length; a++) {
                if (obj.parameter == $(obj.select).find("option").eq(a).val()) {
                    $(obj.select).find("option").eq(a).prop("selected", true);
                    break;
                }
            }//end for
        },
        /**
         *@method       {function}     checkbox_checked()  checkbox默认选中
         *@data         {object/array} obj                 传入参数对象
         *@param        {string}       checkbox_box       复选框盒子
         ** @example    checkbox_checked({
         *                          checkbox_box : '.dom',
         *                          })
         */
        checkbox_checked: function (obj) {
            if ($(obj.checkbox_box).children().length > 0) {
                var checkbox = $(obj.checkbox_box).children();
                var val = obj.data.split(',');
                checkbox.removeClass('selected').children('input').prop('checked', false);
                for (var i = 0; i < checkbox.length; i++) {
                    for (var v = 0; v < val.length; v++) {
                        if (checkbox.eq(i).children('input').val() == val[v]) {
                            checkbox.eq(i).addClass('selected').children('input').prop('checked', true);
                            continue;
                        }
                    }
                }
            }
        },
        /**
         *@method       {function}     info_data()        请求数据时需要传递的参数名集合
         *@data         {object/array} obj                传入参数对象
         *@param        {string}       dom                遍历表单中的对象
         *@param        {string}       type               集合类型：name只拼接参数名，name+val参数名和值一起拼接
         ** @example    info_data({
         *                          form : '.dom',
         *                          type : 'name',
         */
        info_data: function (obj) {
            var info = obj.form.serializeArray();
            var res_data = '';
            $.each(info, function (index, field) {
                if (index > 0) {
                    res_data += ','
                }
                if (obj.type == 'name') {
                    res_data += field.name;
                } else {
                    res_data += '"' + field.name + '":"' + field.value + '"';
                }

            });
            return res_data;
        },
        /**
         *@method       {function}     update_ajaxform()  上传文件
         *@data         {object/array} obj                传入参数对象
         *@param        {string}       dom                表单类名或者ID
         *@param        {string}       updom              上传按钮id input:file
         *@param        {string}       url                上传地址
         *@param        {function}     callback()         回调函数，表单提交后执行的操作
         *@example    update_ajaxform({
         *                          dom : '.dom',
         *                          url : '上传地址',
         *                          updom : 'up-logo',
         *                          callback:funtion(){}
         *                          })
         */
        update_ajaxform: function (obj) {
            $(obj.dom).ajaxSubmit({
                type: 'post',
                url: obj.url,
                data: {},
                dataType: 'json',
                withCredentials: true,
                success: function (data) {
                    var thisVala = '';
                    var vfile = document.getElementById(obj.updom);
                    if (typeof data.data != 'undefined') {
                        for (var i = 0; i < data.data.length; i++) {
                            if (i > 0) {
                                thisVala += ';';
                            }
                            thisVala += data.data[i];
                        }
                    }

                    if (data.status == "OK") {
                        obj.callback(thisVala, data);
                    } else {
                        $('#' + obj.updom).siblings('img').remove();
                    }
                    data.msg != '' ? omara_func.dialog_tips({show_text: data.msg, show_time: 1000}) : '';

                    vfile.value = '';
                },
                error: function (data, status, XMLHttpRequest, textStatus, errorThrown) {
                    console.log(data);
                    console.log(XMLHttpRequest, textStatus, errorThrown);
                    omara_func.dialog_tips({show_text: '上传出错，请刷新页面后重试!', show_time: 1000});
                }
            });
        },
        /**
         * @method      {function}    page_list()    页码处理
         * @data        {object}      data           传入参数对象
         * @param       {number}      page           当前页面号数
         * @param       {number}      total          总页数
         * @param       {number}      ps             每页显示的信息条数
         * @example     page_list({
         *                  page:1,
         *                  total:10,
         *                  pa:20
         *              })
         * */
        page_list: function (data) {
            var pages = '';
            var current = parseInt(data.page);
            var page_total = Math.ceil(parseInt(data.total) / parseInt(data.ps));
            var start = Math.max(current - 3, 0);
            var end = Math.min(current + 2, page_total);
            start = Math.min(start, 6);
            start = Math.max(start, current - 3);
            end = Math.max(end, 5);
            end = Math.min(end, page_total);
            if (current > 1) {
                pages += '<a href="javascript:void(0);" class="prev-page page-link" data-num="' + (current - 1) + '">«</a>';
            }
            if (current - 2 > 1) {
                pages = pages + '<a href="javascript:void(0);">...</a>';
            }

            for (var p = start; p < end; p++) {
                pages = pages + '<a href="javascript:void(0);" class="' + ((current - 1 == p) ? 'active' : 'page-link') + '" data-num="' + (p + 1) + '">' + (p + 1) + '</a>';
            }
            if (current + 2 < page_total) {
                pages = pages + '<a href="javascript:void(0);">...</a>';
            }
            if (current < page_total) {
                pages += '<a href="javascript:void(0);" class="next-page page-link" data-num="' + (current + 1) + '">»</a>';
            }
            return pages;
        },
        /**
         *@method       {function}      alarm_type()       遍历报警方式图标
         *@data         {string/number} data                传入参数对象
         ** @example    alarm_type('160')
         */
        alarm_type: function (data) {
            var type = [128, 64, 32, 16, 8];
            var type_icon = ['icon-app', 'icon-msg', 'icon-mobile', 'icon-mail', 'icon-wechat'];
            var type_title = ['APP', '短信', '语音', '邮件', '微信'];
            var val = data.split(',');
            var icon = '';
            $.each(val, function (ii) {
                if (ii > 0) {
                    icon += '<br/>';
                }
                $.each(type, function (i) {
                    if (val[ii] & type[i]) {
                        icon += '<a href="javascript:void (0);" title="' + type_title[i] + '" class="iconfont omara-middle omara-mleft-10 ' + type_icon[i] + ' omara-alert-icon"></a>';
                    }
                });
            });
            return icon;
        }
    };
    /**滚动条*/
    $.fn.extend({
        slimScroll: function (options) {
            var count = 0;
            var defaults = {
                width: 'auto',
                height: '250px',
                size: '7px',
                color: '#000',
                position: 'right',
                distance: '1px',
                start: 'top',
                opacity: .4,
                alwaysVisible: false,
                disableFadeOut: false,
                railVisible: false,
                railColor: '#333',
                railOpacity: .2,
                railDraggable: true,
                railClass: 'slimScrollRail',
                barClass: 'slimScrollBar',
                wrapperClass: 'slimScrollDiv',
                allowPageScroll: false,
                wheelStep: 20,
                touchScrollStep: 200,
                borderRadius: '7px',
                railBorderRadius: '7px',
                scrollfun: function (o) {

                }
            };

            var o = $.extend(defaults, options);

            //每个匹配选择器的元素的操作
            this.each(function () {

                var isOverPanel, isOverBar, isDragg, queueHide, touchDif,
                    barHeight, percentScroll, lastScroll,
                    divS = '<div></div>',
                    minBarHeight = 30,
                    releaseScroll = false;

                var me = $(this);

                if (me.parent().hasClass(o.wrapperClass)) {
                    var offset = me.scrollTop();

                    bar = me.parent().find('.' + o.barClass);
                    rail = me.parent().find('.' + o.railClass);

                    getBarHeight();

                    if ($.isPlainObject(options)) {
                        if ('height' in options && options.height == 'auto') {
                            me.parent().css('height', 'auto');
                            me.css('height', 'auto');
                            var height = me.parent().parent().height();
                            me.parent().css('height', height);
                            me.css('height', height);
                        }

                        if ('scrollTo' in options) {
                            offset = parseInt(o.scrollTo);
                        } else if ('scrollBy' in options) {
                            offset += parseInt(o.scrollBy);
                        } else if ('destroy' in options) {
                            bar.remove();
                            rail.remove();
                            me.unwrap();
                            return;
                        }

                        scrollContent(offset, false, true);
                    }
                    return;
                } else if ($.isPlainObject(options)) {
                    if ('destroy' in options) {
                        return;
                    }
                }

                // 计算高度
                o.height = (o.height == 'auto') ? me.parent().height() : o.height;

                // 内容盒子
                var wrapper = $(divS)
                    .addClass(o.wrapperClass)
                    .css({
                        position: 'relative',
                        overflow: 'hidden',
                        width: o.width,
                        height: o.height
                    });

                // update style for the div
                // me.css({
                //     overflow: 'hidden',
                //     // width: o.width,
                //     // height: o.height
                // });

                /*滚动条主体*/
                var rail = $(divS)
                    .addClass(o.railClass)
                    .css({
                        width: o.size,
                        height: '100%',
                        position: 'absolute',
                        top: 0,
                        display: (o.alwaysVisible && o.railVisible) ? 'block' : 'none',
                        'border-radius': o.railBorderRadius,
                        background: o.railColor,
                        opacity: o.railOpacity,
                        zIndex: 90
                    });

                /*创建滚动条 handle*/
                var bar = $(divS)
                    .addClass(o.barClass)
                    .css({
                        background: o.color,
                        width: o.size,
                        position: 'absolute',
                        top: 0,
                        opacity: o.opacity,
                        display: o.alwaysVisible ? 'block' : 'none',
                        'border-radius': o.borderRadius,
                        BorderRadius: o.borderRadius,
                        MozBorderRadius: o.borderRadius,
                        WebkitBorderRadius: o.borderRadius,
                        zIndex: 99
                    });

                var posCss = (o.position == 'right') ? {right: o.distance} : {left: o.distance};
                rail.css(posCss);
                bar.css(posCss);

                me.wrap(wrapper);

                me.parent().append(bar);
                me.parent().append(rail);

                if (o.railDraggable) {
                    bar.bind("mousedown", function (e) {
                        var $doc = $(document);
                        isDragg = true;
                        t = parseFloat(bar.css('top'));
                        pageY = e.pageY;

                        $doc.bind("mousemove.slimscroll", function (e) {
                            currTop = t + e.pageY - pageY;
                            bar.css('top', currTop);
                            scrollContent(0, bar.position().top, false);// scroll content
                        });

                        $doc.bind("mouseup.slimscroll", function (e) {
                            isDragg = false;
                            // hideBar();
                            $doc.unbind('.slimscroll');
                        });
                        return false;
                    }).bind("selectstart.slimscroll", function (e) {
                        e.stopPropagation();
                        e.preventDefault();
                        return false;
                    });
                }

                // on rail over
                rail.hover(function () {
                    showBar();
                }, function () {
                    // hideBar();
                });

                // on bar over
                bar.hover(function () {
                    isOverBar = true;
                }, function () {
                    isOverBar = false;
                });

                // show on parent mouseover
                me.hover(function () {
                    isOverPanel = true;
                    showBar();
                    // hideBar();
                }, function () {
                    isOverPanel = false;
                    hideBar();
                });

                me.bind('touchstart', function (e, b) {
                    if (e.originalEvent.touches.length) {
                        touchDif = e.originalEvent.touches[0].pageY;
                    }
                });

                me.bind('touchmove', function (e) {
                    if (!releaseScroll) {
                        e.originalEvent.preventDefault();
                    }
                    if (e.originalEvent.touches.length) {
                        var diff = (touchDif - e.originalEvent.touches[0].pageY) / o.touchScrollStep;
                        scrollContent(diff, true);
                        touchDif = e.originalEvent.touches[0].pageY;
                    }
                });

                // set up initial height
                getBarHeight();

                // check start position
                if (o.start === 'bottom') {
                    bar.css({top: me.outerHeight() - bar.outerHeight()});
                    scrollContent(0, true);
                } else if (o.start !== 'top') {
                    scrollContent($(o.start).position().top, null, true);
                    if (!o.alwaysVisible) {
                        bar.hide();
                    }
                }

                attachWheel();

                function _onWheel(e) {
                    if (!isOverPanel) {
                        return;
                    }

                    var e = e || window.event;

                    var delta = 0;
                    if (e.wheelDelta) {
                        delta = -e.wheelDelta / 120;
                    }
                    if (e.detail) {
                        delta = e.detail / 3;
                    }

                    var target = e.target || e.srcTarget || e.srcElement;
                    if ($(target).closest('.' + o.wrapperClass).is(me.parent())) {
                        // scroll content
                        scrollContent(delta, true);
                    }

                    // stop window scroll
                    if (e.preventDefault && !releaseScroll) {
                        e.preventDefault();
                    }
                    if (!releaseScroll) {
                        e.returnValue = false;
                    }
                }

                var count = 0;

                function scrollContent(y, isWheel, isJump) {
                    releaseScroll = false;
                    var delta = y;
                    var maxTop = me.outerHeight() - bar.outerHeight();

                    if (isWheel) {
                        // move bar with mouse wheel
                        delta = parseInt(bar.css('top')) + y * parseInt(o.wheelStep) / 100 * bar.outerHeight();

                        delta = Math.min(Math.max(delta, 0), maxTop);

                        delta = (y > 0) ? Math.ceil(delta) : Math.floor(delta);

                        bar.css({top: delta + 'px'});
                    }

                    percentScroll = parseInt(bar.css('top')) / (me.outerHeight() - bar.outerHeight());
                    delta = percentScroll * (me[0].scrollHeight - me.outerHeight());

                    if (isJump) {
                        delta = y;
                        var offsetTop = delta / me[0].scrollHeight * me.outerHeight();
                        offsetTop = Math.min(Math.max(offsetTop, 0), maxTop);
                        bar.css({top: offsetTop + 'px'});
                    }
                    me.scrollTop(delta);
                    me.trigger('slimscrolling', ~~delta);
                    showBar();

                    // hideBar();

                    /*加载列表*/
                    if (parseInt(bar.css('top')) == maxTop && count <= 0) {
                        count++;
                        o.scrollfun();
                    } else if (parseInt(bar.css('top')) < maxTop) {
                        count = 0;
                    }


                }

                function attachWheel() {
                    if (window.addEventListener) {
                        this.addEventListener('DOMMouseScroll', _onWheel, false);
                        this.addEventListener('mousewheel', _onWheel, false);
                    } else {
                        document.attachEvent("onmousewheel", _onWheel)
                    }
                }

                function getBarHeight() {
                    // calculate scrollbar height and make sure it is not too small
                    barHeight = Math.max((me.outerHeight() / me[0].scrollHeight) * me.outerHeight(), minBarHeight);
                    bar.css({height: barHeight + 'px'});

                    // hide scrollbar if content is not long enough
                    var display = barHeight == me.outerHeight() ? 'none' : 'none';
                    bar.css({display: display});
                }

                function showBar() {
                    getBarHeight();
                    clearTimeout(queueHide);

                    if (percentScroll == ~~percentScroll) {
                        //release wheel
                        releaseScroll = o.allowPageScroll;

                        // publish approporiate event
                        if (lastScroll != percentScroll) {
                            var msg = (~~percentScroll == 0) ? 'top' : 'bottom';
                            me.trigger('slimscroll', msg);
                        }
                    } else {
                        releaseScroll = false;
                    }
                    lastScroll = percentScroll;

                    // show only when required
                    if (barHeight >= me.outerHeight()) {
                        //allow window scroll
                        releaseScroll = true;
                        return;
                    }
                    bar.stop(true, true).fadeIn('fast');
                    if (o.railVisible) {
                        rail.stop(true, true).fadeIn('fast');
                    }
                }

                function hideBar() {
                    // only hide when options allow it
                    if (!o.alwaysVisible) {
                        queueHide = setTimeout(function () {
                            if (!(o.disableFadeOut && isOverPanel) && !isOverBar && !isDragg) {
                                bar.fadeOut('slow');
                                rail.fadeOut('slow');
                            }
                        }, 1000);
                    }
                }

            });

            // maintain chainability
            return this;
        }
    });

    $.fn.extend({
        slimscroll: $.fn.slimScroll
    });
    $('.scroll-statistical2').slimscroll({
        height: '100%',
        width: '100%',
        size: '3px',
        color: '#999',
        scrollfun: function () {
        }
    });

    /* 公共函数* end* */

    /* 通用操作* start* */

    /** 全选按钮* */
    $('.check-all').on('click', function () {
        $(this).parent().toggleClass('selected');
        if ($(this).is(':checked')) {
            $('.checkbox-child').prop('checked', true);
            $('.checkbox-child').parent().addClass('selected');
        } else {
            $('.checkbox-child').prop('checked', false);
            $('.checkbox-child').parent().removeClass('selected');
        }

    });
    /** 复选按钮* */
    $(document).on('click', '.checkbox-child', function () {
        $(this).parent().toggleClass('selected');
    });
    /** 单选按钮* */
    $(document).on('click', '.redio-child', function () {
        $(this).parent().addClass('selected');
        $(this).parent().siblings('.choose-redio').removeClass('selected').children().prop('checked', false);
    });
    /**开关*/
    $(document).on('click', 'input.switch-checkbox', function () {
        $(this).parent().toggleClass('selected');
        $(this).prop('checked', $(this).is(':checked'));
    });
    /**下拉菜单*/
    $(document).on('click', '.drop-down-menu', function (e) {
        var $this = $(this);
        console.log(e);
        $('.drop-down-menu').removeClass('omara-active');
        $this.toggleClass('omara-active');
        $this.children('.dropdown-content').addClass('dropdown-animation');
        setTimeout(function () {
            $this.children('.dropdown-content').removeClass('dropdown-animation');
        }, 200);
        /*点击空白处消失*/
        $('body').one("click", function () {
            $('.drop-down-menu').removeClass('omara-active');
        });
        e.stopPropagation();
    });
    $(document).on('click', '.dropdown-content li', function (e) {
        var $this = $(this);
        $this.addClass('selected').siblings('li').removeClass('selected');
        $('.drop-down-menu').removeClass('omara-active');
        if ($this.children('.icon-choose').length > 0) {
            $this.parent().siblings('.dropdown-toggle').find('.name').html($this.children('.icon-choose').clone());
        } else if ($this.children('.name').length > 0) {
            $this.parent().siblings('.dropdown-toggle').find('.name').html($this.children('.name').text());
        }
        /*点击空白处消失*/
        $('body').one("click", function () {
            $('.drop-down-menu').removeClass('omara-active');
        });
        e.stopPropagation();
    });
    $('.omara-left-menu .first-link').click(function () {
        $(this).parent().toggleClass('open');
        $(this).parent().siblings().removeClass("open");
    });
    $(document).on('click', '.omara-left-menu .sysGroup-click-panel', function () {
        $('.sysGroup-panel').toggleClass('hidden');
        if ($(this).find('.iconfont').hasClass('icon-arrow-right')) {
            $(this).find('.iconfont').removeClass('icon-arrow-right').addClass('icon-arrow-down');
        } else {
            $(this).find('.iconfont').removeClass('icon-arrow-down').addClass('icon-arrow-right');
        }

    });
    $('.omara-left-menu .tree-folder-header').on('click', function () {
        $(this).siblings('.tree-folder-content').toggleClass('open');
        // if($(this).siblings('.tree-folder-content').is(':visible')){
        //     $(this).siblings('.tree-folder-content').slideUp('100');
        // }else{
        //     $(this).siblings('.tree-folder-content').slideDown('200');
        // }

        var that = $(this);
        var is_have_id = false;
        if (sessionStorage.getItem('omara_left_menu') != undefined) {
            var omara_left_menu = JSON.parse(sessionStorage.getItem('omara_left_menu'));
            $.each(omara_left_menu, function (i, res) {
                if (that.children('.iconfont').hasClass('icon-minus')) {
                    if (res == that.attr('data-id')) {
                        omara_left_menu.splice(i, 1);
                    }
                }
                if (res == that.attr('data-id')) {
                    is_have_id = true;
                }
            });
            if (!is_have_id) {
                omara_left_menu.push(that.attr('data-id'));
            }
            sessionStorage.setItem('omara_left_menu', JSON.stringify(omara_left_menu));
        } else {
            var omara_left_menu = that.children('.iconfont').hasClass('icon-plus') ? '["' + that.attr('data-id') + '"]' : '[]';
            sessionStorage.setItem('omara_left_menu', omara_left_menu);
        }
        if ($(this).children('.iconfont').hasClass('icon-plus')) {
            $(this).children('.iconfont').removeClass('icon-plus').addClass('icon-minus');
        } else {
            $(this).children('.iconfont').removeClass('icon-minus').addClass('icon-plus');
        }
    });
    if (sessionStorage.getItem('omara_left_menu') != undefined) {
        var list = JSON.parse(sessionStorage.getItem('omara_left_menu'));
        $.each(list, function (i, res) {
            $('#left-menu-' + res).find('.iconfont').removeClass('icon-plus').addClass('icon-minus');
            $('#left-menu-' + res).siblings('.tree-folder-content').addClass('open');
        });
    }

    /*菜单收缩*/
    $('.list-toggle').click(function () {
        $('.omara-left-box').hide();
        // $('.omara-left-menu .first-panel').removeClass("open");
        $('.omara-copyright').toggle();
        setTimeout(
            function () {
                $('.omara-left-box').fadeIn(200);
            }, 200);
        $(".omara-right-box,.omara-top-info").toggleClass("in");
        $('.omara-left-box,.omara-logo').toggleClass("mini");
        $('.search-menu-text,.search-menu-close').hide();
        if ($(".omara-right-box").hasClass('in')) {
            $('.search-menu').hide();
            $('.omara-logo img').attr('src', $('.omara-logo img').attr('data-minlogo'));
        } else {
            $('.search-menu').show();
            $('.omara-logo img').attr('src', $('.omara-logo img').attr('data-maxlogo'));
        }

    });

    var menuHeight = $('.omara-copyright').attr('data-authorization') == 1 ? '80%' : '100%';
    $('.menu-list').slimscroll({
        height: $('.omara-left-box').height() - 60 + 'px',
        size: '6px',
        color: '#fff',
        width: '100%',
        height: menuHeight,
        scrollfun: function () {
        }
    });
    /**左栏菜单搜索*/
    $('.search-menu').on('click', function () {
        $(this).hide();
        $('.default-menu-list').hide();
        $('.search-menu-list').html('');
        $('.search-menu-text,.search-menu-close').show();
    });
    $('.search-menu-close').on('click', function () {
        $('.search-menu,.default-menu-list').removeAttr('style');
        $('.search-menu-text,.search-menu-close').hide();
        $('.search-menu-text').val('');
        $('.default-menu-list').removeAttr('style');
        $('.search-menu-list').html('');
    });
    var $leftMenuData = ((typeof leftMenuData) === 'undefined' ? [] : leftMenuData);
    $('.search-menu-text').bind("input propertychange", function (event) {
        var val = $(this).val();
        var html = '';
        var $url = $('.omara-left-box').attr('data-left_url');
        if (val != '') {
            $.each($leftMenuData, function (i, res) {
                if (res.name.indexOf(val) != -1) {
                    html += '<a href="' + $url + res.ID + '" class="third-link"><i class="iconfont icon-host"></i><span>' + res.name + '</span></a>';
                }
            });
        }
        $('.search-menu-list').html(html);
    });

    $(document).on('mouseenter', '.omara-left-box.mini .menu-list li a', function (e) {
        $(this).children('span').css({top: (e.pageY - e.offsetY) + 'px'});
    });
    /*右栏用户下拉*/
    $('.user-info').hover(function () {
        var _this = $(this);
        _this.toggleClass('active');
    });


    $(document).on('mouseover', '.dowmmenu-other-tool', function () {
        var $this = $(this);
        if ($('.dowmmenu-other-tool .dowmmenu').children().length > 0) {
            $this.children('.dowmmenu').show();
            $this.addClass('active');
            $this.children('.iconfont').addClass('active');
        }
    }).on('mouseout', '.dowmmenu-other-tool', function () {
        var $this = $(this);
        $this.removeClass('active');
        $this.children('.iconfont').removeClass('active');
        $this.children('.dowmmenu').hide();
    });

    /*高度*/
    var wheight = $(window).height() - 120;
    var win_width = $('.omara-room-index').width();
    $('.omara-content-box,.omara-system-box').css({minHeight: ($(window).height() - 120) + 'px'});
    $('.omara-room-index .box').css({
        height: wheight + 'px',
        width: win_width + 'px'
    }).attr('data-height', wheight).attr('data-width', win_width);
    $('.omara-camera-video,.omara-data-list.camera').css({minHeight: ($(window).height() - 117) + 'px'});
    /**页面加载完  定位 去掉遮罩层*/
    $(document).ready(function () {
        setTimeout(function () {
            $('html').addClass('filter-b');
        }, 500);
    });
    window.onload = loadingChange;//当页面加载状态改变的时候执行这个方法.
    function loadingChange() {

        if (document.readyState == "complete") { //当页面加载状态为完全结束时进入
            $('.omara-room-index .box').attr('data-imgw', $('.omara-room-index .equipment-thumb').width());
        }
    }

    /**弹窗显示与隐藏*/
    $('.dialog-toggle').on('click', function () {
        var titlebar = $('.omara-art-dialog .titlebar .name');
        titlebar.text(titlebar.attr('data-art-title'));
        $('.omara-art-dialog').show();
        $('.data-ID').val('');
        $('.choose-redio').removeClass('selected').children('.redio-child-options').prop('checked', false);
        $('.choose-redio').eq(1).addClass('selected').children('input').prop('checked', true);
        $('.data-list.left-group').children('.fist-name').removeClass('open');
        $('.data-list.left-group').children('.second-name').hide();
        $('.input-select').each(function () {
            $(this).find("option:first").prop("selected", 'selected');
        });
        $('.mdevice_type').hide();
    });
    var dialog_close_callback = function () {
        omara_func.clearInterval();
        $('.omara-art-dialog').hide();
        $('.data-ID').val('');
        $('.omara-art-dialog').find('input:text,input[name="ID"],input:password,textarea').val('');
        $('.choose-checkbox').removeClass('selected').children('.checkbox-child').prop('checked', false);
        $('.choose-checkbox.none').hide();
        $('.choose-redio').removeClass('selected').children('.redio-child-options').prop('checked', false);
        $('.choose-redio').eq(1).addClass('selected').children('input').prop('checked', true);
        $('.new-attr-box').remove();
        $('.omara-control-options-box').hide();
        $('.equip-list-box .iconfont').removeClass('selected');
        $('.data-list.new-list').children().hide().removeClass('show selected');
        $('.data-list.left-group').children().removeClass('selected');
        $('.omara-parameter-setting li').eq(0).addClass('selected').siblings().removeClass('selected');
        $('.omara-parameter-setting .dropdown-toggle .name').text('无');
        $('.input-select').each(function () {
            $(this).find("option:first").prop("selected", 'selected');
        });
        $('.mdevice_type').hide();
    };
    $('.dialog-close').on('click', function () {
        dialog_close_callback();
        $('.choose-checkbox.hide').removeClass('hide');
        var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
        if (type == 'myGroup') {
            $('.data-list').find('.second-name,.fist-name').removeAttr('style');
            $('.data-list.left-group').children('.second-name').removeAttr('style');
            $('.data-list.left-group').children('.hide').removeClass('none hide');
            $('.data-list .fist-name').removeClass('selected')
        } else if (type == 'sysGroup') {
            $('.data-list').find('.fist-name').removeAttr('style');
            $('.data-list .fist-name').removeClass('selected');
            $('.data-list.left-group').children().removeClass('hide');
        }
        $('.data-list.left-group').children().removeClass('hide');
    });

    /*视频显示与隐藏*/
    $('#switch-camera').on('click', function () {
        $('.omara-camera-video').toggle();
        if ($(this).is(':checked')) {
            $('.omara-data-list.camera').css({width: '30%'});
        } else {
            $('.omara-data-list.camera').css({width: '100%'});
        }
    });

    /**时间*/
    if ($('.start-date').length > 0) {
        var date = new Date();
        $.datetimepicker.setLocale('ch');
        $('.start-date').val(date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate() + ' 00:00');
        $('.start-date').datetimepicker({
            format: 'Y-m-d H:i',
        });
    }
    if ($('.end-date').length > 0) {
        var date = new Date();
        $.datetimepicker.setLocale('ch');
        $('.end-date').val(date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate() + ' 23:59');
        $('.end-date').datetimepicker({
            format: 'Y-m-d H:i',
        });
    }

    /**删除*/
    $(document).on('click', '.delete-single', function () {
        var that = $(this);
        that.addClass('active');
        omara_func.dialog_confirm({
            show_text: '确认删除吗？',
            dialog_id: 'delete-confirm'
        });
    });
    $(document).on('click', "#delete-confirm .btn-confirm", function () {
        var that = $('.delete-single.active');
        var data = {a: 'delete', info: '{"id":"' + that.attr('data-id') + '"}'};
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: data,
            callback: function (data) {
                $('#' + that.attr('data-pid')).remove();
            },
            error: function () {

            }
        });
        that.removeClass('active');
        $('.dialog-confirm').remove();
    });
    $(document).on('click', '.assets-delete-single', function () {
        var that = $(this);
        that.addClass('active');
        omara_func.dialog_confirm({
            show_text: '确认删除吗？',
            dialog_id: 'assets-delete-confirm'
        });
    });
    $(document).on('click', '.contact-delete-single', function () {
        var that = $(this);
        that.addClass('active');
        omara_func.dialog_confirm({
            show_text: '确认删除吗？',
            dialog_id: 'contact-delete-confirm'
        });
    });
    $(document).on('click', '.assets-record-delete-single', function () {
        var that = $(this);
        that.addClass('active');
        omara_func.dialog_confirm({
            show_text: '确认删除吗？',
            dialog_id: 'assets-record-delete-confirm'
        });
    });
    /*!点击确定按钮 进行功能操作*/
    $(document).on('click', "#assets-delete-confirm .btn-confirm", function () {
        var that = $('.assets-delete-single.active');
        var data = {a: 'deleteAsset', info: '{"id":"' + that.attr('data-id') + '"}'};
        omara_func.ajax_data({
            url: $('.omara-data-list').attr('data-url_get'),
            data: data,
            callback: function (data) {
                $('#' + that.attr('data-pid')).remove();
            },
            error: function () {

            }
        });
        that.removeClass('active');
        $('.dialog-confirm').remove();
    });
    $(document).on('click', "#assets-record-delete-confirm .btn-confirm", function () {
        var that = $('.assets-record-delete-single.active');
        var data = {a: 'deleteRecord', info: '{"id":"' + that.attr('data-id') + '"}'};
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: data,
            callback: function (data) {
                $('#' + that.attr('data-pid')).remove();
            },
            error: function () {

            }
        });
        that.removeClass('active');
        $('.dialog-confirm').remove();
    });
    $(document).on('click', "#contact-delete-confirm .btn-confirm", function () {
        var that = $('.contact-delete-single.active');
        var data = {
            a: 'delete',
            info: '{"id":"' + that.attr('data-id') + '","usertype":"' + $('.omara-art-dialog input[name=usertype]').val() + '"}'
        };
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: data,
            callback: function (data) {
                $('#' + that.attr('data-pid')).remove();
            },
            error: function () {

            }
        });
        that.removeClass('active');
        $('.dialog-confirm').remove();
    });
    /*!点击取消按钮 确认弹窗隐藏*/
    $(document).on('click', ".btn-cancel", function () {
        $('.dialog-confirm').remove();
        $('.delete-single.active,.assets-delete-single.active').removeClass('active');
    });
    /* 通用操作* end* */

    /**验证码发送*/
    $('.send-verification-code').on('click', function () {
        var dom = $('#input-mobile');
        omara_func.is_validity({
            dom: $('#sign-user'),
            isnull_msg: '',
            isreg_msg: '',
            reg: !omara_func.reg.is_mobile(dom.val()),
            reglength: false,
            length: 20
        });
        if (dom.val() === '') {
            dom.focus();
            dom.parent().addClass('focus').siblings().removeClass('focus');
            return;
        } else {
            $.ajax({
                url: $('.set-am-form').attr('data-sms'),
                dataType: 'json',
                data: {mobile: dom.val()},
                type: 'post',
                success: function (data) {
                    if (data.state === 'ok') {
                        omara_func.interVal({dom: '.send-verification-code', time: 60});
                    } else {
                        omara_func.dialog_tips({show_text: data.msg, show_time: 1000});
                    }

                },
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    console.log(XMLHttpRequest.status);
                    console.log(XMLHttpRequest.readyState);
                    console.log(textStatus);
                }
            });
        }
    });

    /**修改密码*/
    $('.modify-pwd').on('click', function () {
        $('.modify-pwd-dialog').show();
    });
    $('.default-dialog-close').on('click', function () {
        $('.modify-pwd-dialog').hide();
        $('input:password').val('');
    });
    $('.modify-pwd-save').on('click', function () {
        var that = $(this);
        var oldpwd = $('.omara-user-pwd');
        var newpwd = $('.omara-new-pwd');
        var renewpwd = $('.omara-renew-pwd');
        omara_func.is_validity({
            dom: '.omara-user-pwd', reg: false, reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.omara-new-pwd', reg: !omara_func.reg.is_pwd(newpwd.val()), reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.omara-renew-pwd', reg: false, reglength: false,
            length: 20
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
            $('.regerr').eq(0).focus();
            omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
            return false;
        } else if (newpwd.val() != renewpwd.val()) {
            renewpwd.focus();
            omara_func.dialog_tips({show_text: '两次输入的新密码不一致', show_time: 2000});
        } else {
            var id = $('.data-ID').val();
            var data = omara_func.info_data({form: $('.modify-pwd-form').find('input:password'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.modify-pwd-form').attr('action'),
                data: {a: 'pswd', info: '{' + data + ',"id":"' + id + '"' + '}'},
                callback: function (data) {
                    /*保存成功清除数据，关闭弹窗*/
                    $('.modify-pwd-dialog').hide();
                    $('.modify-pwd-dialog input:password').val('');
                },
                error: function () {

                }
            });
        }
    });

    /**快速定位*/
    /**百度地图API功能*/
    if ($('.map-positioning').length > 0) {
        var fixed = ['01', '02', '03'];
        var fixedColor = ['#128D30', '#FF3300', '#8A8A8A'];
        $('.omara-right-box').css({'min-height': '80%'});
        $('.off-line-map').css({'max-height': '100%', 'max-width': '100%'});
        $('.map-positioning,.map-positioning').css({
            height: ($('.offline-map-set').length > 0 ? $(window).height() - 130 : $(window).height() - 90) + 'px',
            width: $('.omara-right-box').width()
        });
        if ($('#rapid-positioning').length > 0) {
            var positioning = new BMap.Map("rapid-positioning");
            var point = new BMap.Point(116.404, 39.915);
            positioning.centerAndZoom(point, 5);
            positioning.enableScrollWheelZoom();
        }
        var pointArray = new Array();
        omara_func.ajax_data({
            url: $('.map-positioning').attr('data-url'),
            data: {a: 'list'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                if (typeof datas != "undefined") {
                    $.each(datas, function (i, info) {
                        var maxtrix = info.maxtrix;
                        var extra_msg = (info.extra_msg == null ? [] : JSON.parse(info.extra_msg));
                        var attr_item = '';
                        $.each(extra_msg, function (name, result) {
                            attr_item += '<p>' + result + '</p>';
                        });
                        if (maxtrix != null) {
                            if ($('#rapid-positioning').length > 0) {
                                if (maxtrix.indexOf('%') == -1 && maxtrix.indexOf('$') == -1) {
                                    var lat = maxtrix.substring(0, maxtrix.indexOf(','));
                                    var lng = maxtrix.substring(maxtrix.indexOf(',') + 1, maxtrix.length);
                                    var myIcon = new BMap.Icon("/static/images/fixed" + fixed[info.linkState] + ".png", new BMap.Size(23, 23));
                                    var marker = new BMap.Marker(new BMap.Point(lng, lat), {icon: myIcon});
                                    positioning.addOverlay(marker);
                                    pointArray[i] = new BMap.Point(lng, lat);
                                    var label = new BMap.Label('<a href="' + info.url + '">' + info.name + '</a>', {offset: new BMap.Size(25, 0)});
                                    label.setStyle({
                                        border: '1px solid ' + fixedColor[info.linkState],
                                        padding: '2px 5px'
                                    });
                                    marker.setLabel(label);
                                    var address = '';
                                    var txt = '', mouseoverTxt = '';

                                    function ComplexCustomOverlay(point, text, mouseoverText) {
                                        this._point = point;
                                        this._text = text;
                                        this._overText = mouseoverText;
                                    }

                                    ComplexCustomOverlay.prototype = new BMap.Overlay();
                                    ComplexCustomOverlay.prototype.initialize = function (map) {
                                        this._map = map;
                                        var div = this._div = document.createElement("div");
                                        div.style.position = "absolute";
                                        div.style.zIndex = BMap.Overlay.getZIndex(this._point.lat);
                                        div.style.backgroundColor = "rgba(0,0,0,0.8)";
                                        div.style.color = "white";
                                        div.style.padding = "0 10px";
                                        div.style.lineHeight = "24px";
                                        div.style.width = "160px";
                                        // div.style.whiteSpace = "nowrap";
                                        div.style.MozUserSelect = "none";
                                        div.style.fontSize = "12px";
                                        var span = this._span = document.createElement("div");
                                        div.appendChild(span);
                                        span.innerHTML = this._text;
                                        var that = this;

                                        var arrow = this._arrow = document.createElement("div");
                                        arrow.style.position = "absolute";
                                        arrow.style.width = "11px";
                                        arrow.style.height = "10px";
                                        arrow.style.top = "0px";
                                        arrow.style.left = "-10px";
                                        arrow.style.overflow = "hidden";
                                        div.appendChild(arrow);

                                        positioning.getPanes().labelPane.appendChild(div);

                                        return div;
                                    };
                                    ComplexCustomOverlay.prototype.draw = function () {
                                        var map = this._map;
                                        var pixel = map.pointToOverlayPixel(this._point);
                                        this._div.style.left = pixel.x - parseInt(this._arrow.style.left) + "px";
                                        this._div.style.top = pixel.y - 30 + "px";
                                    }
                                    var myCompOverlay;
                                    txt = '<p>名称：' + info.name + '</p><p>健康度：' + info.health + '</p>' + attr_item;
                                    mouseoverTxt = txt;
                                    myCompOverlay = new ComplexCustomOverlay(new BMap.Point(lng, lat), txt, '');
                                    marker.addEventListener("mouseover", function (e) {
                                        positioning.addOverlay(myCompOverlay);
                                    });
                                    marker.addEventListener("mouseout", function (e) {
                                        positioning.removeOverlay(myCompOverlay);
                                    });
                                    marker.addEventListener("click", function () { //点击marker显示label
                                        location.href = info.url;
                                    });
                                }
                            } else {
                                if (maxtrix.indexOf('%') < 0 && maxtrix.indexOf('$') > 0) {
                                    var screenX = maxtrix.substring(0, maxtrix.indexOf('$,'));
                                    var screenY = maxtrix.substring(maxtrix.indexOf(',') + 1, maxtrix.length - 1);
                                    var Px = ($('.omara-offline-map').width() / 2);
                                    var Ix = $('.map-positioning .off-line-map').width() / 2;
                                    var Iy = $('.map-positioning .off-line-map').height() / 2;
                                    var xx = (screenX * Ix) + Px;
                                    var yy = Iy - (screenY * Iy);
                                    var setbtn = $('.offline-map-set').length;
                                    var pop = '<div class="offline-map-art"  id="mark-art-' + info.ID + '" style="display: none;left:' + (xx + 233) + 'px;top:' + (yy + (setbtn == 0 ? 55 : 100)) + 'px;">' +
                                        '<p>名称：' + info.name + '</p>' +
                                        '<p>健康度：' + info.health + '</p>' +
                                        attr_item +
                                        '</div>';
                                    html += pop + '<div class="items" style="left:' + xx + 'px;top:' + yy + 'px;">' +
                                        '<a href="' + info.url + '">' +
                                        '            <img src="/static/images/fixed' + fixed[info.linkState] + '.png" data-id="mark-art-' + info.ID + '" class="map-mark omara-middle" alt="" >' +
                                        '            <span style="border:1px solid ' + fixedColor[info.linkState] + ';">' + info.name + '</span>' +
                                        '        </a></div>';
                                }
                            }
                        }
                    });
                }
                if ($('#rapid-positioning').length > 0) {
                    function clear_arr_trim(array) {
                        for (var i = 0; i < array.length; i++) {
                            if (array[i] == "" || typeof (array[i]) == "undefined") {
                                array.splice(i, 1);
                                i = i - 1;
                            }
                        }
                        return array;
                    }

                    var arr = pointArray;
                    var pointArray_c = clear_arr_trim(arr);
                    positioning.centerAndZoom(pointArray_c[0], 5);
                    positioning.setViewport(pointArray_c);
                }
                $('.omara-offline-map').append(html);
            },
            error: function () {
            }
        });
        $(document).on('mouseenter', '.omara-offline-map .items .map-mark', function (e) {
            var that = $(this);
            $('#' + that.attr('data-id')).show();
            e.stopPropagation();
        }).on('mouseleave', '.omara-offline-map .items', function (e) {
            $('.offline-map-art').hide();
        });

    }
    /**管理员设置地图定位*/
    $('.offline-map-set').on('click', function () {
        $('.room-offline-dialog').show();
        $('.visval-dislog .room-icon.already-plus').each(function (i) {
            var that = $(this);
            var maxtrix = that.attr('data-maxtrix');
            if (maxtrix != undefined) {
                var screenX = maxtrix.substring(0, maxtrix.indexOf('$,'));
                var screenY = maxtrix.substring(maxtrix.indexOf(',') + 1, maxtrix.length - 1);
                var Px = ($('.visval-dislog .equipment-profile').width() / 2);
                var Ix = $('.room-offline-thumb').width() / 2;
                var Iy = $('.room-offline-thumb').height() / 2;
                var xx = (maxtrix.indexOf('%') != -1 ? 0 : ((screenX * Ix) + Px));
                var yy = (screenY.indexOf('%') != -1 ? 0 : (Iy - (screenY * Iy)));
                that.css({
                    left: xx + 'px',
                    top: yy + 'px',
                });
            } else {
                $('.room-offline-name option').each(function () {
                    var option = $(this);
                    if (option.attr('data-id') == that.attr('data-id')) {
                        option.attr('data-selected', false);
                        option.text(option.val());
                    }
                });
                that.css({left: 0, top: 0}).hide()
                    .removeClass('already-plus')
                    .removeAttr('data-id')
                    .children().remove();
            }
        });
    });
    $("#omara-up-offline").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.isup_img(that.val()),
            errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
        });
        if (!that.hasClass('err')) {
            omara_func.update_ajaxform({
                dom: '.visval-dislog .set-form',
                updom: 'omara-up-offline',
                url: that.attr('data-post'),
                callback: function (data) {
                    $('.data-offline-img').val(data);
                    $('.visval-dislog .room-offline-thumb').attr('src', data);
                }
            });
        }
    });
    $('.add-room-offline').on('click', function () {
        /*添加机房*/
        var that = $(this);
        var equip = $('.room-offline-name option:selected');
        if (equip.attr('data-selected') == 'true') {
            omara_func.dialog_tips({show_text: '该机房已添加', show_time: 1000});
        } else {
            equip.attr('data-selected', true);
            var html = ' <img src="/static/images/fixed02.png" class="map-mark omara-middle" alt="" >' +
                '                        <span>' + equip.text() + '</span>';
            $('.visval-dislog .room-icon').eq($('.visval-dislog .room-icon.already-plus').length).show()
                .addClass('already-plus').html(html)
                .attr('data-id', equip.attr('data-id'))
                .css({left: 0 + 'px', top: 0 + 'px'});
            equip.text('(已添加)' + equip.val());
        }

    });
    $('.remove-room-all').on('click', function () {
        /*清空设备*/
        omara_func.dialog_confirm({
            show_text: '确定清空所有机房吗？',
            dialog_id: 'delete-room-all'
        });
    });
    /*!点击确定按钮 清空设备*/
    $(document).on('click', "#delete-room-all .btn-confirm", function () {
        $('.visval-dislog .room-icon.already-plus')
            .css({left: 0, top: 0}).hide()
            .removeClass('already-plus')
            .removeAttr('data-id')
            .children().remove();
        $('.dialog-confirm').remove();
        $('.room-offline-name option').each(function () {
            var option = $(this);
            option.attr('data-selected', false);
            option.text(option.val());
        });
    });
    $('.room-offline-save').on('click', function () {
        /*保存可视化内容*/
        var that = $(this);
        omara_func.proccess({dom: that});
        var equipent = '';
        var imgdom = $('.visval-room-body.equipment-profile');
        var img = $('.visval-room-body .room-offline-thumb');
        var equip = $('.visval-dislog .room-icon.already-plus');
        var Px = imgdom.width() / 2;
        var Py = imgdom.height() / 2;
        var Ix = img.width() / 2;
        var Iy = img.height() / 2;
        for (var e = 0; e < equip.length; e++) {
            if (e != 0) {
                equipent += ',';
            }
            var Ex = parseFloat(equip.eq(e).css('left'));
            var Ey = parseFloat(equip.eq(e).css('top'));
            var top = (equip.eq(e).css('top') == '0px' || equip.eq(e).css('top') == '0') ? '%' : ((Iy - Ey) / Iy).toFixed(5) + '$';
            var left = (equip.eq(e).css('left') == '0px' || equip.eq(e).css('left') == '0') ? '%' : ((Ex - Px) / Ix).toFixed(5) + '$';
            equipent += '{"ID":"' + equip.eq(e).attr('data-id') + '","pos":"' + left + ',' + top + '"' + '}';
        }
        ;
        omara_func.ajax_data({
            url: $('.visval-dislog .set-form').attr('action'),
            data: {a: 'save', info: '{"3dmap":"' + img.attr('src') + '","equips":[' + equipent + ']}'},
            callback: function (data) {
                var datas = data.data[0];
                $('.visval-dislog').hide();
                omara_func.refresh_page({time: 200});

            },
            error: function () {

            }
        });
    });
    /* 监控中心* start* */

    /**机房首页、首页*/
    var requestFullScreen = function (element) {
        // 判断各种浏览器，找到正确的方法
        if (document.documentElement.RequestFullScreen) {
            document.documentElement.RequestFullScreen();
        }
        //兼容火狐
        if (document.documentElement.mozRequestFullScreen) {
            document.documentElement.mozRequestFullScreen();
        }
        //兼容谷歌等可以webkitRequestFullScreen也可以webkitRequestFullscreen
        if (document.documentElement.webkitRequestFullScreen) {
            document.documentElement.webkitRequestFullScreen();
        }
        //兼容IE,只能写msRequestFullscreen
        if (document.documentElement.msRequestFullscreen) {
            document.documentElement.msRequestFullscreen();
        }
    };
    var checkFull = function () {
        var isFull = document.fullscreenEnabled || window.fullScreen || document.webkitIsFullScreen || document.msFullscreenEnabled;
        //to fix : false || undefined == undefined
        if (isFull === undefined) {
            isFull = false;
        }
        return isFull;
    };
    var exitFull = function () {
        // 判断各种浏览器，找到正确的方法
        $('.omara-room-index').removeClass('max');
        $('.omara-room-close').hide();
        var wheight = $('.omara-room-index .box').attr('data-height');
        var win_width = $('.omara-room-index .box').attr('data-width');
        $('.omara-room-index .box').css({height: wheight + 'px', width: win_width + 'px'});
        var Px = (win_width / 2);
        var Ix = ($('.omara-room-index .equipment-thumb').width() / 2);
        var Iy = (wheight / 2);
        $('.omara-room-index .plusitem').each(function (i) {
            var xx = ($(this).attr('data-left') * Ix) + Px;
            var yy = Iy - ($(this).attr('data-top') * Iy);
            $(this).css({left: xx + 'px', top: yy + 'px'});
        });

        var el = document;
        var cfs = el.cancelFullScreen || el.webkitCancelFullScreen ||
            el.mozCancelFullScreen || el.exitFullScreen;
        if (cfs) { //typeof cfs != "undefined" && cfs
            cfs.call(el);
        } else if (typeof window.ActiveXObject != "undefined") {
            //for IE，这里和fullScreen相同，模拟按下F11键退出全屏
            var wscript = new ActiveXObject("WScript.Shell");
            if (wscript != null) {
                wscript.SendKeys("{F11}");
            }
        }

    };
    $('.omara-full-screen').on('click', function () {
        /*全屏*/
        $('.omara-room-index').addClass('max');
        $('.omara-room-close').show();
        var win_width = parseFloat($('.omara-room-index .box').attr('data-win_width'));
        var win_height = parseFloat($('.omara-room-index .box').attr('data-win_height'));
        $('.omara-room-index .box').css({height: win_height + 'px', width: win_width + 'px'});
        $('.omara-room-index .plusitem').remove();
        // var wheight = parseFloat($('.omara-room-index .box').attr('data-height'));
        // var imgwidth = parseFloat($('.omara-room-index .box').attr('data-imgw'));
        // $('.omara-room-index .plusitem').hide();
        // setTimeout(function () {
        //     var Px = (win_width / 2);
        //     var h = wheight / imgwidth;
        //     var Ix = ((win_height / h) / 2);
        //     var Iy = (win_height / 2);
        //     $('.omara-room-index .plusitem').each(function (i) {
        //         var xx = ($(this).attr('data-left') * Ix) + Px;
        //         var yy = Iy - ($(this).attr('data-top') * Iy);
        //         $(this).css({left: xx + 'px', top: yy + 'px'}).show();
        //     });
        //
        // },500);
        room_equip_list1({id: $('.list-info-value').attr('data-id'), time: 500});
        requestFullScreen(document.documentElement);
    });
    $(document).keyup(function (event) {
        if (event.keyCode == 27) {
            $('.omara-room-index').removeClass('max');
            exitFull();
        }
    });
    // window.onresize = function () {
    //     if (!checkFull()) {
    //         //要执行的动作
    //         exitFull();
    //         setTimeout(function () {
    //             exitFull();
    //         }, 100);
    //     }
    // };

    $('.omara-room-close').on('click', function () {
        /*退出全屏*/
        exitFull();
    });

    /*首页告警信息列表*/
    var index_alert = function () {
        /*首页告警信息列表*/
        var data = $('.list-info-value').val();
        var ps = 20;
        var relieve_type = $('.list-info-value').attr('data-relieve_type');
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"' + data + '","ps":"' + ps + '","cp":"' + 1 + '","relieve_type":"' + relieve_type + '"}'
            },
            callback: function (data) {
                var datas = data.data;
                var html = '';
                $.each(datas, function (i, result) {
                    var status = result.alert_status != '2' && result.is_confirmed != '1' ? 'omara-warring' : '';
                    var status_val = result.alert_status == '0' && result.is_confirmed != '1' ? '告警' : (result.is_confirmed != '1' ? '故障' : '已确认');
                    var icon = omara_func.alarm_type(result.notify_mode);
                    var urlGroups = '';
                    var urlEquipments = '';
                    if (result.urlGroups == 'javascript:void (0);') {
                        urlGroups = '<span>' + result.name + '</span>';
                    } else {
                        urlGroups = '<a href="' + result.urlGroups + '" class="' + status + '">' + result.name + '</a>';
                    }
                    if (result.urlEquipments == 'javascript:void (0);') {
                        urlEquipments = '<span>' + result.eq_name + '</span>';
                    } else {
                        urlEquipments = '<a href="' + result.urlEquipments + '" class="' + status + '">' + result.eq_name + '</a>';
                    }
                    html += '<tr class="' + status + '">' +
                        '                    <td class="omara-textcenter" width="100">' + i + '</td>' +
                        '                    <td width="15%">' + urlGroups + '</td>' +
                        '                    <td width="25%">' + urlEquipments + '</td>' +
                        '                    <td width="120" class="omara-textcenter">' + result.alert_item + '</td>' +
                        '                    <td width="100" class="omara-textcenter">' + result.alert_value + '</td>' +
                        '                    <td width="100" class="omara-textcenter">' + result.alert_describe + '</td>' +
                        '                    <td width="10%" class="omara-textcenter">' + result.pubdate + '</td>' +
                        '                    <td width="15%" class="omara-textcenter">' +
                        icon +
                        '                    </td>' +
                        '                    <td width="100" class="omara-textcenter">' + result.realname + '</td>' +
                        '                    <td class="omara-textcenter ' + status + '" width="100">' +
                        status_val +
                        '                    </td>' +
                        '                </tr>';

                });
                $('.index-alert tbody').html(html);
            },
            error: function () {
            }
        });
    };
    if ($('.index-alert').length > 0) {
        index_alert();
    }

    if ($('.omara-camera-video').length > 0) {
        /*视频页列表加载*/
        var data = $('.list-info-value').val();
        var type = $('.list-info-value').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        var id = $('.list-info-value').attr('data-id');
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"' + data + '",' + re_type + ',"id":"' + id + '"}'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                $.each(datas, function (i, result) {
                    var status = result.normal == result.number ? '' : 'omara-warring';
                    var statusval = result.normal == result.number ? '正常' : '告警';
                    html += '<tr>' +
                        '                        <td width="60%"><a href="' + result.url + '">' + result.type_name + '</a></td>' +
                        '                        <td width="30%" class="omara-textcenter">' + result.number + '</td>' +
                        '                        <td class="omara-textcenter ' + status + '" width="100">' + statusval + '</td>' +
                        '                    </tr>';

                });
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
            }
        });
    }
    var statistical_list = function () {
        var that = $('.home-info-equipments-type');
        var data = that.val();
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'statistics', info: '{}'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var tag = '';
                var url = '';
                $.each(datas, function (i, result) {
                    if (i % 3 == 0) {
                        html += '<li>';
                    }
                    if (result.url == '') {
                        tag = 'span';
                        url = '';
                    } else {
                        tag = 'a';
                        url = 'href="' + result.url + '"';
                    }
                    html += '<' + tag + ' ' + url + ' class="name omara-textcenter"><em class="omara-fsize-24 omara-displayblock">' + result.value + '</em>' + result.name + '</' + tag + '>';
                    if ((i + 1) % 3 == 0) {
                        html += '</li>';
                    }
                });
                $('.statistical-list').html(html);
            },
            error: function () {
            }
        });
    };
    if ($('.statistical-list').length > 0) {
        /*统计信息*/
        statistical_list();
    }
    var energy_info = function () {
        var that = $('.omara-energy-info');
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'health', info: '{}'},
            callback: function (data) {
                var datas = data.data;
                omara_func.charts_pie({
                    id: 'omara-home-equip-pie',
                    datas: datas.equipments,
                    piename: '设备项',
                    size: '90%'
                });
                omara_func.charts_pie({
                    size: '90%',
                    id: 'omara-home-monitor-pie',
                    datas: datas.monitor,
                    piename: '监控项'
                })
            },
            error: function () {
            }
        });
    };
    if ($('.energy-info').length > 0) {
        /*首页能耗*/
        energy_info();
    }
    var index_chart = function () {
        var chart_index;
        var width = $('.omara-home-chart').width() - 10;
        if ($('.home-chart-type').length > 0) {
            var that = $('.home-chart-type');
            var data = that.children('option:selected').val();
            var type = $('.omara-tabs-time .active').attr('data-type');
            var retype = type.replace(/'/g, '"');
            var dataarr = new Array(0);
            chart_index = omara_func.charts({
                'dom': 'statistics-home-chart',
                'data': dataarr,
                'width': width,
                xtype: "datetime",
                'type': 'spline',
                'title': '',
                verticalAlign: 'top',
                legend: true,
                backgroundColor: 'transparent'
            });
            omara_func.ajax_data({
                url: that.attr('data-url'),
                data: {a: 'list', info: '{"id":"' + data + '",' + retype + '}'},
                callback: function (data) {
                    var charts_w = data.data;
                    chart_index = omara_func.charts({
                        'dom': 'statistics-home-chart',
                        'data': charts_w,
                        'width': width,
                        xtype: "datetime",
                        'type': 'spline',
                        'title': '',
                        verticalAlign: 'top',
                        legend: true,
                        backgroundColor: 'transparent'
                    });
                    omara_func.charts_label({
                        chart: chart_index,
                        minshow: false,
                        maxshow: true
                    });
                    chart_index.hideLoading();
                },
                error: function () {
                    chart_index = omara_func.charts({
                        'dom': 'statistics-home-chart',
                        'data': dataarr,
                        'width': width,
                        'type': 'spline',
                        xtype: "datetime",
                        'title': '',
                        verticalAlign: 'top',
                        legend: true,
                        backgroundColor: 'transparent'
                    });
                    chart_index.hideLoading();
                }
            });
        }
    };
    index_chart();
    $('.home-chart-type').on('change', function () {
        var that = $(this);
        var href = $('.export-excel').attr('data-url') + '?id=' + that.find('option:selected').val() + '&t=' + $('.omara-tabs-time .active').attr('data-t');
        $('.export-excel').attr('href', href);
        index_chart();

    });
    $('.omara-tabs-time .tabs-items').on('click', function () {
        var that = $(this);
        that.addClass('active').siblings().removeClass('active');
        var href = $('.export-excel').attr('data-url') + '?id=' + $('.home-chart-type option:selected').val() + '&t=' + that.attr('data-t');
        $('.export-excel').attr('href', href);
        index_chart();
    });
    setInterval(function () {
        index_chart();
        if ($('.energy-info').length > 0) {
            /*首页能耗*/
            energy_info();
        }
        if ($('.statistical-list').length > 0) {
            /*统计信息*/
            statistical_list();
        }
        if ($('.index-alert').length > 0) {
            index_alert();
        }
    }, 15000);


    /**机房设备显示*/
    var equip_html = function (o) {
        var ehtml = '';
        var evalue = '';
        if (o.icon_type == '0') {
            $.each(o.monitor, function (i, result) {
                if (o.showvalue) {
                    evalue = '：' + o.current_value[i]
                } else {
                    evalue = '';
                }

                ehtml += '<p>' + result + evalue + '</p>';
            });
        } else {
            ehtml = '<p>' + o.name + '</p>';
        }

        var html = '<div class="prompting ' + (ehtml == '' ? 'icon-min' : 'icon-default') + '">' +
            ' <div class="upsicon" style="background-image: url(' + o.icon.replace('.png', '.svg') + ') ;"></div>' +
            '            </div>' +
            '<div class="plusinfo ' + (ehtml == '' ? 'hidden' : '') + '">' +
            ehtml +
            '            </div>';
        return html;
    };
    var room_equip_list1 = function (o) {
        var data = $('.list-info-value').val();
        var id = o.id;
        var id2 = $('.list-info-value').attr('data-id');
        var type = $('.list-info-value').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {a: 'list', info: '{"limits":"' + data + '","id":"' + id + '",' + re_type + '}'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                if ((typeof datas.equips) != "string") {
                    var Px = ($('.omara-room-index .box').width() / 2);
                    var Py = ($('.omara-room-index .box').height() / 2);
                    var Ix = ($('.omara-room-index .equipment-thumb').width() / 2);
                    var Iy = ($('.omara-room-index .equipment-thumb').height() / 2);
                    $('.omara-room-index .box').attr('data-imgw', $('.omara-room-index .equipment-thumb').width()).attr('data-win_width', window.screen.availWidth).attr('data-win_height', window.screen.height);
                    $.each(datas.equips, function (i, result) {
                        var status = result.istatus == '正常' ? 'normal' : 'error';
                        var pos = result.pos;
                        var left = pos.substring(0, pos.indexOf(','));
                        var top = pos.substring(pos.indexOf(',') + 1, pos.length);
                        var title = '';
                        var evalue = '';
                        if (left != '%' && top != '%') {
                            var xx = (left * Ix) + Px;
                            var yy = Iy - (top * Iy);
                            if (data.icon_type == '1') {
                                $.each(result.monitor, function (m, res) {
                                    if (true) {
                                        evalue = '：' + result.current_value[m] + '\n';
                                    } else {
                                        evalue = '';
                                    }

                                    title += res + evalue;
                                });
                            }
                            html += '<div class="plusitem clearfix already-plus ' + status + (data.icon_type == '0' ? ' default' : ' min') + '" data-left="' + left + '" data-top="' + top + '" title="' + title + '" style="left:' + xx + 'px;top: ' + yy + 'px;">' +
                                '<a href="' + result.url + '" class="a-link ' + status + '" target="'+(result.blank?'_blank':'_self')+'">' +
                                equip_html({
                                    name: result.eq_name,
                                    icon: result.icon,
                                    url: result.url,
                                    monitor: result.monitor,
                                    showvalue: true,
                                    current_value: result.current_value,
                                    icon_type: data.icon_type
                                }) +
                                '</a>' +
                                '        </div>';
                        }
                    });
                }

                if (id2 == id) {
                    $('.omara-room-index .box').children('.plusitem').remove();
                    setTimeout(function () {
                        $('.omara-room-index .box').append(html);
                    }, o.time);
                    $('.omara-title-bar .first-name').text(datas.name);
                    if (datas._3dmap != '') {
                        $('.omara-room-index .equipment-thumb').show();
                        $('.omara-room-index .room-3d-thumb').attr('src', datas._3dmap);
                    }
                }

            },
            error: function () {
                if ($('.omara-room-index').length > 0) {
                    $('.omara-room-index .plusitem').remove();
                }
            }
        });
    };
    var room_equip_list2 = function (o) {
        var data = $('.list-info-value').val();
        var id = o.id;
        var id2 = $('.list-info-value').attr('data-id');
        var type = $('.list-info-value').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {a: 'list', info: '{"limits":"' + data + '","id":"' + id + '",' + re_type + '}'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var html2 = '';
                var option = '';
                $('.data-room-thumb').val(datas._3dmap);
                $('.visval-dislog .room-3d-thumb').attr('src', datas._3dmap);
                $('.visval-dislog .plusitem').html('')
                    .removeClass('already-plus')
                    .removeAttr('data-id')
                    .removeAttr('data-icon')
                    .removeAttr('id')
                    .css({left: '0', top: '0', display: 'none'});
                setTimeout(function () {
                    if ((typeof datas.equips) != "string") {
                        var Pxx = ($('.visval-room-body').width() / 2);
                        var Pyy = ($('.visval-room-body').height() / 2);
                        var Ixx = ($('.visval-room-body .equipment-thumb').width() / 2);
                        var Iyy = ($('.visval-room-body .equipment-thumb').height() / 2);
                        $.each(datas.equips, function (i, result) {
                            var status = result.istatus == '正常' ? 'normal' : 'error';
                            var pos = result.pos;
                            var left = pos.substring(0, pos.indexOf(','));
                            var top = pos.substring(pos.indexOf(',') + 1, pos.length);
                            var vxx = (left * Ixx) + Pxx;
                            var vyy = Iyy - (top * Iyy);
                            html2 = equip_html({
                                name: result.eq_name,
                                icon: result.icon,
                                url: 'javascript:void(0);',
                                monitor: result.monitor,
                                showvalue: false,
                                current_value: ''
                            });
                            $('.visval-dislog .plusitem').eq(i).show()
                                .addClass('already-plus default already-plus2').html(html2)
                                .attr('data-id', result.ID)
                                .attr('id', 'already-plus' + result.ID)
                                .attr('data-icon', result.icon)
                                .css({left: vxx + 'px', top: vyy + 'px', display: 'block'});
                            if (left != '%' && top != '%') {
                                option += '<li data-name="' + result.eq_name + '" data-id="' + result.ID + '"  id="e-' + result.ID + '" class="none" data-icon="' + result.icon + '" data-pos="' + result.pos + '" data-monitor="' + result.monitor + '">' +
                                    '                                        <a href="javascript:void(0);">' +
                                    '                                            <span class="name">' + result.eq_name + '</span>' +
                                    '                                            <i class="iconfont icon-check"></i>' +
                                    '                                        </a>' +
                                    '                                    </li>';

                            } else {
                                $('.visval-dislog .plusitem').eq(i).hide();
                                option += '<li data-name="' + result.eq_name + '" data-id="' + result.ID + '"  id="e-' + result.ID + '" data-icon="' + result.icon + '" data-pos="' + result.pos + '" data-monitor="' + result.monitor + '">' +
                                    '                                        <a href="javascript:void(0);">' +
                                    '                                            <span class="name">' + result.eq_name + '</span>' +
                                    '                                            <i class="iconfont icon-check"></i>' +
                                    '                                        </a>' +
                                    '                                    </li>';

                            }
                        });
                        var option1 = '<li data-name="请选择设备" data-id="" id="e-00" class="selected" data-icon="" data-pos="%,%" data-monitor="">' +
                            ' <a href="javascript:void(0);">' +
                            ' <span class="name">请选择设备</span>' +
                            ' <i class="iconfont icon-check"></i>' +
                            ' </a>' +
                            ' </li>';
                        $('#room-equip-type .dropdown-content').html(option1 + option);

                    }
                }, 500);

                var arrBackground = datas.arrBackground;
                if (arrBackground != '') {
                    var img = '';
                    $.each(arrBackground, function (im, resultimg) {
                        img += '<label for="l-' + im + '" class="choose-redio choose-3d-thumb">' +
                            '                            <img src="' + resultimg.url + '" class="thumb" alt="">' +
                            '                            <span> <i class="iconfont icon-redio omara-middle"></i><em class="omara-middle">3D图#' + resultimg.ID + '</em></span>' +
                            '                            <input type="radio" name="radio" value="l-' + im + '" class="none redio-child" id="l-' + im + '">' +
                            '                        </label>';

                    });
                    $('.view-room-thumb .body').html(img);
                }

                var arrIcon = datas.arrIcon;
                if (arrIcon != '') {
                    var arricon = '';
                    $.each(arrIcon, function (im, resulticon) {
                        arricon += '<div class="room-equip-icon">' +
                            '                            <img src="' + resulticon.url + '" class="icon" alt="">' +
                            '                        </div>';

                    });
                    $('.view-room-icon .body').html(arricon);

                }
                omara_func.select_checked({select: '.room-name', parameter: id})

            },
            error: function () {

            }
        });
    };
    if ($('.omara-room-index').length > 0) {
        room_equip_list1({id: $('.list-info-value').attr('data-id'), time: 100});
        // room_equip_list2({id: $('.list-info-value').attr('data-id')});
        window.onload = function () {
            $('.svg-embed').each(function (e) {
                var embed = $(this);
                console.log(embed);
                // var d = embed.getSVGDocument();
                // var svg = d.querySelector('svg');
                // console.log(svg);
            });
        }
        setInterval(function () {
            room_equip_list1({id: $('.list-info-value').attr('data-id'), time: 100});
        }, 150000);
    }
    /**柱状图显示*/

    var chart_gragh_interval = function (o) {
        var sn = $('#omara-chart-graph').attr('data-eq_sn');
        var re_sn = sn.replace(/'/g, '"');
        var eq_no = $('#omara-chart-graph').attr('data-eq_no');
        var re_eq_no = eq_no.replace(/'/g, '"');
        var type = $('#omara-chart-graph').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        var id = $('#omara-chart-graph').attr('data-id');

        omara_func.ajax_data({
            url: $('#omara-chart-graph').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"ID","id":"' + id + '",' + re_eq_no + ',' + re_sn + ',' + re_type + ',' + o.visible + '}'
            },
            callback: function (data) {
                var charts_graph = omara_func.charts_graph({
                    'id': 'omara-chart-graph',
                    'data': data.data,
                    categories: data.categories
                });
            },
            error: function () {

            }
        });
    };
    if ($('#omara-chart-graph').length > 0) {
        chart_gragh_interval({
            visible: '"visible":""'
        });
        setInterval(function () {
            var visible = '';
            $('.highcharts-data-labels').each(function (i) {
                if (i > 0) {
                    visible += ';';
                }
                if ($(this).attr('visibility') == 'hidden') {
                    visible += 'false';
                } else {
                    visible += 'true';
                }
            });
            chart_gragh_interval({
                visible: '"visible":"' + visible + '"',
            });
        }, 15000);
    }

    /**数据曲线*/
    var data_charts_ajax = function () {
        var dom = $('.list-info-value2');
        var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
        var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
        var type_id = dom.attr('data-type_id').replace(/'/g, '"');
        var spec = dom.attr('data-spec').replace(/'/g, '"');
        var fdate = $('.start-date').val();
        var edate = $('.end-date').val();
        var date_type = $('.query-data-select option:selected').val();
        var monitor = $('.monitor-value option:selected').val();
        var data = omara_func.info_data({form: $('.data-inquire'), type: 'val+name'});
        omara_func.ajax_data({
            url: $('.data-inquire').attr('action'),
            data: {
                a: 'curve',
                info: '{"limits":"' + dom.val() + '","ps":"20","cp":"1",' + eq_no + ',' + spec + "," + sn + ',' + type_id + ',' + data + '}'
            },
            callback: function (data) {
                var ymin = ($('input[name=ymin]').val() == '' ? null : $('input[name=ymin]').val());
                var ymax = ($('input[name=ymax]').val() == '' ? null : $('input[name=ymax]').val());
                var data_charts = omara_func.charts({
                    'dom': 'omara-chart-data-line',
                    'data': data.data,
                    'width': $('#omara-chart-data-line').width(),
                    xtype: "datetime",
                    'type': 'area',
                    'title': '',
                    verticalAlign: 'top',
                    legend: false,
                    backgroundColor: 'transparent',
                    min: ymin,
                    max: ymax
                });
                $('.charts-value').html(data.ext_msg);
                data_charts.hideLoading();
            },
            error: function () {
                var data_charts = omara_func.charts({
                    'dom': 'omara-chart-data-line',
                    'data': [],
                    'width': $('#omara-chart-data-line').width(),
                    xtype: "datetime",
                    'type': 'spline',
                    'title': '',
                    verticalAlign: 'top',
                    legend: false,
                    backgroundColor: 'transparent',
                    min: null, max: null
                });
                data_charts.hideLoading();
                $('.charts-value').html('');
            }
        });
    };
    if ($('#omara-chart-data-line').length > 0) {
        data_charts_ajax();

        $('.omara-data-inquire').on('click', function () {
            var that = $(this);
            omara_func.proccess({dom: that});
            data_charts_ajax();
        });
    }
    ;
    $('.query-data-select').on('change', function () {
        if ($(this).children('option:selected').text() == '自定义') {
            $('.query-data-box').removeClass('hidden');
        } else {
            $('.query-data-box').addClass('hidden');
        }
    });
    /**当前状态*/
    $(document).on('click', '.omara-new-status .items', function () {
        $(this).find('.icon-checkb').toggleClass('selected');
        $('.' + $(this).attr('data-type')).toggle();
    });
    var eq_html_status = function (o) {
        var type = ['', 'dial3', 'meter', 'kaiguan2', 'door'];
        var typeval = o.type;
        var current_value = o.current_value == '' ? 0 : o.current_value;
        var istatus = '';
        var istatus_value = o.istatus;
        var icon = '';
        var html = '';
        if (typeval == '02' || typeval == '03' || typeval == '04' || typeval == '06' || typeval == '08' || typeval == '09') {
            istatus = o.current_value == '0' ? 'omara-warring2' : "oamra-success2";
        } else if (typeval == '01' || typeval == 'ec4') {
            istatus = o.current_value == '1' || o.current_value == '断开' ? 'omara-warring' : "oamra-success2";
        } else {
            istatus = (istatus_value == '正常' ? 'oamra-success2' : 'omara-warring');
        }
        if (typeval == 'dial3' || typeval == 'dial') {
            var height = 0;
            if (o.current_value != '') {
                var num = parseFloat(o.current_value) > 100 ? 70 : ((parseFloat(o.current_value) - 10) < 0 ? 0 : parseFloat(o.current_value) - 10);
                var left = (o.value.toLowerCase() == 'hum') ? 'width:9px;left:17px;bottom: 52px;height:' : 'left:17px;bottom: 50px;height:';
                height = left + (typeof parseFloat(o.current_value) == 'string' ? 0 : ((150 / 70) * num).toFixed(2));
            } else {
                height = 0;
            }
            var img = (o.value.toLowerCase() == 'hum') ? '/static/images/dial-rh.png' : '/static/images/dial-c.png';
            icon = '<div class="dial-box">' +
                '<div class="unit">&nbsp;' + o.spec + '</div>' +
                '                    <div class="thumb-cur' + ((o.value.toLowerCase() == 'hum') ? '2' : '') + '" style="' + height + 'px;"></div>' +
                '                    <img src="' + img + '" class="thumb" alt="">' +
                '                </div>';
        } else if (typeval == 'meter') {
            icon = '<div class="term-t" id="term-t-' + o.num + '" data-max="' + o.max + '" data-min="' + o.min + '" data-value="' + o.current_value + '" data-spec="' + o.spec + '" data-name="' + o.name + '" data-num="' + o.num + '" style="width: 200px; height: 130px;"></div>';
        } else if (typeval == 'kaiguan2' || typeval == 'ec') {
            icon = '<i class="iconfont ' + istatus + ' icon-' + typeval + '" title="' + o.name + '"></i>';
        } else if (typeval == 'door') {
            icon = '<i class="iconfont ' + istatus + ' icon-' + typeval + '" title="' + o.name + '"></i>';
        } else if (typeval == '26') {
            icon = '<div class="term-tpie" id="term-t-pie' + o.num + '" data-max="' + o.max + '" data-value="' + o.current_value + '" data-spec="' + o.spec + '" data-name="' + o.name + '" data-num="' + o.num + '" style="width:200px; height:125px;"></div>';
        } else if (typeval != '') {
            var icon_val = typeval;
            if (typeval == '15') {
                icon_val = '30';
            } else if (typeval == '16') {
                icon_val = '29';
            }
            icon = '<i class="iconfont ' + istatus + ' icon-' + icon_val + '" title="' + o.name + '"></i>';
        } else if (typeval == ('undefined' || '')) {
            return;
        }
        if (typeval != '') {
            html = '<div class="items" title="当前状态：' + o.istatus + '">' +
                icon +
                '                <p class="' + istatus + '" style="' + (typeval == 'meter' ? 'margin-top:0;' : '') + '"><span>' + o.typename + ':' + o.current_value + (o.spec.indexOf('|') > 0 ? o.spec.substring(0, o.spec.indexOf('|')) : o.spec) + '</span><br/><a href="javascript:void (0);" class="iconfont icon-chart history-chart-toggle omara-displayblock" data-value="' + o.value + '" data-history="' + o.history + '"></a></p>' +
                '            </div>';
        }

        return html;
    };
    var omara_equipment_status = function () {
        var dom = $('.list-info-value');
        var ps = 20;
        var id = dom.attr('data-id');
        var eq_sn = dom.attr('data-eq_sn');
        var re_eq_sn = eq_sn.replace(/'/g, '"');
        var eq_no = dom.attr('data-eq_no');
        var re_eq_no = eq_no.replace(/'/g, '"');
        var type = dom.attr('data-type');
        var re_type = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"' + dom.val() + '","ps":"' + ps + '","cp":"' + 1 + '","id":"' + id + '",' + re_eq_sn + ',' + re_eq_no + ',' + re_type + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var item = '';
                var eq_html = '';
                var count = 0;
                $.each(datas, function (i, result) {
                    var unit = (result.unit.indexOf("|") != -1 ? result.unit.substring(0, result.unit.indexOf('|')) : result.unit);
                    var istatus = result.istatus == '正常' ? '' : ' omara-warring';
                    item += '<p class="items" data-type="type-' + i + '"><i class="icon-checkb selected"></i><span>' + result.alert_item_value + '</span></p>';
                    html += '<tr class="type-' + i + istatus + '">' +
                        '                            <td width="33%">' + result.alert_item_value + '</td>' +
                        '                            <td width="33%">' + result.current_value + unit + '</td>' +
                        '                            <td class="omara-textcenter">' + result.istatus + '</td>' +
                        '                        </tr>';

                });
                if (typeof data.figure != 'undefined') {
                    $.each(data.figure, function (e, eresult) {
                        if (eresult.type != '') {
                            count++;
                        }
                        var range = eresult.value_range.substring(eresult.value_range.indexOf('-') + 1, eresult.value_range.length);
                        var range2 = eresult.value_range.indexOf('-') > 0 ? eresult.value_range.substring(0, eresult.value_range.indexOf('-')) : 0;
                        eq_html += eq_html_status({
                            type: eresult.type,
                            num: e,
                            value: eresult.value,
                            current_value: eresult.current_value,
                            min: range2,
                            max: range,
                            istatus: eresult.istatus,
                            name: eresult.name,
                            spec: eresult.unit,
                            history: eresult.history,
                            typename: eresult.name
                        });
                    });
                }

                $('.omara-data-list tbody').html(html);
                $('.omara-new-status .dowmmenu').html(item);
                $('.omara-equipment-status').html(eq_html).addClass((count > 3 ? 'left' : 'center'));
                setTimeout(function () {
                    $('.term-t').each(function () {
                        var thatc = $(this);
                        var arr = new Array();
                        var d = thatc.attr('data-value') == '故障' || thatc.attr('data-value') == '' ? 0 : parseFloat(thatc.attr('data-value'));
                        arr[0] = d;
                        var minv = parseFloat(thatc.attr('data-min')),
                            maxv = (d > parseFloat(thatc.attr('data-max')) ? d : parseFloat(thatc.attr('data-max')));
                        var spec = thatc.attr('data-spec');
                        var spec1 = (spec.indexOf("|") != -1 ? spec.substring(0, spec.indexOf('|')) : spec);
                        var spec2 = (spec.indexOf("|") != -1 ? spec.substring(spec.lastIndexOf('|') + 1, spec.length) : '');
                        omara_func.charts_gauge({
                            id: 'term-t-' + thatc.attr('data-num'),
                            spec1: spec1,
                            spec2: spec2,
                            name: thatc.attr('data-name'),
                            max: maxv,
                            min: 0,
                            data: arr,
                            band: []
                        });
                    });
                    $('.term-tpie').each(function () {
                        var thatc = $(this);
                        var d = thatc.attr('data-value') == '故障' || thatc.attr('data-value') == '' ? 0 : parseFloat(thatc.attr('data-value'));
                        d = (isNaN(d)) ? 0 : d;
                        var color = '#E1E6DF';
                        if (d <= 60) {
                            color = '#00FF00';
                        } else if (d > 60 && d <= 80) {
                            color = '#FFE100';
                        } else if (d > 80) {
                            color = '#FF0000';
                        }
                        omara_func.charts_pieequip({
                            id: 'term-t-pie' + $(this).attr('data-num'),
                            text: d + $(this).attr('data-spec'),
                            y1: d,
                            y2: 100 - d,
                            color: color
                        });
                    });

                });
            },
            error: function () {
                $('.omara-data-list tbody').html('');
            }
        });
    };
    if ($('.omara-equipment-status').length > 0) {
        omara_equipment_status();
        setInterval(function () {
            omara_equipment_status();
        }, 15000);
        /*告警解除*/
        $('.alert-relieve-submit').on('click', function () {
            var that = $(this);
            omara_func.dialog_confirm({
                show_text: '确认解除告警吗？',
                dialog_id: 'relieve-confirm'
            });
            omara_func.proccess({dom: that});
        });
        $(document).on('click', "#relieve-confirm .btn-confirm", function () {
            var aid = $('.alert-relieve-submit').attr('data-aid');
            omara_func.ajax_data({
                url: $('.alert-relieve-submit').attr('data-relieve_url'),
                data: {a: 'relieve', info: '{"aid":"' + aid + '"}'},
                callback: function (data) {
                    omara_func.refresh_page({time: 1000});
                },
                error: function () {
                }
            });
            $('.dialog-confirm').remove();
        });
    }

    $(document).on('click', '.history-chart-toggle', function () {
        $('.omara-tabs-history .tabs-items').eq(0).addClass('active').siblings().removeClass('active');
        var that = $(this);
        var thisc = $('.omara-art-dialog');
        thisc.attr('data-value', that.attr('data-value'));
        var chart_type = $('.omara-tabs-history .tabs-items').eq(0).attr('data-chart-type');
        var re_chart_type = chart_type.replace(/'/g, '"');
        if (that.attr('data-history') == 'true') {
            $('.omara-art-dialog').show();
            omara_func.ajax_data({
                url: thisc.attr('data-url'),
                data: {
                    a: 'chart',
                    info: '{"id":"' + thisc.attr('data-id') + '","field_name":"' + that.attr('data-value') + '",' + re_chart_type + '}'
                },
                callback: function (data) {
                    var datas = data.data;
                    var charts_w = datas.chart;
                    var length = 0;
                    var width = $('#history-chart-line').width();
                    $.each(charts_w, function (i, li) {
                        if (li.data.length == 0) {
                            length++;
                        }
                    });
                    if (length > 0) {
                        charts_w = '';
                    }

                    var statistics_chart_line = omara_func.charts({
                        'dom': 'history-chart-line',
                        'data': charts_w,
                        'width': width,
                        'type': 'spline',
                        xtype: "datetime",
                        'title': '',
                        verticalAlign: 'top',
                        legend: false,
                        backgroundColor: 'transparent'
                    });
                    statistics_chart_line.hideLoading();
                },
                error: function () {
                }
            });
        } else {
            omara_func.dialog_tips({show_text: '无历史曲线', show_time: 2000});
        }

    });
    $('.omara-tabs-history .tabs-items').on('click', function () {
        var that = $(this);
        var thisc = $('.omara-art-dialog');
        var chart_type = that.attr('data-chart-type');
        var re_chart_type = chart_type.replace(/'/g, '"');
        $(this).addClass('active').siblings().removeClass('active');
        omara_func.ajax_data({
            url: thisc.attr('data-url'),
            data: {
                a: 'chart',
                info: '{"id":"' + thisc.attr('data-id') + '","field_name":"' + thisc.attr('data-value') + '",' + re_chart_type + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var charts_w = datas.chart;
                var length = 0;
                var width = $('#history-chart-line').width();
                $.each(charts_w, function (i, li) {
                    if (li.data.length == 0) {
                        length++;
                    }
                });
                if (length > 0) {
                    charts_w = '';
                }
                var statistics_chart_line = omara_func.charts({
                    'dom': 'history-chart-line',
                    'data': charts_w,
                    'width': width,
                    'type': 'spline',
                    xtype: "datetime",
                    'title': '',
                    verticalAlign: 'top',
                    legend: false,
                    backgroundColor: 'transparent'
                });
                statistics_chart_line.hideLoading();

            },
            error: function () {
            }
        });
    });

    /**参数设置*/
    if ($('.omara-args-save').length > 0) {
        var dom = $('.list-info-value');
        var ps = 20;
        var id = dom.attr('data-id');
        var eq_sn = dom.attr('data-eq_sn');
        var re_eq_sn = eq_sn.replace(/'/g, '"');
        var eq_no = dom.attr('data-eq_no');
        var re_eq_no = eq_no.replace(/'/g, '"');
        var type = dom.attr('data-type');
        var re_type = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"' + dom.val() + '","ps":"' + ps + '","cp":"' + 1 + '","id":"' + id + '",' + re_eq_sn + ',' + re_eq_no + ',' + re_type + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var minval = '';
                var maxval = '';
                var is_alert = '';
                var alert_delay = '';
                var alert_interval = '';
                var xor_value = '';
                $.each(datas, function (i, result) {
                    var arrAlertRules = result.arrAlertRules;
                    var inputhtml = '';
                    var vtype = result.alert_item_value_type;
                    if (arrAlertRules != '') {
                        minval = arrAlertRules.min_value;
                        maxval = arrAlertRules.max_value;
                        is_alert = arrAlertRules.is_alert;
                        alert_delay = arrAlertRules.alert_delay;
                        alert_interval = arrAlertRules.alert_interval;
                        xor_value = arrAlertRules.xor_value;
                    } else {
                        xor_value = '';
                        minval = '';
                        maxval = '';
                        is_alert = '0';
                    }
                    switch (vtype) {
                        case '0':
                            inputhtml = '<input type="number" name="arg-input-min" size="10" class="input-text arg-input-min min_value" value="' + minval + '">' +
                                '<span class="omara-mleft-10">~</span>' +
                                '<input type="number" size="10" class="input-text arg-input-max omara-mleft-10 max_value" value="' + maxval + '">';
                            break;
                        case '1':
                            inputhtml = '<span>~</span>' +
                                '<input type="number" name="arg-input-min" size="10" class="input-text arg-input-min min_value omara-mleft-10" value="' + minval + '">' +
                                '<input type="number" size="10" class="input-text arg-input-max omara-mleft-30 max_value" value="' + maxval + '">' +
                                '<span class="omara-mleft-10">~</span>';
                            break;
                        case '2':
                            inputhtml = '<span>~</span>' +
                                '<input type="number" name="arg-input-min" size="10" class="input-text arg-input-min min_value omara-mleft-10" value="' + minval + '">';
                            break;
                        case '3':
                            inputhtml = '<input type="number" size="10" class="input-text arg-input-max omara-mleft-20 max_value" value="' + maxval + '">' +
                                '<span class="omara-mleft-10">~</span>';
                            break;
                        case '4':
                            inputhtml = '<input type="text" size="10" class="input-text arg-input-max xor_value" value="' + xor_value + '">';
                            break;
                    }
                    html += '<tr data-type="' + vtype + '" data-alert_item="' + result.alert_item + '">' +
                        '                            <td width="20%" >' + result.alert_item_value + '</td>' +
                        '                            <td width="30%" class="omara-textcenter">' + inputhtml + '</td>' +
                        '                            <td class="omara-textcenter">' +
                        '                                <label class="switch-checkbox omara-mleft-10 switch-checkbox-min ' + (is_alert == '1' ? 'selected' : '') + '" for="switch-shelves-' + i + '">' +
                        '                                    <div class="switch-label"></div>' +
                        '                                    <input type="checkbox" value="' + result.ID + '" class="hidden switch-checkbox" ' + (is_alert == '1' ? 'checked' : '') + ' id="switch-shelves-' + i + '" >' +
                        '                                </label>' +
                        '                            </td>' +
                        '                        </tr>';

                });
                $('.omara-data-list tbody').html(html);
                $('.arg-warning-delay').val(alert_delay);
                $('.arg-warning-interval').val(alert_interval);
            },
            error: function () {
                $('.omara-data-list tbody').html('');
                $('.omara-page').html('');
            }
        });
    }
    $('.omara-args-save').on('click', function () {
        $('.omara-data-list').find('.arg-input-min,.arg-input-max').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        omara_func.is_validity({
            dom: '.arg-warning-delay',
            reg: !omara_func.reg.is_number($('.arg-warning-delay').val()),
            reglength: true,
            length: 20
        });
        omara_func.is_validity({
            dom: '.arg-warning-interval',
            reg: !omara_func.reg.is_number($('.arg-warning-interval').val()),
            reglength: true,
            length: 20
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
            $('.regerr').eq(0).focus();
            omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
            return false;
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return false;
        } else {
            var dom = $('.list-info-value');
            var id = dom.attr('data-id');
            var eq_sn = dom.attr('data-eq_sn');
            var re_eq_sn = eq_sn.replace(/'/g, '"');
            var eq_no = dom.attr('data-eq_no');
            var re_eq_no = eq_no.replace(/'/g, '"');
            var data = '';
            $('.omara-data-list tbody tr').each(function (i) {
                var thistr = $(this);
                var min_value = '';
                var max_value = '';
                var xor_value = '';
                var is_alert = thistr.find('.switch-checkbox').is(':checked') ? 1 : 0;
                var type = thistr.attr('data-type');
                switch (type) {
                    case '0':
                        min_value = thistr.find('.min_value').val();
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '1':
                        min_value = thistr.find('.min_value').val();
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '2':
                        min_value = thistr.find('.min_value').val();
                        break;
                    case '3':
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '4':
                        xor_value = thistr.find('.xor_value').val();
                        break;
                }
                if (i > 0) {
                    data += ',';
                }

                data += '{"alert_item":"' + thistr.attr('data-alert_item') + '","min_value":"' + min_value + '","max_value":"' + max_value + '","xor_value":"' + xor_value + '","vtype":"' + type + '","alert_delay":"' + $('.arg-warning-delay').val() + '","alert_interval":"' + $('.arg-warning-interval').val() + '","is_alert":"' + is_alert + '"}';
            });
            omara_func.ajax_data({
                url: $('.list-info-value').attr('data-url'),
                data: {
                    a: 'parameter',
                    info: '{"id":"' + id + '","revise_all":"' + ($('.revise_all option:selected').val()) + '","data":[' + data + ']}'
                },
                callback: function (data) {
                },
                error: function () {

                }
            });
        }
    });
    $('.args-set').on('click', function () {
        $('.args-dialog').show();
    });
    $('.args-dialog .default-dialog-close').on('click', function () {
        $('.args-dialog').hide();
    });
    $('.args-select-val').on('change', function (i) {
        var that = $(this);
        var type = that.children('option:selected').text();
        if (type == '无') {
            that.siblings('.args-box').addClass('hidden');
        } else if (type == '范围内') {
            that.siblings('.args-box').removeClass('hidden');
            that.siblings('.args-box').find('.symbol').hide();
            that.siblings('.args-box').find('.symbol-2,.input-text').show();
        } else if (type == '范围外') {
            that.siblings('.args-box').removeClass('hidden');
            that.siblings('.args-box').find('.symbol').hide();
            that.siblings('.args-box').find('.symbol-1,.symbol-3,.input-text').show();
        } else if (type == '小于小值') {
            that.siblings('.args-box').removeClass('hidden');
            that.siblings('.args-box').find('.symbol,.arg-input-max').hide();
            that.siblings('.args-box').find('.symbol-1,.arg-input-min').show();
        } else if (type == '大于大值') {
            that.siblings('.args-box').removeClass('hidden');
            that.siblings('.args-box').find('.symbol,.arg-input-min').hide();
            that.siblings('.args-box').find('.symbol-3,.arg-input-max').show();
        } else if (type == '通路监测') {
            that.siblings('.args-box').removeClass('hidden');
            that.siblings('.args-box').find('.symbol,.arg-input-min').hide();
            that.siblings('.args-box').find('.arg-input-max').show();
        }

    });
    $('.args-set-save').on('click', function () {
        $('.args-dialog').find('.arg-input-min,.arg-input-max').each(function () {
            var thatc = $(this);
            if (thatc.is(':visible')) {
                omara_func.is_validity_mul({
                    dom: thatc, reg: !omara_func.reg.is_number(thatc.val()), reglength: true,
                    length: 20
                });
            }

        });
        omara_func.is_validity({
            dom: '.args-dialog .arg-warning-delay',
            reg: !omara_func.reg.is_number($('.args-dialog .arg-warning-delay').val()),
            reglength: true,
            length: 20
        });
        omara_func.is_validity({
            dom: '.args-dialog .arg-warning-interval',
            reg: !omara_func.reg.is_number($('.args-dialog .arg-warning-interval').val()),
            reglength: true,
            length: 20
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
            $('.regerr').eq(0).focus();
            omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
            return false;
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return false;
        } else {
            var dom = $('.list-info-value');
            var id = dom.attr('data-id');
            var eq_sn = dom.attr('data-eq_sn');
            var re_eq_sn = eq_sn.replace(/'/g, '"');
            var eq_no = dom.attr('data-eq_no');
            var re_eq_no = eq_no.replace(/'/g, '"');
            var datas = '';
            $('.args-dialog .input-box').each(function (i) {
                var thistr = $(this);
                var min_value = '';
                var max_value = '';
                var xor_value = '';
                var is_alert = thistr.find('.switch-checkbox').is(':checked') ? 1 : 0;
                var type = thistr.find('.args-select-val option:selected').val();
                switch (type) {
                    case '0':
                        min_value = thistr.find('.min_value').val();
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '1':
                        min_value = thistr.find('.min_value').val();
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '2':
                        min_value = thistr.find('.min_value').val();
                        break;
                    case '3':
                        max_value = thistr.find('.max_value').val();
                        break;
                    case '4':
                        xor_value = thistr.find('.max_value').val();
                        break;
                }
                if (i > 0) {
                    datas += ',';
                }


                datas += '{"alert_item":"' + thistr.attr('data-alert_item') + '","min_value":"' + min_value + '","max_value":"' + max_value + '","xor_value":"' + xor_value + '","vtype":"' + type + '","alert_delay":"' + $('.args-dialog .arg-warning-delay').val() + '","alert_interval":"' + $('.args-dialog .arg-warning-interval').val() + '","is_alert":"' + is_alert + '"}';
            });

            omara_func.ajax_data({
                url: $('.args-form').attr('action'),
                data: {a: 'parameter2', info: '{"id":"' + id + '","data":[' + datas + ']}'},
                callback: function (data) {
                    omara_func.refresh_page({time: 1000});
                },
                error: function () {

                }
            });
        }
    });

    /**设备控制*/
    var send_control_command = function (val) {
        var dom = $('.list-info-value');
        var id = dom.attr('data-id');
        var eq_sn = dom.attr('data-eq_sn');
        var re_eq_sn = eq_sn.replace(/'/g, '"');
        var eq_no = dom.attr('data-eq_no');
        var re_eq_no = eq_no.replace(/'/g, '"');
        var type = dom.attr('data-type');
        var re_type = type.replace(/'/g, '"');
        var variable = false;
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"' + dom.val() + '","id":"' + id + '",' + re_eq_sn + ',' + re_eq_no + ',' + re_type + '}'
            },
            callback: function (data) {
                var data = data.data;
                var html = '';
                var btn = '';
                $.each(data, function (i, result) {
                    if (result.control_type == 'onoff') {
                        var checked = result.default_value;
                        var seledted = checked == '1' ? 'selected' : '';
                        var other = '';
                        if (result.variable == 'ictrl' && checked == '1') {
                            variable = true;
                        }
                        if (result.variable != 'ictrl') {
                            other = 'switch-checkbox-other';
                        }
                        var checked2 = (result.variable != 'ictrl' && variable) ? 'disabled' : '';
                        html += '<div class="omara-monitor-con omara-textcenter" data-type="' + result.control_type + '" data-name="' + result.variable + '">' +
                            '            <span class="omara-middle width100 omara-displayline omara-textright">' + result.title + '：</span>' +
                            '            <label class="switch-checkbox omara-mleft-10 ' + seledted + '" for="switch-shelves-' + i + '">' +
                            '                <div class="switch-label"></div>' +
                            '                <input type="checkbox" name="' + result.variable + '" value="' + checked + '" ' + checked2 + ' class="hidden switch-checkbox ' + other + '" id="switch-shelves-' + i + '">' +
                            '            </label>' +
                            '        </div>'
                    } else if (result.control_type == 'processbar') {
                        var range = result.default_value;
                        var val = result.value_range;
                        var range_max = val.substring(val.indexOf(',') + 1, val.length);
                        var min_value = val.substring(0, val.indexOf(','));
                        var checked = variable ? 'true' : 'false';
                        html += '<div class="omara-monitor-con omara-textcenter" data-type="' + result.control_type + '" data-name="' + result.variable + '">' +
                            '            <span class="omara-middle width100 omara-displayline omara-textright">' + result.title + '：</span>' +
                            '            <div class="omara-range omara-displayline omara-middle" data-type="' + result.variable + '" id="omara-range' + i + '" data-id="' + i + '" data-min="' + min_value + '" data-range="' + range + '" data-max="' + range_max + '">' +
                            '                <div class="range-handle" id="range-handle' + i + '" style="left: 0;" data-name="' + result.variable + '" data-disabled="' + checked + '"></div>' +
                            '                <div class="range-body" id="range-body' + i + '" style="width: 0;"></div>' +
                            '            </div>' +
                            '           <div class="omara-displayline omara-middle textval" style="width: 120px;overflow: hidden;">' +
                            '               <span class="omara-range-text omara-range-value omara-middle omara-mleft-10">' + range + '</span>' +
                            '               <span class="omara-range-text omara-middle">' + result.unit + '</span>' +
                            '           </div>' +
                            '        </div>';
                    } else if (result.control_type == 'radiogroup') {
                        var redio = result.value_range.split(',');
                        var rhtml = '';
                        $.each(redio, function (r, val) {
                            var selected = result.default_value == val ? ' selected' : '';
                            var checked = result.default_value == val ? 'checked' : '';
                            var checked2 = variable ? 'disabled' : '';
                            rhtml += '<label for="radiogroup' + i + '-' + r + '" class="choose-redio omara-mleft-30' + selected + '">' +
                                '<i class="iconfont icon-redio omara-middle"></i>' +
                                '<span class="omara-middle">' + val + '</span>' +
                                '<input type="radio" value="' + val + '" name="' + result.variable + '" id="radiogroup' + i + '-' + r + '" class="redio-child none" ' + checked + ' ' + checked2 + ' name="radiogroup">' +
                                '</label>';
                        });
                        html += '<div class="omara-monitor-con omara-textcenter" data-type="' + result.control_type + '" data-name="' + result.variable + '">' +
                            '            <span class="omara-middle width100 omara-displayline omara-textright">' + result.title + '：</span>' +
                            '            <div class="radiogroup omara-displayline omara-textleft" style="width: 397px;">' +
                            rhtml +
                            '            </div>' +
                            '        </div>';
                    } else if (result.control_type == 'checkgroup') {
                        var checkbox = result.value_range.split(',');
                        var checkbox_selectedval = result.default_value.split(',');
                        var chtml = '';
                        $.each(checkbox, function (cc, val) {
                            $.each(checkbox_selectedval, function (c, cval) {
                                var selected = cval == val ? ' selected' : '';
                                var checked = cval == val ? 'checked' : '';
                                var checked2 = variable ? 'disabled' : '';
                                chtml += '<label for="checkbox-' + i + '-' + cc + '" class="choose-checkbox pu-left checkbox-block omara-mleft-30 ' + selected + '">' +
                                    '   <i class="iconfont icon-checkbox"></i>' +
                                    '<span>' + val + '</span>' +
                                    '<input type="checkbox" name="' + result.variable + '" value="' + val + '" id="checkbox-' + i + '-' + cc + '" ' + checked + ' ' + checked2 + ' class="checkbox-child none">' +
                                    '</label>';
                            });
                        });
                        html += ' <div class="omara-monitor-con omara-textcenter" data-type="' + result.control_type + '" data-name="' + result.variable + '">' +
                            '            <span class="omara-middle width100 omara-displayline omara-textright">' + result.title + '：</span>' +
                            '            <div class="omara-middle checkgroup omara-displayline omara-textleft" style="width: 397px;">' +
                            chtml +
                            '            </div>' +
                            '        </div>';
                    } else if (result.control_type == 'button') {
                        btn = '<div class="omara-monitor-con omara-textcenter">' +
                            '<div class="btn-submit monitor-submit omara-displayline">' +
                            '                <span class="btn-shadow2"></span>' +
                            '                <span class="text">操&nbsp;&nbsp;作</span>' +
                            '            </div>'
                        '</div>';
                    }
                });

                $('.omara-content-box').append(html + btn);
                setTimeout(function () {
                    $('.omara-range').each(function (i) {
                        var thatc = $(this);
                        var index = thatc.attr('data-id');
                        new scale('range-handle' + index, 'omara-range' + index, 'range-body' + index, $('#omara-range' + index).attr('data-range'), $('#omara-range' + index).attr('data-min'));
                    });
                    $('.omara-monitor-con').show();
                }, 100);

            },
            error: function () {

            }
        });
    };
    var send_btn_control = function (o) {
        var dom = $('.list-info-value');
        var id = dom.attr('data-id');
        var val = ',"operation":"' + o.name + '"';
        $('.omara-monitor-con').each(function (i) {
            var thatc = $(this);
            var name = thatc.attr('data-name');
            switch (thatc.attr('data-type')) {
                case 'onoff':
                    var onoff = thatc.find('label.switch-checkbox').hasClass('selected') ? 1 : 0;
                    val += ',"' + name + '":"' + onoff + '"';
                    break;
                case 'processbar':
                    val += ',"' + name + '":"' + thatc.find('.omara-range-value').text() + '"';
                    break;
                case 'radiogroup':
                    val += ',"' + name + '":"' + thatc.find('.redio-child').val() + '"';
                    break;
                case 'checkgroup':
                    var c_val = '';
                    thatc.find('.checkbox-child:checked').each(function (c) {
                        if (c > 0) {
                            c_val += ',';
                        }
                        c_val += $(this).val();
                    });
                    val += ',"' + name + '":"' + c_val + '"';
                    break;
            }
        });
        var info = '{"id":"' + id + '"' + val + '}';
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-control_url'),
            data: {
                a: 'list',
                info: info
            },
            callback: function (data) {

            },
            error: function () {

            }
        });
    };
    if ($('.device_control').length > 0) {
        send_control_command('');
        $(document).on('click', 'input.switch-checkbox', function () {
            var that = $(this);
            var checked = that.parent().hasClass('selected');
            if (that.attr('name') == 'ictrl') {
                $('.range-handle').attr('data-disabled', checked);
                $('.omara-monitor-con').find('input[type=radio],.checkbox-child,.switch-checkbox-other').prop('disabled', checked);
            }
            if ($('.monitor-submit').length < 1) {
                send_btn_control({name: $(this).attr('name')});
            }
        });
        $(document).on('click', '.redio-child', function () {
            if ($('.monitor-submit').length < 1) {
                send_btn_control({name: $(this).attr('name')});
            }
        });
        $(document).on('click', '.checkbox-child', function () {
            if ($('.monitor-submit').length < 1) {
                send_btn_control({name: $(this).attr('name')});
            }
        });
        $(document).on('click', '.monitor-submit', function () {
            send_btn_control({name: ''});
        });
    }
    scale = function (btn, bar, step, addnum, min) {
        this.btn = document.getElementById(btn);
        this.bar = document.getElementById(bar);
        this.step = document.getElementById(step);
        this.min = parseInt(min);
        this.num = (parseInt(addnum) < this.min ? parseInt(addnum) : parseInt(addnum) - this.min);
        this.max = parseFloat(this.bar.getAttribute('data-max')).toFixed(2) - this.min;
        this.init();
    };
    scale.prototype = {
        init: function () {
            var f = this, g = document, b = window, m = Math;
            var num = this.num / f.bar.getAttribute('data-max');
            f.step.style.width = num * (f.bar.offsetWidth - 8) + 'px';
            f.btn.style.left = num * (f.bar.offsetWidth - 8) + 'px';
            f.btn.onmousedown = function (e) {
                var x = (e || b.event).clientX;
                var l = this.offsetLeft;
                var max = f.bar.offsetWidth - this.offsetWidth;
                console.log(e.target.dataset.disabled);
                if (e.target.dataset.disabled != 'true') {
                    g.onmousemove = function (e) {


                        var thisX = (e || b.event).clientX;
                        var to = m.min(max, m.max(-2, l + (thisX - x)));
                        f.btn.style.left = to + 'px';
                        f.ondrag(m.round(m.max(0, to / max) * f.max), to);
                        b.getSelection ? b.getSelection().removeAllRanges() : g.selection.empty();
                    }
                    g.onmouseup = new Function('this.onmousemove=null');
                }
                ;

            };
            f.btn.onmouseup = function (e) {
                if (e.target.dataset.disabled != 'true' && $('.monitor-submit').length < 1) {
                    send_btn_control({name: e.target.dataset.name});
                }
            }
        },
        ondrag: function (pos, x) {
            var val = this.min;
            this.step.style.width = Math.max(0, x) + 'px';
            $('#' + this.bar.id).siblings('.textval').find('.omara-range-value').text(pos + val);
        }
    };


    /**确认告警信息*/
    $('.omara-confirm-alarm').on('click', function () {
        var that = $(this);
        if ($('.checkbox-child:checked').length > 0) {
            var id = '';
            $('.checkbox-child:checked').each(function (i) {
                if (i > 0) {
                    id += ',';
                }
                id += $(this).val();
            });
            omara_func.dialog_confirm({
                show_text: '确认已选择的告警信息吗？',
                dialog_id: 'alert-confirm'
            });
            omara_func.proccess({dom: that});
        } else {
            omara_func.dialog_tips({show_text: '请选择操作记录', show_time: 2000});
        }
    });
    $('.all-confirm').on('click', function () {
        var that = $(this);
        omara_func.dialog_confirm({
            show_text: '确定确认全部告警信息吗？',
            dialog_id: 'all-alert-confirm'
        });
        omara_func.proccess({dom: that});
    });

    /*!点击确定按钮 进行功能操作*/
    $(document).on('click', "#alert-confirm .btn-confirm", function () {
        var id = '';
        $('.checkbox-child:checked').each(function (i) {
            if (i > 0) {
                id += ',';
            }
            id += $(this).val();
        });
        omara_func.ajax_data({
            url: $('.data-inquire').attr('action'),
            data: {a: 'confirm', info: '{"id":"' + id + '"}'},
            callback: function (data) {
                $('.checkbox-child:checked').each(function (i) {
                    $(this).parent().remove();
                    var tr = $('#tr-' + $(this).val());
                    $('#tr-span' + $(this).val()).text('已确认').removeClass('omara-warring');
                    tr.removeClass('omara-warring');
                });
            },
            error: function () {
            }
        });
        $('.dialog-confirm').remove();
    });
    $(document).on('click', "#all-alert-confirm .btn-confirm", function () {
        omara_func.ajax_data({
            url: $('.all-confirm').attr('data-url'),
            data: {a: 'allConfirm', info: '{}'},
            callback: function (data) {
                $('.checkbox-child').each(function (i) {
                    $(this).parent().remove();
                    var tr = $('#tr-' + $(this).val());
                    $('#tr-span' + $(this).val()).text('已确认').removeClass('omara-warring');
                    tr.removeClass('omara-warring');
                });
            },
            error: function () {
            }
        });
        $('.dialog-confirm').remove();
    });

    /**可视化设置*/
    $(document).on('click', '.omara-room-set', function () {
        /*可视化设置弹窗显示*/
        $('.visval-dislog').show();
        $('#room-equip-type .dropdown-toggle .name').text('请选择设备');
        $('#room-equip-type .dropdown-content li').removeClass('selected');
        if ($('.omara-sys-groupadd').length > 0) {
            /*我的分组页需要手动修改ID，获取某一机房信息*/
            $('.list-info-value').attr('data-id', $(this).attr('data-id'));
            room_equip_list2({id: $(this).attr('data-id')});
        } else {
            room_equip_list2({id: $('.list-info-value').attr('data-id')});
        }
    });
    $('.room-name').on('change', function () {
        /*可视化设置-机房切换*/
        room_equip_list2({id: $(this).children('option:selected').val()});

    });

    $('.dialog-close').on('click', function () {
        /*可视化设置弹窗隐藏*/
        $('.visval-dislog').hide();
        $('#room-equip-type .dropdown-toggle .name').text('请选择设备');
        $('#room-equip-type .dropdown-content li').removeClass('selected');
    });
    $("#omara-up-bg").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.isup_img(that.val()),
            errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
        });
        if (!that.hasClass('err')) {
            omara_func.update_ajaxform({
                dom: '.visval-dislog .set-form',
                updom: 'omara-up-bg',
                url: that.attr('data-post'),
                callback: function (data) {
                    var imgdom = $('.view-room-thumb .body');
                    var html = '<label for="l-c-' + imgdom.children().length + '" class="choose-redio choose-3d-thumb">                            ' +
                        '<img src="' + data + '" class="thumb" alt="">' +
                        '<span> ' +
                        '<i class="iconfont icon-redio omara-middle"></i>' +
                        '<em class="omara-middle">3D图</em>' +
                        '</span>                            ' +
                        '<input type="radio" name="radio" value="l-c' + imgdom.children().length + '" class="none redio-child" id="l-c-' + imgdom.children().length + '">' +
                        '</label>';
                    imgdom.append(html);
                    $('.data-room-thumb').val(data);
                    $('.visval-dislog .room-3d-thumb').attr('src', data);
                }
            });
        }
    });
    $("#omara-up-icon").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.isup_img(that.val()),
            errtypemsg: '图片格式有误，仅支持jpg,png,gif,svg格式的图片'
        });
        if (!that.hasClass('err')) {
            omara_func.update_ajaxform({
                dom: '.visval-dislog .set-form',
                updom: 'omara-up-icon',
                url: that.attr('data-post'),
                callback: function (data) {
                    var imgdom = $('.view-room-icon .body');
                    var html = '<div class="room-equip-icon">' +
                        '                            <img src="' + data + '" class="icon" alt="">' +
                        '                        </div>';
                    imgdom.append(html);
                }
            });
        }
    });
    $('.omara-browse-dialog').on('click', function () {
        /*浏览弹窗显示*/
        $('#room-equip-type .dropdown-content li').removeClass('selected');
        $('#room-equip-type .dropdown-toggle .name').text('请选择设备');
        $('.' + $(this).attr('data-class')).show().toggleClass('active').siblings('.dialog-visval-box').removeClass('active').hide();
    });
    $('.view-room-close').on('click', function () {
        /*浏览弹窗隐藏*/
        $('#room-equip-type .dropdown-content li').removeClass('selected');
        $('#room-equip-type .dropdown-toggle .name').text('请选择设备');
        $('.dialog-visval-box.active').hide().toggleClass('active');
    });
    $(document).on('click', '.choose-3d-thumb', function () {
        /*浏览背景选择图片*/
        $('.visval-dislog .room-3d-thumb').attr('src', $(this).find('.thumb').attr('src'));
        $('.data-room-thumb').val($(this).find('.thumb').attr('src'));
    });
    if ($('.equipment-drag').length > 0) {
        /*拖动*/
        $('.equipment-drag').find('.room-icon,.plusitem').draggable({containment: "parent", offset: true});
        $('.equipment-drag .plusitem').on('click', function () {
            $(this).toggleClass('selected');
        });
    }
    $('.remove-visval-equip').on('click', function () {
        /*删除已选设备*/
        if ($('.visval-dislog .plusitem.selected').length > 0) {
            $('#room-equip-type .dropdown-content li').each(function () {
                var option = $(this);
                $('.visval-dislog .plusitem.selected').each(function () {
                    var plusitem = $(this);
                    if (option.attr('data-id') == plusitem.attr('data-id')) {
                        option.show();
                    }
                });
            });
            $('.visval-dislog .plusitem.selected').removeClass('selected').css({'left': 0, top: 0}).hide();
        } else {
            omara_func.dialog_tips({show_text: '请选择需要删除的设备', show_time: 2000});
        }
    });
    $('.remove-plus-all').on('click', function () {
        $('#room-equip-type .dropdown-content li').each(function () {
            var option = $(this);
            $('.visval-dislog .plusitem.already-plus').each(function () {
                var plusitem = $(this);
                if (option.attr('data-id') == plusitem.attr('data-id')) {
                    option.show();
                }
            });
        });
        /*清空设备*/
        omara_func.dialog_confirm({
            show_text: '确定清空所有设备吗？',
            dialog_id: 'delete-equip-all'
        });
    });
    /*!点击确定按钮 清空设备*/
    $(document).on('click', "#delete-equip-all .btn-confirm", function () {
        $('.visval-dislog .plusitem.already-plus').removeClass('selected').hide().css({left: 0, top: 0});
        $('.dialog-confirm').remove();
    });
    $('.add-attr').on('click', function () {
        $(this).parent().before(additem(36, 'omara-mleft-20', 57, '', '', 'omara-mtop-20'));
    });
    $("#up-icon").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.isup_img(that.val()),
            errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
        });
        if (!that.hasClass('err')) {
            omara_func.update_ajaxform({
                dom: '.visval-dislog .set-form',
                updom: 'up-icon',
                url: that.attr('data-post'),
                callback: function (data) {
                    $('#up-icon-detail').val(data);
                    $('.omara-map-thumb').css({'background-image': 'url("' + data + '")'});
                }
            });
        }
    });
    $(document).on('click', '#room-equip-type li', function () {
        $('#room-equip-type .dropdown-toggle .name').text($(this).attr('data-name'));
    });
    $('.visval-save').on('click', function () {
        /*保存设备*/
        var that = $(this);
        var equip = $('#room-equip-type .dropdown-content .selected');
        if (equip.length < 1 || equip.attr('data-name') == '请选择设备') {
            omara_func.dialog_tips({show_text: '请选择设备', show_time: 1000});
        } else {
            var monitor = equip.attr('data-monitor') != '' ? equip.attr('data-monitor').split(',') : '';
            var html = equip_html({icon: equip.attr('data-icon'), url: 'javascript:void(0);', monitor: monitor});
            if ($('#up-icon-detail').val() != '') {
                $('#already-plus' + equip.attr('data-id'))
                    .attr('data-icon', $('#up-icon-detail').val())
                    .find('.upsicon').attr('style', 'background-image:url(' + host + $('#up-icon-detail').val() + ');');
            }
            $('#already-plus' + equip.attr('data-id')).show();
            $('#up-icon-detail').val('');
            $('.omara-map-thumb').removeAttr('style');
            equip.hide().removeClass('selected');
            $('#room-equip-type .dropdown-toggle .name').text('请选择设备');
        }
        $('.dialog-visval-box.active').hide().toggleClass('active');
    });
    $('.room-visval-save').on('click', function () {
        /*保存可视化内容*/
        var that = $(this);
        omara_func.proccess({dom: that});
        var equipent = '';
        var imgdom = $('.visval-room-body.equipment-profile');
        var img = $('.visval-room-body .equipment-thumb');
        var equip = $('.visval-dislog .plusitem.already-plus');
        var Px = imgdom.width() / 2;
        var Py = imgdom.height() / 2;
        var Ix = img.width() / 2;
        var Iy = img.height() / 2;
        var roomid = $('.room-name option:selected').val();
        for (var e = 0; e < equip.length; e++) {
            if (e != 0) {
                equipent += ',';
            }
            var Ex = parseFloat(equip.eq(e).css('left'));
            var Ey = parseFloat(equip.eq(e).css('top'));
            var top = (equip.eq(e).css('top') == '0px' || equip.eq(e).css('top') == '0') ? '%' : ((Iy - Ey) / Iy).toFixed(5);
            var left = (equip.eq(e).css('left') == '0px' || equip.eq(e).css('left') == '0') ? '%' : ((Ex - Px) / Ix).toFixed(5);
            equipent += '{"ID":"' + equip.eq(e).attr('data-id') + '","icon":"' + equip.eq(e).attr('data-icon') + '","pos":"' + left + ',' + top + '"' + '}';
        }
        ;
        omara_func.ajax_data({
            url: $('.visval-dislog .set-form').attr('action'),
            data: {
                a: 'save',
                info: '{"id":"' + roomid + '' + '","3dmap":"' + img.attr('src') + '","equips":[' + equipent + ']}'
            },
            callback: function (data) {
                var datas = data.data[0];
                $('.visval-dislog').hide();
                omara_func.refresh_page({time: 200});
            },
            error: function () {

            }
        });
    });

    /**系统分组  列表*/
    var group_list = function (o) {
        var data = $('.list-info-value').val();
        var ps = o.ps;
        var url = location.href;
        var id = url.substring(url.indexOf('=') + 1, url.length);
        var type = $('.list-info-value').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.list-info-value').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"' + data + '","ps":"' + ps + '","cp":"' + o.page + '","id":"' + id + '",' + re_type + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var html = '';
                $.each(datas, function (i, result) {
                    var status = result.istatus.istatus != '正常' || result.istatus == '未知' ? 'omara-warring' : '';
                    var status_val = result.istatus.istatus || result.istatus;
                    var trhtml = '';

                    if (typeof result.monitor_arr != "undefined") {
                        $.each(result.monitor_arr, function (a, res) {
                            trhtml += '<tr>';
                            $.each(res, function (t, tes) {
                                trhtml += '<td width="15%" class="' + (tes == '' ? 'noborder' : '') + '">' + tes + '</td>';
                            });
                            trhtml += '</tr>';
                        });
                    }

                    html += '<tr class="tr-click-link ' + status + '" data-link="' + result.url + '"  data-blank="'+result.blank+'">' +
                        '                    <td class="omara-textcenter" width="100">'+ result.ID + '</td>' +
                        '                    <td width="10%">' + result.eq_name + '</td>' +
                        '                    <td width="10%">' + result.name + '</td>' +
                        '                    <td>' +
                        '<table class="omara-list-data-status">' +
                        '            <tbody>' +
                        trhtml +
                        '            </tbody>' +
                        '        </table>' +
                        '</td>' +
                        ' <td width="100">' + status_val + '</td>' +
                        '</tr>';

                });
                var page = omara_func.page_list({total: data.total, ps: ps, page: o.page});
                $('.omara-data-list tbody').html(html);
                $('.omara-page').html(page);
            },
            error: function () {
                $('.omara-data-list tbody').html('');
                $('.omara-page').html('');
            }
        });
    };
    if ($('.sys-group-device').length > 0) {
        group_list({page: 1, ps: 20});
        $('.omara-data-list').css({minHeight: ($(window).height() - 120) + 'px'});
        $('#switch-relay').on('click', function () {
            /*一键控制*/
            var that = $(this);
            var type_id = that.attr('data-type_id');
            var re_type = type_id.replace(/'/g, '"');
            var value = !that.parent().hasClass('selected') ? 1 : 0;
            omara_func.ajax_data({
                url: that.attr('data-url'),
                data: {a: 'anynet', info: '{"' + that.attr('name') + '":"' + value + '",' + re_type + '}'},
                callback: function (data) {
                },
                error: function () {
                }
            });
        });
    }
    $(document).on('click', '.tr-click-link', function () {
        var link=$(this).attr('data-link');
        if (link != 'javascript:void (0);' && (typeof  $(this).attr('data-blank')=='undefined')) {
            location.href = link;
        }
        if(link != 'javascript:void (0);'){
            if($(this).attr('data-blank')=='true'){
                window.open(link,'_blank','');
            }else{
                location.href = link;
            }

        }
    });
    /* 监控中心* end* */


    /*统计分析 start*/
    /**能耗分析*/
    if ($('.omara-statistics-inquire').length > 0) {
        /*能耗*/
        var that = $('.omara-statistics-box');
        var data = that.val();
        var type = that.attr('data-type');
        var re_type = type.replace(/'/g, '"');
        var dataarr = [];
        var width = $('.omara-statistics-box').width() - 30;
        var statistics_chart_line = omara_func.charts({
            'dom': 'statistics-chart-line',
            'data': dataarr,
            xtype: "datetime",
            'width': width,
            'type': 'spline',
            'title': '',
            verticalAlign: 'top',
            legend: false,
            backgroundColor: 'transparent'
        });
        var statistics_chart_bar = omara_func.charts({
            'dom': 'statistics-chart-bar',
            'data': dataarr,
            'width': width,
            'type': 'column',
            'title': '',
            xtype: "category",
            verticalAlign: 'top',
            legend: true,
            backgroundColor: 'transparent'

        });
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'list', info: '{' + re_type + '}'},
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var charts_w = datas.chart,
                    width = $('.omara-statistics-box').width() - 30;
                var length = 0;
                $.each(datas.li, function (i, li) {
                    html += '<span>' + li.name + '：' + li.current_value + '</span>';
                });

                $('.item-list').html(html);
                $('.omara-statistics-box .title').html(datas.now.name + '：' + datas.now.current_value);

            },
            error: function () {
            }
        });
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'list', info: '{"dispose_type":"chart"}'},
            callback: function (data) {
                var datas = data.data;
                var charts_w = datas.chart;
                var length = 0;
                $.each(charts_w, function (i, li) {
                    if (li.data.length == 0) {
                        length++;
                    }
                });
                if (length == 0) {
                    statistics_chart_line = omara_func.charts({
                        'dom': 'statistics-chart-line',
                        'data': charts_w,
                        xtype: "datetime",
                        'width': width,
                        'type': 'spline',
                        'title': '',
                        verticalAlign: 'top',
                        legend: false,
                        backgroundColor: 'transparent'
                    });
                    setTimeout(function () {
                        statistics_chart_line.hideLoading();
                    }, 1000);
                }
            },
            error: function () {
                statistics_chart_line = omara_func.charts({
                    'dom': 'statistics-chart-line',
                    'data': dataarr,
                    'width': width,
                    'type': 'spline',
                    xtype: "datetime",
                    'title': '',
                    verticalAlign: 'top',
                    legend: false,
                    backgroundColor: 'transparent'
                });
                statistics_chart_line.hideLoading();
            }
        });
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'list', info: '{"dispose_type":"ring"}'},
            callback: function (data) {
                var column = data.data;
                var length = 0;
                $.each(column, function (i, li) {
                    if (li.data.length == 0) {
                        length++;
                    }
                });
                if (length == 0) {
                    statistics_chart_bar = omara_func.charts({
                        'dom': 'statistics-chart-bar',
                        'data': column,
                        'width': width,
                        'type': 'column',
                        'title': '',
                        xtype: "category",
                        verticalAlign: 'top',
                        legend: true,
                        backgroundColor: 'transparent'

                    });
                    setTimeout(function () {
                        statistics_chart_bar.hideLoading();
                    }, 1000);
                }
            },
            error: function () {
                statistics_chart_bar.hideLoading();
                statistics_chart_bar = omara_func.charts({
                    'dom': 'statistics-chart-bar',
                    'data': dataarr,
                    'width': width,
                    'type': 'column',
                    'title': '',
                    xtype: "category",
                    verticalAlign: 'top',
                    legend: true,
                    backgroundColor: 'transparent'
                });
            }
        });
        $('.omara-tabs-line .tabs-items').on('click', function () {
            var thisc = $('.omara-statistics-box');
            var chart_type = $(this).attr('data-chart-type');
            var re_chart_type = chart_type.replace(/'/g, '"');
            var type = thisc.attr('data-type');
            var re_type = type.replace(/'/g, '"');
            $(this).addClass('active').siblings().removeClass('active');
            statistics_chart_line.showLoading();
            omara_func.ajax_data({
                url: thisc.attr('data-url'),
                data: {a: 'list', info: '{"dispose_type":"chart",' + re_chart_type + '}'},
                callback: function (data) {
                    var datas = data.data;
                    var charts_w = datas.chart,
                        width = $('.omara-statistics-box').width() - 30;
                    var length = 0;

                    $.each(charts_w, function (i, li) {
                        if (li.data.length == 0) {
                            length++;
                        }
                    });
                    if (length > 0) {
                        charts_w = '';
                    }
                    statistics_chart_line = omara_func.charts({
                        'dom': 'statistics-chart-line',
                        'data': charts_w,
                        'width': width,
                        'type': 'spline',
                        xtype: "datetime",
                        'title': '',
                        verticalAlign: 'top',
                        legend: false,
                        backgroundColor: 'transparent'
                    });
                    setTimeout(function () {
                        statistics_chart_line.hideLoading();
                    }, 1000);
                },
                error: function () {
                    statistics_chart_line = omara_func.charts({
                        'dom': 'statistics-chart-line',
                        'data': dataarr,
                        'width': width,
                        'type': 'spline',
                        xtype: "datetime",
                        'title': '',
                        verticalAlign: 'top',
                        legend: false,
                        backgroundColor: 'transparent'
                    });
                    statistics_chart_line.hideLoading();
                }
            });
        });
        $('.omara-tabs-ring .tabs-items').on('click', function () {
            var thisc = $('.omara-statistics-box');
            var chart_type = $(this).attr('data-chart-type');
            var re_chart_type = chart_type.replace(/'/g, '"');
            $(this).addClass('active').siblings().removeClass('active');
            statistics_chart_bar.showLoading();
            omara_func.ajax_data({
                url: thisc.attr('data-url'),
                data: {a: 'list', info: '{' + re_chart_type + ',"dispose_type":"ring"}'},
                callback: function (data) {
                    var datas = data.data;
                    var column = datas,
                        width = $('.omara-statistics-box').width() - 30;
                    var length = 0;

                    $.each(column, function (i, li) {
                        if (li.data.length == 0) {
                            length++;
                        }
                    });
                    if (length > 0) {
                        column = '';
                    }

                    statistics_chart_bar = omara_func.charts({
                        'dom': 'statistics-chart-bar',
                        'data': column,
                        'width': width,
                        'type': 'column',
                        xtype: "category",
                        'title': '',
                        verticalAlign: 'top',
                        legend: true,
                        backgroundColor: 'transparent'
                    });
                    setTimeout(function () {
                        statistics_chart_bar.hideLoading();
                    }, 1000);

                },
                error: function () {
                    statistics_chart_bar = omara_func.charts({
                        'dom': 'statistics-chart-bar',
                        'data': dataarr,
                        'width': width,
                        'type': 'column',
                        xtype: "category",
                        'title': '',
                        verticalAlign: 'top',
                        legend: true,
                        backgroundColor: 'transparent'
                    });
                    statistics_chart_bar.hideLoading();
                }
            });
        });
        $('.omara-statistics-inquire').click(function () {
            var data = omara_func.info_data({form: $('.omara-statistics-box').find('input:text'), type: 'val+name'});
            var thisc = $('.omara-statistics-box');
            var chart_type = $('.omara-tabs-line .tabs-items.active').attr('data-chart-type');
            var re_chart_type = chart_type.substring(1, chart_type.indexOf(":") - 1);
            var type = thisc.attr('data-type');
            var re_type = type.replace(/'/g, '"');
            omara_func.ajax_data({
                url: thisc.attr('data-url'),
                data: {a: 'list', info: '{"' + re_chart_type + '":"-1",' + data + ',' + re_type + '}'},
                callback: function (data) {
                    var datas = data.data;
                    var charts_w = datas.chart,
                        width = $('.omara-statistics-box').width() - 30;

                    // var statistics_chart_line =omara_func.charts({
                    //     'dom': 'statistics-chart-line', 'data':  charts_w, 'width': width, xtype:"datetime",'type': 'spline', 'title': '',verticalAlign:'top',legend:false
                    // });
                    // statistics_chart_line.hideLoading();

                },
                error: function () {
                }
            });

        });
    }

    /**机房能耗*/
    var statistics_room_select = function (o) {
        omara_func.ajax_data({
            url: $('.statistics-name').attr('data-groupurl'),
            data: {a: 'energy', info: '{}'},
            callback: function (datas) {
                var option = '';
                var option2 = '';
                $.each(datas.data, function (i, res) {
                    if (i == 0 && (res.arrEnergy != 'null' && res.arrEnergy != null)) {
                        $.each(res.arrEnergy, function (a, resa) {
                            option2 += '<option value="' + resa.name + '">' + resa.name + '</option>';
                        });
                    }
                    option += '<option value="' + res.ID + '" data-energy=\'' + res.energy + '\'>' + res.name + '</option>';
                });

                $('.statistics-name').html(option);
                $('.energy-chart-type').html(option2);
                o.callback();
            },
            error: function () {

            }
        });
    };
    var statistics_pue = function () {
        $('.statistics-pue .txt').text($('.statistics-name option:selected').text());
        omara_func.ajax_data({
            url: $('.statistics-name').attr('data-pueurl'),
            data: {a: 'pue', info: '{"limits":"ID,name","gid":"' + $('.statistics-name option:selected').val() + '"}'},
            callback: function (datas) {
                var data = datas.data;
                $('.skyblueVal span').text(data.pue);
                var color = '';
                var css = $('link').attr('href');
                if (css.indexOf('C') != -1 || css.indexOf('B') != -1) {
                    color = '5E63A3';
                } else {
                    color = '54B5FF';
                }
                if (datas.status == 'OK') {
                    try {
                        var html = '';
                        $.each(data.arrMsg, function (i, res) {
                            html += '<div class="omara-fsize-16">' + res.name + ':' + res.value + (res.unit == null ? '' : res.unit) + '</div>';
                        });
                        $('.energy-text-box').html(html);
                        omara_func.charts_gauge_pue({
                            id: 'statistics-pue',
                            name: 'PUE',
                            valueSuffix: 'PUE',
                            pue: data.pue,
                            y: ($('#statistics-pue').height() - 200) / 2,
                            lineColor: color
                        });
                        omara_func.charts_pie({
                            id: 'statistics-chart-column',
                            datas: data.pie,
                            piename: 'pie',
                            size: '90%'
                        })
                    } catch (e) {

                    }

                }


            },
            error: function () {

            }
        });
    };
    var energyChart = function (o) {
        var chart_index;
        var width = $('.energy-data-chart').width();
        var type = o.type;
        var retype = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.statistics-name').attr('data-pueurl'),
            data: {
                a: 'energyChart',
                info: '{"limits":"","gid":"' + $('.statistics-name option:selected').val() + '","check_name":"' + $('.energy-chart-type option:selected').val() + '",' + retype + '}'
            },
            callback: function (data) {
                var charts_w = data.data;
                chart_index = omara_func.charts({
                    'dom': 'energy-data-chart',
                    'data': charts_w,
                    'width': width,
                    xtype: "datetime",
                    'type': 'spline',
                    'title': '',
                    verticalAlign: 'top',
                    legend: true,
                    backgroundColor: 'transparent'
                });
                chart_index.hideLoading();
            },
            error: function () {
                chart_index = omara_func.charts({
                    'dom': 'energy-data-chart',
                    'data': [],
                    'width': width,
                    xtype: "datetime",
                    'type': 'spline',
                    'title': '',
                    verticalAlign: 'top',
                    legend: true,
                    backgroundColor: 'transparent'
                });
                chart_index.hideLoading();
            }
        });
    };
    if ($('#statistics-pue').length > 0) {
        statistics_room_select({
            callback: function () {
                statistics_pue();
                energyChart({
                    type: $('.omara-tabs-energy-time .active').attr('data-type')
                });
            }
        });

        $(document).on('change', '.statistics-name', function (i) {
            var that = $(this);
            var energy = that.children('option:selected').attr('data-energy');
            var val = (energy != 'null' ? JSON.parse(energy) : []);
            var option = '';

            $.each(val, function (i, res) {
                option += '<option value="' + res.name + '">' + res.name + '</option>';
            });
            $('.energy-chart-type').html(option);
            statistics_pue();
            energyChart({
                type: $('.omara-tabs-energy-time .active').attr('data-type')
            });
        });

        $(document).on('change', '.energy-chart-type', function () {
            var that = $(this);
            energyChart({
                type: $('.omara-tabs-energy-time .active').attr('data-type')
            });
        });
        $('.omara-tabs-energy-time .tabs-items').on('click', function () {
            var that = $(this);
            that.addClass('active').siblings().removeClass('active');
            energyChart({
                type: that.attr('data-type')
            });
        });
        setInterval(function () {
            statistics_pue();
            energyChart({
                type: $('.omara-tabs-energy-time .active').attr('data-type')
            });
        }, 15000);
    }

    /**告警信息、告警查询、操作日志、运行状态等列表*/
    var list_data = function (o) {
        var data = $('.list-info-value').val();
        var ps = o.ps;
        omara_func.ajax_data({
            url: $('.data-inquire').attr('action'),
            data: {
                a: o.gettype,
                info: '{"limits":"' + data + '","ps":"' + ps + '","cp":"' + o.page + '"' + o.parameter + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var html = '';
                var html2 = '';
                var relieve_type = ['', '手动解除', '自动解除'];
                $.each(datas, function (i, result) {
                    switch ($('.omara-inquire').attr('data-name')) {
                        case '告警查询':
                        case '告警信息':
                            var status = result.alert_status != '2' && result.is_confirmed != '1' ? 'omara-warring' : '';
                            var status_val = result.alert_status == '0' && result.is_confirmed != '1' ? '告警' : (result.is_confirmed != '1' ? '故障' : '已确认');
                            var icon = omara_func.alarm_type(result.notify_mode);
                            var relieve_type_val = parseInt(result.relieve_type);
                            html += '<tr id="tr-' + result.ID + '" class="' + status + '">' +
                                '                    <td width="100">' +
                                (result.is_confirmed != '1' ?
                                    '                        <label for="checkbox-' + result.ID + '" class="choose-checkbox omara-middle omara-displayline">' +
                                    '                            <i class="iconfont icon-checkbox"></i>' +
                                    '                            <input type="checkbox" value="' + result.ID + '" id="checkbox-' + result.ID + '" class="checkbox-child none">' +
                                    '                        </label>' : '') +
                                '<span class="omara-middle omara-mleft-10">' + i + '</span>' +
                                '                    </td>' +
                                '                    <td width="10%">' + result.name + '</td>' +
                                '                    <td width="30%">' + result.eq_name + '</td>' +
                                '                    <td>' + result.alert_item + '</td>' +
                                '                    <td>' + result.alert_value + '</td>' +
                                '                    <td>' + result.pubdate + '</td>' +
                                '                    <td>' +
                                icon +
                                '                    </td>' +
                                '                    <td>' + result.realname + '</td>' +
                                '                    <td width="100">' +
                                '                        <span class="' + status + '" id="tr-span' + result.ID + '">' + status_val + '</span>' +
                                '                    </td>' +
                                '<td>' + relieve_type[relieve_type_val] + '</td>' +
                                '                </tr>';
                            break;
                        case '运行状态':
                            var status = result.istatus != '正常' ? 'omara-warring' : '';
                            var trhtml = '';

                            if (typeof result.monitor_arr != "undefined") {
                                $.each(result.monitor_arr, function (a, res) {
                                    trhtml += '<tr>';
                                    $.each(res, function (t, tes) {
                                        trhtml += '<td width="15%" class="' + (tes == '' ? 'noborder' : '') + '">' + tes + '</td>';
                                    });
                                    trhtml += '</tr>';
                                });
                            }

                            html += '<tr class="tr-click-link ' + status + '" data-link="' + result.url + '">' +
                                '                    <td class="omara-textcenter" width="100"><a href="' + result.url + '" class="' + status + ' width100p omara-displayline link">' + i + '</a></td>' +
                                '                    <td width="10%"><a href="' + result.url + '" class="' + status + ' width100p omara-displayline link">' + result.eq_name + '</a></td>' +
                                '                    <td width="10%"><a href="' + result.url + '"  class="' + status + ' width100p omara-displayline link">' + result.name + '</a></td>' +
                                '                    <td><a href="' + result.url + '"  class="' + status + (trhtml == "" ? ' width100p omara-displayline' : '') + ' link">' +
                                '<table class="omara-list-data-status">' +
                                '            <tbody>' +
                                trhtml +
                                '            </tbody>' +
                                '        </table>' +
                                '</a></td>' +
                                ' <td width="100"><a href="' + result.url + '"  class="' + status + ' width100p omara-displayline link">' + result.istatus + '</a></td>' +
                                '</tr>';
                            break;
                        case '操作日志':
                            html += '<tr>' +
                                '                    <td width="10%">' + result.username + '</td>' +
                                '                    <td width="50%">' + result.content + '</td>' +
                                '                    <td class="omara-textcenter">' + result.pubdate + '</td>' +
                                '                    <td width="150" class="omara-textcenter">' +
                                result.ip +
                                '                    </td>' +
                                '                </tr>';
                            break;
                        case '历史数据':
                            var status = result.istatus != '正常' ? 'omara-warring' : '';
                            var trhtml = '';
                            if ($('.input-select option:selected').text() == '整组') {
                                if (typeof result.alert_item_arr != "undefined") {
                                    $.each(result.alert_item_arr, function (a, res) {
                                        trhtml += '<tr><td>#' + (a + 1) + '</td>';
                                        $.each(res, function (t, tes) {
                                            trhtml += '<td width="30%" class="' + (tes == '' ? 'noborder' : '') + '">' + tes + '</td>';
                                        });
                                        trhtml += '</tr>';
                                    });
                                    trhtml = '<table class="omara-list-data-status">' +
                                        '            <tbody>' +
                                        trhtml +
                                        '            </tbody>' +
                                        '        </table>';
                                }
                            } else {
                                trhtml = result.alert_item_value;
                            }

                            html += '<tr class="' + status + '">' +
                                '                        <td width="10%" class="omara-textcenter">' + $('.input-select option:selected').text() + '</td>' +
                                '                        <td width="60%" class="omara-textcenter">' + trhtml + '</td>' +
                                '                        <td class="omara-textcenter">' + result.pubtime + '</td>' +
                                '                        <td width="100" class="omara-textcenter">' +
                                '                            <span class="' + status + '">' + result.istatus + '</span>' +
                                '                        </td>' +
                                '                    </tr>';
                            break;
                        case '日志':
                            var td = '';
                            $.each(data.table, function (i, result2) {
                                var name = result2.field_name;
                                td += '<td class="omara-textcenter">' + result[name] + '</td>';
                            });
                            html += '<tr>' +
                                td +
                                '                    </tr>';
                            break;
                    }

                });
                var page = omara_func.page_list({total: data.total, ps: ps, page: o.page});
                $('.omara-data-list tbody').html(html);
                $('.omara-page a').remove();
                if ($('.omara-inquire').attr('data-name') == '日志') {
                    $.each(data.table, function (i, result2) {
                        html2 += '<td class="omara-textcenter" data-field_name="' + result2.field_name + '">' + result2.name + '</td>';
                    });
                    $('.omara-data-list thead tr').html(html2);
                }
                if ($('.omara-confirm-alarm').length > 0) {
                    $('.omara-page').append(page);
                } else {
                    $('.omara-page').html(page);
                }
            },
            error: function () {
                $('.omara-data-list tbody').html('');
                if ($('.omara-inquire').attr('data-name') == '告警信息' || $('.omara-inquire').attr('data-name') == '告警查询') {
                    $('.omara-page a').remove();
                } else {
                    $('.omara-page').html('');
                }
            }
        });
    };
    if ($('.omara-inquire').length > 0) {
        switch ($('.omara-inquire').attr('data-name')) {
            case '告警查询':
                list_data({gettype: 'list', page: 1, parameter: '', ps: 20});
                break;
            case '运行状态':
                var dom = $('.omara-tabs-run-status');
                var data = omara_func.info_data({form: $('.data-inquire'), type: 'val+name'});
                list_data({
                    gettype: 'list',
                    page: 1,
                    parameter: ',"' + dom.attr('data-name') + '":"' + dom.children('.active').attr('data-value') + '",' + data,
                    ps: 20
                });
                setInterval(function () {
                    var data2 = omara_func.info_data({form: $('.data-inquire'), type: 'val+name'});
                    list_data({
                        gettype: 'list',
                        page: 1,
                        parameter: ',"' + dom.attr('data-name') + '":"' + dom.children('.active').attr('data-value') + '",' + data2,
                        ps: 20
                    });
                }, 15000);
                break;
            case '操作日志':
                var dom = $('.list-info-value');
                var username = dom.attr('data-username').replace(/'/g, '"');
                list_data({gettype: 'list', page: 1, parameter: ',' + username, ps: 20});
                break;
            case '告警信息':
                var dom = $('.list-info-value');
                var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                list_data({gettype: 'list', page: 1, parameter: ',' + sn + ',' + eq_no, ps: 20});
                setInterval(function () {
                    var data = omara_func.info_data({form: $('.data-inquire').find('input:text'), type: 'val+name'});
                    list_data({gettype: 'list', page: 1, parameter: ',' + sn + ',' + eq_no + ',' + data, ps: 20});
                }, 15000);
                break;
            case '历史数据':
                var dom = $('.list-info-value');
                var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                var spec = dom.attr('data-spec').replace(/'/g, '"');
                list_data({
                    gettype: 'list',
                    page: 1,
                    parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + ',"' + $('.input-select').attr('name') + '":"' + $('.input-select option:selected').val() + '"',
                    ps: 20
                });
                break;
            case '日志':
                var dom = $('.list-info-value');
                var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                var spec = dom.attr('data-spec').replace(/'/g, '"');
                list_data({
                    gettype: 'log',
                    page: 1,
                    parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + '',
                    ps: 20
                });
                break;
        }
        ;
        $('.storage-battery').on('change', function () {
            if ($(this).children('option:selected').text() == '单节') {
                $('.single-storage-battery').show();
            } else {
                $('.single-storage-battery').hide().val('');
            }
        });
    }
    /**信息查询*/
    $('.omara-inquire').click(function () {
        var that = $(this);
        omara_func.is_validity({
            dom: '.start-date',
            reg: !omara_func.reg.is_number($('.start-date').val()),
            reglength: true,
            length: 20
        });
        omara_func.is_validity({
            dom: '.end-date',
            reg: !omara_func.reg.is_number($('.end-date').val()),
            reglength: true,
            length: 20
        });
        if ($('.data-inquire .error').length > 0) {
            $('.data-inquire .error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return;
        } else {
            omara_func.proccess({dom: that});
            var data = omara_func.info_data({form: $('.data-inquire').find('input:text,select'), type: 'val+name'});
            switch ($('.omara-inquire').attr('data-name')) {
                case '告警查询':
                    list_data({gettype: 'list', page: 1, parameter: ',' + data, ps: 20});
                    break;
                case '运行状态':
                    var dom = $('.omara-tabs-run-status');
                    list_data({
                        gettype: 'list',
                        page: 1,
                        parameter: ',"' + dom.attr('data-name') + '":"' + dom.children('.active').attr('data-value') + '",' + data,
                        ps: 20
                    });
                    break;
                case '操作日志':
                    var dom = $('.list-info-value');
                    var username = dom.attr('data-username').replace(/'/g, '"');
                    list_data({gettype: 'list', page: 1, parameter: ',' + username + ',' + data, ps: 20});
                    break;
                case '告警信息':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    list_data({gettype: 'list', page: 1, parameter: ',' + sn + ',' + eq_no + ',' + data, ps: 20});
                    break;
                case '历史数据':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                    var spec = dom.attr('data-spec').replace(/'/g, '"');
                    list_data({
                        gettype: 'list',
                        page: 1,
                        parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + ',' + data,
                        ps: 20
                    });
                    break;
                case '日志':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                    var spec = dom.attr('data-spec').replace(/'/g, '"');
                    list_data({
                        gettype: 'log',
                        page: 1,
                        parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + ',' + data,
                        ps: 20
                    });
                    break;
                case '资产登记':
                    assets_list({
                        ps: 20,
                        page: 1,
                        data: ',' + data
                    });
                    break;
            }
            ;
        }
        $('.export-excel').attr('href', $('.export-excel').attr('data-url') + '&' + $('.data-inquire').serialize());
    });
    $('.omara-tabs-run-status .tabs-items').on('click', function () {
        $(this).addClass('active').siblings().removeClass('active');
        var dom = $('.omara-tabs-run-status');
        var data = omara_func.info_data({form: $('.data-inquire').find('input:text,select'), type: 'val+name'});
        $('.export-excel').attr('href', $('.export-excel').attr('data-url') + '&' + $('.data-inquire').serialize() + "&" + dom.attr('data-name') + '=' + $(this).attr('data-value'));
        list_data({
            gettype: 'list',
            page: 1,
            parameter: ',"' + dom.attr('data-name') + '":"' + dom.children('.active').attr('data-value') + '",' + data,
            ps: 20
        });
    });
    /**页码点击*/
    $(document).on('click', '.omara-page .page-link', function () {
        var that = $(this);
        var data = omara_func.info_data({form: $('.data-inquire').find('input:text,select'), type: 'val+name'});
        if ($('.sys-group-device').length > 0) {
            /*监控中心-系统分组-某一设备列表*/
            group_list({page: that.attr('data-num'), ps: 20});
        } else if ($('.omara-inquire').length > 0) {
            /*统计分析-[告警查询，运行状态]列表*/
            omara_func.proccess({dom: that});
            switch ($('.omara-inquire').attr('data-name')) {
                case '告警查询':
                    list_data({gettype: 'list', page: that.attr('data-num'), parameter: ',' + data, ps: 20});
                case '运行状态':
                    var dom = $('.omara-tabs-run-status');
                    list_data({
                        gettype: 'list',
                        page: that.attr('data-num'),
                        parameter: ',"' + dom.attr('data-name') + '":"' + dom.children('.active').attr('data-value') + '",' + data,
                        ps: 20
                    });
                    break;
                case '操作日志':
                    var dom = $('.list-info-value');
                    var username = dom.attr('data-username').replace(/'/g, '"');
                    list_data({
                        gettype: 'list',
                        page: that.attr('data-num'),
                        parameter: ',' + username + ',' + data,
                        ps: 20
                    });
                    break;
                case '告警信息':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    list_data({
                        gettype: 'list',
                        page: that.attr('data-num'),
                        parameter: ',' + sn + ',' + eq_no + ',' + data,
                        ps: 20
                    });
                    break;
                case '历史数据':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                    var spec = dom.attr('data-spec').replace(/'/g, '"');
                    list_data({
                        gettype: 'list',
                        page: that.attr('data-num'),
                        parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + ',' + data,
                        ps: 20
                    });
                    break;
                case '日志':
                    var dom = $('.list-info-value');
                    var sn = dom.attr('data-eq_sn').replace(/'/g, '"');
                    var eq_no = dom.attr('data-eq_no').replace(/'/g, '"');
                    var type_id = dom.attr('data-type_id').replace(/'/g, '"');
                    var spec = dom.attr('data-spec').replace(/'/g, '"');
                    list_data({
                        gettype: 'log',
                        page: that.attr('data-num'),
                        parameter: ',' + sn + ',' + eq_no + ',' + type_id + ',' + spec + ',' + data,
                        ps: 20
                    });
                    break;
                case '资产登记':
                    assets_list({
                        ps: 20,
                        page: that.attr('data-num'),
                        data: ',' + data
                    });
                    break;
            }
            ;
        } else if ($('.omara-sys-groupadd').length > 0) {
            my_group_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.omara-sys-epsadd').length > 0) {
            equip_type_list({
                page: that.attr('data-num'),
                ps: 20
            })
        } else if ($('.omara-equip-add').length > 0) {
            /*列表获取*/
            sys_equip_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.add-group-permissions').length > 0) {
            group_permissions_list({
                ps: 20,
                page: that.attr('data-num'),
            });
        } else if ($('.omara-sys-admin,.omara-sys-contact').length > 0) {
            /*系统管理员列表*/
            sys_admin_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.omara-sys-room').length > 0) {
            /*机房管理员列表*/
            sys_room_admin_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.omara-alarm-rankadd').length > 0) {
            alarm_rank_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.omara-sys-alarmadd').length > 0) {
            alarm_modal_list({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-assets-type').length > 0) {
            assets_type({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-assets-brand').length > 0) {
            assets_brand({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-storage-location').length > 0) {
            storage_location({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-home-cabinet').length > 0) {
            home_cabinet({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-use-department').length > 0) {
            use_department({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.new-business-attribution').length > 0) {
            business_attribution({
                page: that.attr('data-num'),
                ps: 20
            });
        } else if ($('.asset-record').length > 0) {
            asset_record({
                ps: 20,
                page: that.attr('data-num'),
                data: ''
            });
        } else if ($('.entrance-guard-dialog').length > 0) {
            menjin_list({
                ps: 20,
                page: that.attr('data-num'),
                data:''
            });
        }

    });
    /*统计分析 end*/

    /*资产登记 start*/
    /**资产登记列表*/
    if ($('.qeury-date').length > 0) {
        var date = new Date();
        $.datetimepicker.setLocale('ch');
        $('.qeury-date').val(date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate());
        $('.qeury-date').datetimepicker({
            format: 'Y-m-d', timepicker: false
        });
    }
    $(document).on('change', ".J_selectFile", function () {
        var that = $(this);
        console.log();
        if (that.val() == '') {

        } else if (!omara_func.reg.isup_word(that.val())) {
            omara_func.dialog_tips({show_text: '文件格式有误，仅支持pdf|word|表格三种格式', show_time: 2000});
        } else {
            omara_func.update_ajaxform({
                dom: '#' + that.attr('data-form'),
                updom: that.attr('data-id'),
                url: that.attr('data-post'),
                callback: function (data) {
                    if ($('.asset-record').length > 0) {
                        setTimeout(function () {
                            location.href = location.href;
                        }, 1000);
                    }

                    $(".J_selectFile").val('');
                }
            });
        }
    });
    var assets_list_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '<td>' + result.name + '</td>' +
            '                        <td>' + result.brand_name + '</td>' +
            '                        <td>' + result.model + '</td>' +
            '                        <td>' + result.state_name + '</td>' +
            '                        <td>' + result.location_name + '</td>' +
            '                        <td>' + (result.u_start != '0' ? '√' : '') + '</td>' +
            '                        <td>' + result.cabinet_name + '</td>' +
            '                        <td>' + result.user + '</td>' +
            '                        <td>' + result.business_name + '</td>' +
            '                        <td class="omara-textcenter">' +
            '<form action="' + result.url_amr + '" method="post" class="assets-form omara-displayline omara-middle" id="assets-form-' + result.ID + '">' +
            '<a href="javascript:void (0);" class="file_box icon-toggle omara-middle" title="添加文件">' +
            '                                    <i class="iconfont icon-upfile omara-fsize-24"></i>' +
            '                                    <input type="file" class="input_file choose_file J_selectFile" name="fn[]" id="J_selectFile-' + result.ID + '" data-id="J_selectFile-' + result.ID + '" data-form="assets-form-' + result.ID + '" data-post="/api/Files?a=amr&aid=' + result.ID + '" title="添加文件">' +
            '                                </a>' +
            '</form>' +
            '<a href="' + result.url_record + '" class="iconfont icon-alink omara-mleft-10 omara-middle icon-toggle omara-fsize-22" title="查看"></a>' +
            '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify modify-assets" data-id="' + result.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete assets-delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var assets_list = function (o) {
        omara_func.ajax_data({
            url: $('.omara-data-list').attr('data-url_get'),
            data: {a: 'listAsset', info: '{"limits":"ID","cp":"' + o.page + '","ps":"' + o.ps + '"' + o.data + '}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += assets_list_html({
                            name: result.name,
                            ID: result.ID,
                            index: i,
                            sn: result.sn,
                            state_name: result.state_name,
                            brand_name: result.brand_name,
                            model: result.model,
                            location_name: result.location_name,
                            u_start: result.u_start,
                            cabinet_name: result.cabinet_name,
                            user: result.user,
                            business_name: result.business_name,
                            url_record: result.url_record,
                            url_amr: result.url_amr
                        });
                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
                $('.omara-data-list tbody').html('');
            }
        });
    };
    var asset_record = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'record',
                info: '{"limits":"","cp":"' + o.page + '","ps":"' + o.ps + '","aid":"' + $('.data-form').attr('data-aid') + '"}'
            },
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += '<tr id="tr-' + result.ID + '">' +
                            '                        <td class="omara-textcenter">' + i + '</td>' +
                            '                        <td>' + result.original_name + '</td>' +
                            '                        <td>' + result.ext + '</td>' +
                            '                        <td>' + result.upload_date + '</td>' +
                            '                        <td class="omara-textcenter">' +
                            '<a href="' + result.url + '" class="iconfont icon-toggle omara-middle icon-downfile omara-fsize-24" title="下载"></a>' +
                            '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-mleft-20 omara-fsize-28 icon-delete assets-record-delete-single" data-checkbox-id="checkbox-' + result.ID + '" data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
                            '</td>' +
                            '                    </tr>';
                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
                $('.omara-data-list tbody').html('');
            }
        });
    };
    if ($('.new-assets').length > 0) {
        assets_list({
            ps: 20,
            page: 1,
            data: ''
        });
    }
    if ($('.asset-record').length > 0) {
        asset_record({
            ps: 20,
            page: 1,
            data: ''
        });
    }
    /**资产登记保存*/
    var daysBetween = function (DateOne, DateTwo) {
        var OneMonth = DateOne.substring(5, DateOne.lastIndexOf('-'));
        var OneDay = DateOne.substring(DateOne.length, DateOne.lastIndexOf('-') + 1);
        var OneYear = DateOne.substring(0, DateOne.indexOf('-'));

        var TwoMonth = DateTwo.substring(5, DateTwo.lastIndexOf('-'));
        var TwoDay = DateTwo.substring(DateTwo.length, DateTwo.lastIndexOf('-') + 1);
        var TwoYear = DateTwo.substring(0, DateTwo.indexOf('-'));

        var cha = ((Date.parse(OneMonth + '/' + OneDay + '/' + OneYear) - Date.parse(TwoMonth + '/' + TwoDay + '/' + TwoYear)) / 86400000);
        return Math.abs(cha);
    };
    var getDate = function () {
        var d = new Date();
        var year = d.getFullYear();
        var month = d.getMonth() + 1;
        var day = d.getDate();
        var currentMonth, currentDay;
        if (month >= 10) {
            currentMonth = month;
        } else {
            currentMonth = '0' + month;
        }

        if (day >= 10) {
            currentDay = day;
        } else {
            currentDay = '0' + day;
        }

        var pollTime = year + '-' + currentMonth + '-' + currentDay;
        return pollTime;
    };
    var getNetVal = function () {
        var pollTime = getDate();
        var initiaValue = $('.omara-initial-valuation').val();
        var startTime = $('.omara-initial-date').val();
        var days = daysBetween(pollTime, startTime);
        var salvage = $('.omara-residual-rate').val();
        var years;
        if (days <= 365) {
            years = 0;
        } else {
            years = Math.round((days - 365) / 365);
        }

        var diff = parseFloat(100) - parseFloat(salvage);
        var rateDiff = (diff / 100).toFixed(2); // 四舍五入保留2位小数
        var net_value = initiaValue * Math.pow(rateDiff, years); // Math.pow(x, y) 获得x的y次方
        $('.omara-valuation').val(net_value);
    };
    $('.omara-initial-date,.omara-initial-valuation,.omara-residual-rate').on('blur', function () {
        getNetVal();
    });
    $('.new-assets').on('click', function () {
        $('.omara-valuation').val(0);
        $('.omara-art-dialog .input-select').each(function () {
            $(this).find('option').eq(0).prop("selected", true);
        });
        var date = new Date();
        $('.qeury-date').val(date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate());
        $('.omara-assets-depreciation').val('平均年限法');
    });
    /**编辑资产*/
    $(document).on('click', '.modify-assets', function () {
        var that = $(this);
        var titlebar = $('.omara-art-dialog .titlebar .name');
        $('.omara-art-dialog').show();
        titlebar.text(titlebar.attr('data-art-modify'));
        $('.data-ID').val(that.attr('data-id'));
        var info = '{' +
            '"limits":"id",' +
            '"id":"' + that.attr('data-id') + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.omara-data-list').attr('data-url_get'),
            data: {a: 'listAloneAsset', info: info},
            callback: function (data) {
                var data = data.data;
                $('.omara-assets-name').val(data.name);
                $('.omara-assets-num').val(data.code);
                $('.omara-assets-serial').val(data.sn);
                $('.omara-assets-model').val(data.model);
                $('.omara-assets-supplier').val(data.supplier);
                $('.omara-assets-purchase').val(data.buy_date);
                $('.omara-maintenance-cycle').val(data.maintenance_cycle);
                $('.omara-expire-date').val(data.expire_date);
                $('.omara-originate-U').val(data.u_start);
                $('.omara-occupy-U').val(data.u_num);
                $('.omara-manager').val(data.user);
                $('.omara-initial-date').val(data.start_time);
                $('.omara-earsy-use').val(data.service_life);
                $('.omara-initial-valuation').val(data.initia_value);
                $('.omara-residual-rate').val(data.salvage);
                $('.omara-valuation').val(data.net_value);
                $('.omara-assets-depreciation').val('平均年限法');
                if ($('.omara-assets-status').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-assets-status',
                        parameter: data.state
                    });
                }
                if ($('.omara-assets-type').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-assets-type',
                        parameter: data.type
                    });
                }
                if ($('.omara-assets-brand').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-assets-brand',
                        parameter: data.brand
                    });
                }
                if ($('.omara-storage-location').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-storage-location',
                        parameter: data.location
                    });
                }
                if ($('.omara-home-cabinet').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-home-cabinet',
                        parameter: data.cabinet
                    });
                }
                if ($('.omara-use-department').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-use-department',
                        parameter: data.department
                    });
                }
                if ($('.omara-business-attribution').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-business-attribution',
                        parameter: data.business
                    });
                }

            },
            error: function () {

            }
        });
    });
    $('.assets-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'saveAsset', info: '{' + data + '}'},
                callback: function (data) {
                    var id = $('.data-ID').val();
                    var datas = data.data[0];
                    if (id == '') {
                        var html = assets_list_html({
                            name: datas.name,
                            ID: datas.ID,
                            index: $('.omara-data-list tbody tr').length + 1,
                            sn: datas.sn,
                            state_name: datas.state_name,
                            brand_name: datas.brand_name,
                            model: datas.model,
                            location_name: datas.location_name,
                            u_start: datas.u_start,
                            cabinet_name: datas.cabinet_name,
                            user: datas.user,
                            business_name: datas.business_name,
                            url_record: result.url_record,
                            url_amr: result.url_amr
                        });
                        $('.omara-data-list tbody').append(html);
                    } else {
                        $('#tr-' + id + ' td').eq(1).text(datas.name);
                        $('#tr-' + id + ' td').eq(2).text(datas.brand_name);
                        $('#tr-' + id + ' td').eq(3).text(datas.model);
                        $('#tr-' + id + ' td').eq(4).text(datas.state_name);
                        $('#tr-' + id + ' td').eq(5).text(datas.location_name);
                        $('#tr-' + id + ' td').eq(6).text((datas.u_start != '0' ? '√' : ''));
                        $('#tr-' + id + ' td').eq(7).text(datas.cabinet_name);
                        $('#tr-' + id + ' td').eq(8).text(datas.user);
                        $('#tr-' + id + ' td').eq(9).text(datas.business_name);
                    }

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**资产类型列表*/
    var assets_type_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var assets_type = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,name","cp":"' + o.page + '","ps":"' + o.ps + '","type":"0"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += assets_type_html({
                            name: result.name,
                            ID: result.ID,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-assets-type').length > 0) {
        assets_type({
            ps: 20,
            page: 1
        });
    }


    /**资产类型保存*/
    $('.assets-type-save').on('click', function () {
        var that = $(this);
        var id = $('.data-ID').val();
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = assets_type_html({
                        name: datas.name,
                        ID: datas.ID,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**节点品牌列表*/
    var assets_brand_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var assets_brand = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,name","cp":"' + o.page + '","ps":"' + o.ps + '","type":"1"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += assets_brand_html({
                            name: result.name,
                            ID: result.ID,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-assets-brand').length > 0) {
        assets_brand({
            ps: 20,
            page: 1
        });
    }
    /**节点品牌保存*/
    $('.assets-brand-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = assets_brand_html({
                        name: datas.name,
                        ID: datas.ID,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**存放地点列表*/
    var storage_location_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var storage_location = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,name","cp":"' + o.page + '","ps":"' + o.ps + '","type":"2"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += storage_location_html({
                            name: result.name,
                            ID: result.ID,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-storage-location').length > 0) {
        storage_location({
            ps: 20,
            page: 1
        });
    }
    /**存放地点保存*/
    $('.storage-location-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = assets_brand_html({
                        name: datas.name,
                        ID: datas.ID,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**归属机柜列表*/
    var home_cabinet_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.location_code_name + '</td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td>' + result.cabinet_total_u + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var home_cabinet = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"ID,name,location_code,cabinet_total_u","cp":"' + o.page + '","ps":"' + o.ps + '","type":"3"}'
            },
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += home_cabinet_html({
                            name: result.name,
                            ID: result.ID,
                            location_code_name: result.location_code_name,
                            cabinet_total_u: result.cabinet_total_u,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-home-cabinet').length > 0) {
        home_cabinet({
            ps: 20,
            page: 1
        });
    }

    /**归属机柜保存*/
    $('.home-cabinet-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = home_cabinet_html({
                        name: datas.name,
                        ID: datas.ID,
                        location_code_name: datas.location_code_name,
                        cabinet_total_u: datas.cabinet_total_u,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**使用部门列表*/
    var use_department_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var use_department = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,name","cp":"' + o.page + '","ps":"' + o.ps + '","type":"4"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += use_department_html({
                            name: result.name,
                            ID: result.ID,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-use-department').length > 0) {
        use_department({
            ps: 20,
            page: 1
        });
    }

    /**使用部门保存*/
    $('.use-department-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = assets_brand_html({
                        name: datas.name,
                        ID: datas.ID,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });

    /**业务归属列表*/
    var business_attribution_html = function (result) {
        var html = '<tr id="tr-' + result.ID + '">' +
            '                        <td class="omara-textcenter">' + result.index + '<input type="checkbox" value="' + result.ID + '" name="id" class="none" id="checkbox-' + result.ID + '"></td>' +
            '                        <td>' + result.name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-checkbox-id="checkbox-' + result.ID + '"  data-id="' + result.ID + '" data-pid="tr-' + result.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var business_attribution = function (o) {
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,name","cp":"' + o.page + '","ps":"' + o.ps + '","type":"5"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                if (datas.status == 'OK') {
                    $.each(data, function (i, result) {
                        html += business_attribution_html({
                            name: result.name,
                            ID: result.ID,
                            index: i
                        });

                    });
                }

                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.new-business-attribution').length > 0) {
        business_attribution({
            ps: 20,
            page: 1
        });
    }
    /**业务归属保存*/
    $('.business-attribution-save').on('click', function () {
        var that = $(this);
        $('.dialog-content .input-text[type=text]').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var html = assets_brand_html({
                        name: datas.name,
                        ID: datas.ID,
                        index: $('.omara-data-list tbody tr').length + 1
                    });
                    $('.omara-data-list tbody').append(html);

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });
    /*资产登记 end*/

    /*系统设置 start*/
    /**设备管理*/
    var equip_typehtml = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                            <td class="omara-textcenter" >' + o.number + '</td>' +
            '                            <td width="50%"><a href="' + o.url + '">' + o.type_name + '</a></td>' +
            '                            <td class="omara-textcenter">' + o.equipments_number + '</td>' +
            '                            <td class="omara-textcenter" width="20%">' +
            '                                <a href="' + o.url_setting + '" class="iconfont icon-toggle omara-middle omara-fsize-28 icon-modify sys-eps-modify2" data-id="' + o.ID + '"></a>' +
            '<a href="javascript:void (0);" class="iconfont icon-toggle omara-middle icon-alarm omara-mleft-10 omara-fsize-24 eps-alarm-des-set"data-id="' + o.ID + '" title="告警描述设置" data-type_id="' + o.type_id + '" data-spec="' + o.spec + '"></a>' +
            '                                <a href="javascript:void (0);" class="iconfont icon-toggle omara-middle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-pid="tr-' + o.ID + '"></a>' +
            '                            </td>' +
            '                        </tr>';
        return html;
    };
    var equip_type_list = function (o) {
        var epsadd = omara_func.info_data({form: $('.set-form').find('input:text'), type: 'name'});
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,' + epsadd + '","cp":"' + o.page + '","ps":"' + o.ps + '"}'},
            callback: function (d) {
                var data = d.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += equip_typehtml({
                        ID: result.ID,
                        number: i,
                        type_name: result.type_name,
                        equipments_number: result.equipments_number,
                        url: result.url,
                        url_setting: result.url_setting,
                        type_id: result.type_id,
                        spec: result.spec
                    });
                });
                var page = omara_func.page_list({total: d.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-sys-epsadd').length > 0) {
        equip_type_list({
            page: 1,
            ps: 20
        })
    }
    if ($('.add-epsadd-save').length > 0) {
        var url = location.href;
        var type = omara_func.getQueryVariable('t');
        var id = (omara_func.getQueryVariable('id') == false ? '' : omara_func.getQueryVariable('id'));
        var equit_manage = function (o) {
            var epsadd = omara_func.info_data({
                form: $('.eq-setting.set-form').find('input:text,textarea,input:hidden,select'),
                type: 'name'
            });
            var eid = ',"id":"' + o.id + '"';
            var mtype_id = '';
            var level = ($('.eq-setting.set-form').find('select').length > 0 ? ',' + $('.eq-setting.set-form').find('select').attr('name') : '');
            if (o.type != 'ntype' || o.type != 'etype') {
                mtype_id = o.type_id
            }
            omara_func.ajax_data({
                url: $('.eq-setting.set-form').attr('action'),
                data: {a: o.a, info: '{"limits":"' + epsadd + level + '"' + eid + mtype_id + '}'},
                callback: function (data) {
                    var data = data.data;
                    $('.mdevice_type').show();
                    $('.omara-equip-name').val(data.type_name);
                    $('.omara-equip-pname').val(data.eq_name);
                    $('.omara-equip-number').val(data.eq_no);
                    $('.omara-equip-sn').val(data.eq_sn);
                    $('.omara-equip-typeid').val(data.type_id);
                    $('.type_icon').val(data.type_icon);
                    $('.omara-control-options').val(data.control_opt);
                    $('.omara-equip-spec').val(data.spec);
                    $('.equip-list-box .iconfont').each(function () {
                        if ($(this).attr('data-icon') == data.type_icon) {
                            $(this).addClass('selected').siblings().removeClass('selected');
                        }
                    });

                    $('.choose-redio').removeClass('selected').children('input').prop('checked', false);
                    if (data.is_control == '1') {
                        $('.choose-redio').eq(0).addClass('selected').children('input').prop('checked', true);
                        $('.omara-control-options-box').show();
                        $('.omara-control-options').val(data.control_opt);
                    } else {
                        $('.omara-control-options-box').hide();
                        $('.omara-control-options').val('');
                        $('.choose-redio').eq(1).addClass('selected').children('input').prop('checked', true);
                    }

                    if ($('#alarm-rank').length > 0) {
                        var alarm_list = '';
                        $.each(data.arrAlertLevels, function (i, val) {
                            alarm_list += '<option value="' + val.ID + '" ' + (data.alert_level == val.ID ? 'selected' : '') + '>' + val.level_name + '</option>';
                        });
                        $('#alarm-rank').html(alarm_list);
                    }
                    properties_arr({
                        properties: data.properties,
                        width: 73
                    });

                    var html_tr = '';
                    var arrField = data.arrField;
                    var arrProperties = data.arrProperties;
                    if (arrField != null) {
                        var rname = '';
                        var unit = '';
                        var ratio = '';
                        var field_value_range = '';
                        var monitor_value_type = '';
                        var figure_type = '';
                        var monitor = false;
                        var exhibition = false;
                        var chart = false;
                        var history = false;
                        var statistics = false;
                        var camera_type = '';
                        var eq_log = false;
                        var briefing = false;
                        html_tr = '';
                        $.each(arrField, function (i, val) {
                            if (arrProperties != null) {
                                $.each(arrProperties, function (name, result) {
                                    if (result.field_name == val) {
                                        rname = typeof result.name == "undefined" ? '' : result.name;
                                        unit = typeof result.unit == "undefined" ? '' : result.unit;
                                        ratio = typeof result.ratio == "undefined" ? '' : result.ratio;
                                        field_value_range = typeof result.field_value_range == "undefined" ? '' : result.field_value_range;
                                        monitor_value_type = typeof result.monitor_value_type == "undefined" ? '' : result.monitor_value_type;
                                        figure_type = typeof result.figure_type == "undefined" ? '' : result.figure_type;
                                        monitor = typeof result.monitor == "undefined" ? '' : 'checked';
                                        exhibition = typeof result.exhibition == "undefined" ? '' : 'checked';
                                        chart = typeof result.chart == "undefined" ? '' : 'checked';
                                        history = typeof result.history == "undefined" ? '' : 'checked';
                                        statistics = typeof result.statistics == "undefined" ? '' : 'checked';
                                        camera_type = typeof result.camera_type == "undefined" ? '' : result.camera_type;
                                        eq_log = typeof result.eq_log == "undefined" ? '' : result.eq_log;
                                        briefing = typeof result.briefing == "undefined" ? '' : result.briefing;
                                        return false;
                                    } else {
                                        rname = '';
                                        unit = '';
                                        ratio = '';
                                        field_value_range = '';
                                        monitor_value_type = '';
                                        figure_type = '';
                                        monitor = '';
                                        exhibition = '';
                                        chart = '';
                                        history = '';
                                        statistics = '';
                                        camera_type = '';
                                        eq_log = '';
                                        briefing = '';
                                    }
                                });

                            }
                            html_tr += eps_trhtml({
                                number: i,
                                val: val,
                                rname: rname,
                                unit: unit,
                                ratio: ratio,
                                field_value_range: field_value_range,
                                monitor_value_type: monitor_value_type,
                                figure_type: figure_type,
                                monitor: monitor,
                                exhibition: exhibition,
                                chart: chart,
                                history: history,
                                statistics: statistics,
                                camera_type: camera_type,
                                eq_log: eq_log,
                                briefing: briefing,
                                re_properties: data.properties
                            });
                        });
                    }

                    $('.omara-parameter-setting tbody').html(html_tr);
                },
                error: function () {

                }
            });
        };
        if (type == 'ndevice' || type == 'ntype') {
            $('.eq-setting .data-ID').val('');
            var a = 'list';
            if (type == 'ndevice') {
                var type_id = '';
                a = 'dsetting';
                type_id = ',"type_id":"' + omara_func.getQueryVariable('type_id') + '"';
                equit_manage({
                    id: id,
                    type_id: type_id,
                    type: type,
                    a: a
                });
            } else {
                $('.mdevice_type').hide();
            }

        } else if (type == 'edevice' || type == 'etype') {
            $('.eq-setting .data-ID').val(id);
            var type_id = '';
            var a = 'list';
            if (type == 'edevice') {
                type_id = ',"type_id":"' + omara_func.getQueryVariable('type_id') + '"';
                a = 'dsetting';
            }
            equit_manage({
                id: id,
                type_id: type_id,
                type: type,
                a: a
            });
        }
    }
    $('.equip-list-box .iconfont').on('click', function () {
        $('.type_icon').val($(this).attr('data-icon'));
        $(this).addClass('selected').siblings().removeClass('selected');
    });
    $('.omara-epsauto-generate').on('click', function () {
        var that = $(this);
        var id = (typeof that.attr('data-type_id') != undefined) ? ',"type_id":"' + that.attr('data-type_id') + '"' : '';
        var spec = (typeof that.attr('data-spec') != undefined) ? ',"spec":"' + that.attr('data-spec') + '"' : '';
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: 'scan', info: '{"type":"' + that.attr('data-type') + '"' + id + spec + '}'},
            callback: function (data) {
                var data = data.data;
                var html = '';
                $.each(data, function (i, result) {
                    if ($('.omara-equip-add').length > 0) {
                        html += sys_equip_html({
                            ID: result.ID,
                            number: $('.omara-data-list tbody tr').length + 1 + i,
                            eq_name: result.eq_name,
                            eq_no: result.eq_no,
                            eq_sn: result.eq_sn,
                            name: result.name,
                            level_name: result.level_name,
                            url_setting: result.url_setting
                        });
                    } else {
                        html += equip_typehtml({
                            ID: result.ID,
                            number: $('.omara-data-list tbody tr').length + 1 + i,
                            type_name: result.type_name,
                            equipments_number: result.equipments_number,
                            url: result.url
                        });
                    }
                });
                $('.omara-data-list tbody').append(html);
            },
            error: function () {

            }
        });
    });
    $('.omara-check-equipment').on('click', function () {
        var that = $(this);
        omara_func.ajax_data({
            url: that.attr('data-url'),
            data: {a: '', info: '{}'},
            callback: function (data) {
            },
            error: function () {

            }
        });
    });

    var eps_trhtml = function (o) {
        /*参数列表*/
        var arr = ['范围内', '范围外', '小于小值', '大于大值', '通路监测'];
        var icon = ['dial3', 'meter', 'kaiguan2', 'door', '01', '02', '03', '04', '05', '06', '08', '09', '10', '11', '12', '13', '14', '30', '29', '27', '28', '26'];
        var carame_type = [{name:"无",val:""}, {name:"A3-3078",val:'A3-3078'}, {name:"A3-3079",val:'A3-3079'}, {name:"3803",val:'3803'},{name:"海康视频",val:'haikang-video'}];
        var carame_select = '';
        var select_option = '';
        var li = '';
        var cselcted = '';
        var figure_type = '无';
        var selcted_li = o.figure_type == "" ? 'selected' : '';
        var statistics = o.statistics == 'checked' ? 'selected' : '';
        var monitor = o.monitor == 'checked' ? 'selected' : '';
        var exhibition = o.exhibition == 'checked' ? 'selected' : '';
        var chart = o.chart == 'checked' ? 'selected' : '';
        var history = o.history == 'checked' ? 'selected' : '';
        var eq_log = o.eq_log == true ? 'selected' : '';
        var briefing = o.briefing == true ? 'selected' : '';
        var c_arr = [exhibition, chart, statistics, history, eq_log, briefing];
        var c_arr_name = ['exhibition', 'chart', 'statistics', 'history', 'eq_log', 'briefing'];
        var selcted_li2 = '';
        var checkbox_html = '';
        var selected = '';
        var re_properties = '';
        if (o.figure_type != '') {
            figure_type = '<i class="iconfont omara-middle omara-fsize-28 icon-choose icon-' + o.figure_type + '"></i>'
        } else {
            figure_type = '无'
        }
        $.each(arr, function (i, val) {
            var ii = i.toString();
            if (o.monitor_value_type == ii) {
                selected = 'selected';
            } else {
                selected = '';
            }
            select_option += ' <option value="' + i + '" ' + selected + '>' + val + '</option>';

        });
        $.each(icon, function (i, val) {
            selcted_li2 = '';
            if (o.figure_type == val) {
                selcted_li2 = 'selected';
            } else {
                selcted_li2 = '';
            }
            li += '<li data-name="' + val + '" class="' + selcted_li2 + '">' +
                '    <i class="iconfont omara-middle omara-fsize-28 icon-choose icon-' + val + '"></i>' +
                '    <i class="iconfont omara-middle icon-check"></i>' +
                '</li>';
        });
        $.each(carame_type, function (i, res) {
            if (o.camera_type == res.val) {
                cselcted = 'selected';
            } else {
                cselcted = '';
            }

            carame_select += '<option value="' + res.val + '" ' + cselcted + '>' + res.name + '</option>';
        });
        $.each(c_arr, function (i, val) {
            checkbox_html += '<td class="omara-textcenter">' +
                '    <label for="parameter-setting_' + o.val + '_' + i + '" class="choose-checkbox omara-displayline omara-middle ' + val + '">' +
                '        <i class="iconfont icon-checkbox"></i>' +
                '        <input type="checkbox" value="1" name="' + c_arr_name[i] + '" id="parameter-setting_' + o.val + '_' + i + '" ' + (val == 'selected' ? 'checked' : '') + ' class="checkbox-child none">' +
                '    </label>' +
                '</td>';
        });
        $.each(o.re_properties, function (name, result) {
            if (name.indexOf('re_') != -1 && name.indexOf(o.val) != -1) {
                var res = result.split(';');
                $.each(res, function (i, rval) {
                    var r_rval = rval.split(',');
                    re_properties += '<div class="input-box new-content-box omara-mbotom-10">' +
                        '                                        <input type="text" class="input-text omara-attr-name old-data-attr " style="width: 100px;" placeholder="原始数据" value="' + r_rval[0] + '">\n' +
                        '                                        =>' +
                        '                                        <input type="text" class="input-text omara-attr-value new-data-attr omara-mleft-5" style="width: 100px;" placeholder="替换数据" value="' + r_rval[1] + '">\n' +
                        '                                        <i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle"></i>\n' +
                        '                                    </div>';
                });
            }
        });
        var html = '<tr data-value="' + o.val + '">' +
            '                            <td>' + o.val + '</td>' +
            '                            <td class="omara-textcenter">' +
            '                                <label for="parameter-setting_monitor_avg_' + o.number + '"' +
            '                                       class="choose-checkbox omara-displayline omara-middle ' + monitor + '">' +
            '                                    <i class="iconfont icon-checkbox"></i>' +
            '                                    <input type="checkbox" name="monitor" id="parameter-setting_monitor_avg_' + o.number + '"' +
            '                                           class="checkbox-child none " ' + (monitor == 'selected' ? 'checked' : '') + '>' +
            '                                </label>' +
            '                                <input type="text" name="name" class="input-text name ' + (monitor == 'selected' ? 'omara-displayblock' : 'none') + '" size="3" style="margin: 10px auto 0 auto" placeholder="命名" value="' + o.rname + '">' +
            '                                <input type="text" name="unit" class="input-text unit ' + (monitor == 'selected' ? 'omara-displayblock' : 'none') + '" size="3" style="margin: 10px auto 0 auto" placeholder="单位" value="' + o.unit + '">' +
            '                                <select name="monitor_value_type" class="input-select ' + (monitor == 'selected' ? 'omara-displayblock' : 'none') + '" style="min-width: 50px;max-width: 65px;padding:0;margin: 10px auto 0 auto;">' +
            '                                    <option value="">无</option>' +
            select_option +
            '                                </select>' +
            '                            </td>' +
            '                            <td class="omara-textcenter">' +
            '                                <label for="parameter-setting_charts_avg_' + o.number + '"' +
            '                                       class="choose-checkbox omara-displayline omara-middle ' + (figure_type == '无' ? '' : 'selected') + '">' +
            '                                    <i class="iconfont icon-checkbox"></i>' +
            '                                    <input type="checkbox" value="1" id="parameter-setting_charts_avg_' + o.number + '"' +
            '                                           class="checkbox-child none" ' + (figure_type == '无' ? '' : 'checked') + '>' +
            '                                </label>' +
            '                                <div class="downmenu downbox omara-downmenu drop-down-menu ' + (figure_type == '无' ? 'hidden' : 'omara-displayblock') + ' omara-mtop-10" style="width: 60px;margin: 0 auto;height: 31px;padding: 0 2px;">\n' +
            '                                    <button type="button" class="dropdown-toggle">' +
            '                                       <span class="name omara-middle">' + figure_type + '</span> <span' +
            '                                            class="iconfont icon-arrow-down"></span></button>' +
            '                                    <ul class="dropdown-content" style="min-width: 100px;">' +
            '                                        <li data-name="" class="' + selcted_li + '"><span class="name">无</span> <i' +
            '                                                class="iconfont omara-middle icon-check"></i></li>' +
            li +
            '                                    </ul>' +
            '                                </div>' +
            '                                <input type="text" name="figure_type_range" class="input-text ' + (o.figure_type != 'meter' ? 'hidden' : 'omara-displayblock') + ' omara-mtop-10" size="2" value="' + o.field_value_range + '" name="field_value_range" placeholder="赋值范围" style="margin: 10px auto 0 auto;">' +
            '                            </td>\n' +
            '                            <td class="omara-textcenter">\n' +
            '                                <input type="text" class="input-text" size="2" value="' + o.ratio + '" name="ratio" placeholder="系数">\n' +
            '                            </td>\n' +
            '                            <td class="omara-textcenter">\n' +
            '                                <select class="input-select" name="carame_type" style="min-width: 50px;max-width: 60px;">\n' +
            '                                    <option value="" selected="">无</option>\n' +
            carame_select +
            '                                </select>\n' +
            '                            </td>\n' +
            checkbox_html +
            '                            <td class="omara-textcenter" width="300">\n' +
            '                                <div class="content-attr-box">\n' +
            re_properties +
            '                                    <i class="iconfont icon-add content-attr-attr omara-middle omara-fsize-24"></i>\n' +
            '                                </div>\n' +
            '                            </td>\n' +
            '                        </tr>';
        return html;
    };
    var propertiesExtra_eps = function () {
        /*参数设置列表数值拼接*/
        var properties = '';
        $('.omara-parameter-setting tbody tr').each(function (i) {
            var that_tr = $(this);
            var checkbox = ['monitor', '', 'exhibition', 'chart', 'statistics', 'history', 'eq_log', 'briefing'];
            var name = that_tr.find('.name').val();
            var unit = that_tr.find('.unit').val();
            var ratio = that_tr.find('input[name=ratio]').val();
            var field_value_range = that_tr.find('input[name=figure_type_range]').val();
            var monitor_value_type = that_tr.find('.input-select[name=monitor_value_type] option:selected').val();
            var camera_type = that_tr.find('.input-select[name=carame_type] option:selected').val();
            var figure_type = that_tr.find('.drop-down-menu li.selected').attr('data-name');
            var checkbox_length = that_tr.find('.checkbox-child:checked').length;
            var field_name = that_tr.attr('data-value');
            var checkbox_val = '';
            var input_val = (name || ratio || unit || field_value_range || monitor_value_type || figure_type);

            for (var c = 0; c < that_tr.find('.checkbox-child').length; c++) {
                if (c > 0 && checkbox[c] != '') {
                    checkbox_val += ',';
                }
                if (checkbox[c] != '') {
                    checkbox_val += '"' + checkbox[c] + '":' + that_tr.find('.checkbox-child').eq(c).is(':checked');
                }
            }
            if ((input_val != '' && figure_type != 'undefined') || checkbox_length > 0 || camera_type != '' || monitor_value_type != '' || figure_type != '') {
                properties += '{"field_name":"' + field_name + '","field_value_range":"' + field_value_range + '",' +
                    '"figure_type":"' + figure_type + '","monitor_value_type":"' + monitor_value_type + '",' +
                    '"name":"' + name + '","unit":"' + unit + '","ratio":"' + ratio + '","camera_type":"' + camera_type + '",' + checkbox_val + '},';
            }

        });
        return properties.substring(0, properties.lastIndexOf(','));
    };
    var properties_arr = function (o) {
        var properties = o.properties;
        var item = '';
        var column = '';
        var isInArray = function (arr, value) {
            var index = $.inArray(value, arr);
            console.log(index);
            if (index >= 0) {
                return true;
            }
            return false;
        };
        if (properties != null) {
            var arr = ['monitor', 'exhibition', 'chart', 'statistics', 'history', 'figure', 'coefficient', 'energy_kwh', 'energy_max_kwh', 'energy_min_kwh', 'energy_avg_kwh', 'energy_chart', 'energy_ring', 'camera', 'eq_log', 'briefing', 're_'];
            $.each(properties, function (name, result) {
                if (name != '') {
                    if (name.indexOf('bar_') == -1) {
                        var show = ' none omara-mtop-20';
                        if (name.indexOf('re_') == -1) {
                            show = (isInArray(arr, name) ? ' none omara-mtop-20' : 'omara-mtop-20');
                        }
                        item += additem(52, '', o.width, name, result, show);
                    } else {
                        var bar = result.split(';');
                        column += ' <div class="input-box new-column-box omara-mbotom-10">' +
                            '                            <input type="text" class="input-text column-attr" size="6" placeholder="名称" value="' + bar[0] + '">' +
                            '                            -' +
                            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="前缀" value="' + bar[1] + '">' +
                            '                            -' +
                            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="开始" value="' + bar[2] + '">' +
                            '                            -' +
                            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="结束" value="' + bar[3] + '">' +
                            '                            -' +
                            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="颜色" value="' + bar[4] + '">' +
                            '                            <i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle"></i>' +
                            '                        </div>';

                    }
                }

            });
        }
        $('.add-equip-attr').parent().before(item);
        $('.column-attr-box').prepend(column);
        item = '';
    };
    $('.add-epsadd-save').on('click', function () {
        var that = $(this);
        omara_func.is_validity({
            dom: '.omara-equip-name', reg: false, reglength: true,
            length: 50
        });
        omara_func.is_validity({
            dom: '.omara-equip-typeid', reg: false, reglength: true,
            length: 50
        });
        omara_func.is_validity({
            dom: '.omara-equip-spec', reg: false, reglength: true,
            length: 500
        });
        // omara_func.is_validity({dom: '.omara-control-options', reg: false});
        $('.new-attr').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 500
            });
        });
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.equip-list-box .selected').length < 1 && $('.equip-list-box').length > 0) {
            omara_func.dialog_tips({show_text: '请选择图标', show_time: 2000});
            return false;
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return;
        } else {
            omara_func.proccess({dom: that});
            var id = $('.eq-setting .data-ID').val();
            var equip_attr = '';
            var histogram = '';
            var type_id = (omara_func.getQueryVariable('type_id') == false ? '' : ',"type_id":"' + omara_func.getQueryVariable('type_id') + '"');
            var propertiesExtra = (id == '' && type_id == '' ? '' : ',"propertiesExtra":[' + propertiesExtra_eps() + ']');

            $('.new-attr-box').each(function (i) {
                if (i > 0) {
                    equip_attr += ',';
                }
                equip_attr += '"' + $(this).find('.omara-attr-name').val() + '":"' + $(this).find('.omara-attr-value').val() + '"'
            });
            $('.column-attr-box .new-column-box').each(function (i) {
                if (i > 0) {
                    histogram += ',';
                }
                var val = '';
                $(this).find('.column-attr').each(function (c) {
                    var that = $(this);
                    if (c > 0) {
                        val += ';';
                    }
                    val += that.val();
                });
                histogram += '"' + val + '"';
            });
            var texteara = $('.omara-control-options').val();
            var replace = '';
            $('.omara-parameter-setting tbody tr').each(function (i) {
                var tr = $(this);
                if (tr.find('.new-content-box').length > 0) {
                    var conval = '';
                    if (replace != '') {
                        replace += ',';
                    }

                    tr.find('.new-content-box').each(function (t) {
                        var content = $(this);
                        if (t > 0) {
                            conval += ';';
                        }
                        conval += content.find('.old-data-attr').val() + ',' + content.find('.new-data-attr').val();
                    });
                    replace += '{"field_name":"' + tr.attr('data-value') + '","value":"' + conval + '"}';
                }

            });
            var data = omara_func.info_data({
                form: $('.eq-setting.set-form .input-box').find('input:text,select'),
                type: 'val+name'
            });

            var type_id = (omara_func.getQueryVariable('type_id') == false ? '' : ',"type_id":"' + omara_func.getQueryVariable('type_id') + '"');
            var info = '{' + data + ',"id":"' + id + '"' + propertiesExtra + ',"histogram":[' + histogram + '],"' + $('.new-equip-attr').attr('name') + '":{' + equip_attr + '},"' + $('.omara-control-options').attr('name') + '":' + JSON.stringify(texteara) + type_id + ',"is_control":"' + $('input[name=is_control]:checked').val() + '","replace":[' + replace + ']}';
            omara_func.ajax_data({
                url: $('.eq-setting.set-form').attr('action'),
                data: {a: 'save', info: info},
                callback: function (data) {
                    setTimeout(function () {
                        location.href = data.url;
                    }, 1000);

                },
                error: function () {

                }
            });
        }
    });
    $("#up-data-import").on('change', function () {
        /*设备类型导入*/
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.reg.isup_excel(that.val()),
            errtypemsg: '格式有误，仅支持excel格式的文件'
        });
        if (!that.hasClass('err')) {
            that.before('<img src="/static/images/loading.svg" width="18" class="omara-middle omara-mleft-5"/>');
            omara_func.update_ajaxform({
                dom: '.set-form',
                updom: 'up-data-import',
                url: that.attr('data-post'),
                callback: function (val, data) {
                    that.siblings('img').remove();
                    var datas = data.data;
                    var html = '';
                    $.each(datas, function (i, result) {
                        html += equip_typehtml({
                            ID: result.ID,
                            number: i,
                            type_name: result.type_name,
                            equipments_number: result.equipments_number,
                            url: result.url
                        });
                    });
                    $('.omara-right-box .omara-data-list tbody').html(html);
                }
            });
        }
    });

    var sys_equip_html = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                            <td width="100">' +
            '                               <label for="checkbox-' + o.ID + '" class="choose-checkbox omara-middle omara-displayline">' +
            '                                   <i class="iconfont icon-checkbox"></i>                            ' +
            '                                   <input type="checkbox" value="' + o.ID + '" id="checkbox-' + o.ID + '" class="checkbox-child none">' +
            '                               </label>' +
            '                               <span class="omara-middle omara-mleft-10">' + o.number + '</span>' +
            '                            </td>' +
            '                            <td width="20%">' + o.eq_name + '</td>' +
            '                            <td class="omara-textcenter">' + o.eq_no + '</td>' +
            '                            <td class="omara-textcenter">' + o.eq_sn + '</td>' +
            '                            <td class="omara-textcenter">' + o.name + '</td>' +
            '                            <td>' + o.level_name + '</td>' +
            '                            <td class="omara-textcenter" width="10%">' +
            '                                <a href="' + o.url_setting + '" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify" data-id="' + o.ID + '"></a>' +
            '                                <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-pid="tr-' + o.ID + '"></a>' +
            '                            </td>' +
            '                        </tr>';
        return html;
    };
    var sys_equip_list = function (o) {
        var epsadd = omara_func.info_data({form: $('.set-form').find('input:text,select'), type: 'name'});
        var url = location.href.substring(location.href.indexOf('?') + 1, location.href.length);
        var id = url.split('&');
        var type_id = id[0].split('='), re_type_id = '"' + type_id[0] + '":"' + type_id[1] + '"';
        var spec = id[1].split('='), re_spec = '"' + spec[0] + '":"' + spec[1] + '"';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"ID,' + epsadd + '","cp":"' + o.page + '","ps":"' + o.ps + '",' + re_type_id + ',' + re_spec + '}'
            },
            callback: function (d) {
                var data = d.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += sys_equip_html({
                        ID: result.ID,
                        number: i,
                        eq_name: result.eq_name,
                        eq_no: result.eq_no,
                        eq_sn: result.eq_sn,
                        name: result.name,
                        level_name: result.level_name,
                        url_setting: result.url_setting
                    });
                });
                var page = omara_func.page_list({total: d.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-equip-add').length > 0) {
        /*列表获取*/
        sys_equip_list({
            page: 1,
            ps: 20
        });
    }
    var additem = function (size, addClass_name, width, val1, val2, show) {
        var additem = '<div class="input-box new-attr-box ' + show + '">' +
            '                    <input type="text" class="input-text omara-attr-name new-attr ' + addClass_name + '"  style="width: ' + width + 'px;" placeholder="属性名" value="' + val1 + '"> :' +
            '                    <input type="text" class="input-text omara-attr-value new-attr omara-mleft-5" size="' + size + '" placeholder="属性值" value="' + val2 + '">' +
            '<i class="iconfont icon-reduce remove-attr-box omara-fsize-28 omara-mleft-5 omara-middle"></i>' +
            '                </div>';
        return additem;
    };

    $('.add-equip-attr').on('click', function () {
        /*添加新属性*/
        $(this).parent().before(additem(52, '', 60, '', '', 'omara-mtop-20'));
    });
    $(document).on('click', '.column-attr-attr', function () {
        /*添加柱状图设置参数*/
        var html = '<div class="input-box new-column-box omara-mbotom-10">' +
            '                            <input type="text" class="input-text column-attr" size="6" placeholder="名称">' +
            '                            -' +
            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="前缀">' +
            '                            -' +
            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="开始">' +
            '                            -' +
            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="结束">' +
            '                            -' +
            '                            <input type="text" class="input-text column-attr omara-mleft-5" size="6" placeholder="颜色">' +
            '                            <i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle"></i>' +
            '                        </div>';
        $(this).before(html);
    });
    $(document).on('click', '.content-attr-attr', function () {
        /*添加内容替换属性*/
        var html = '<div class="input-box new-content-box omara-mbotom-10">' +
            '                                        <input type="text" class="input-text omara-attr-name old-data-attr " style="width: 100px;" placeholder="原始数据" value="">\n' +
            '                                        =>' +
            '                                        <input type="text" class="input-text omara-attr-value new-data-attr omara-mleft-5" style="width: 100px;" placeholder="替换数据" value="">\n' +
            '                                        <i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle"></i>\n' +
            '                                    </div>';
        $(this).before(html);
    });
    $(document).on('click', '.remove-attr-box', function () {
        /*删除属性*/
        $(this).parent().remove();
    });
    $(document).on('click', '.mdevice_type .checkbox-child', function () {
        /*复选框操作*/
        if ($(this).is(':checked')) {
            $(this).parent().siblings('.drop-down-menu').removeClass('hidden');
            $(this).parent().siblings().addClass('omara-displayblock').removeClass('none');
        } else {
            $(this).parent().siblings('.drop-down-menu').addClass('hidden');
            $(this).parent().siblings().addClass('none').removeClass('omara-displayblock');
        }
    });
    $(document).on('click', '.mdevice_type .dropdown-content li', function (e) {
        if ($(this).attr('data-name') == 'meter') {
            $(this).parent().parent().siblings('.input-text').removeClass('hidden');
        } else {
            $(this).parent().parent().siblings('.input-text').addClass('hidden');
        }

    });
    $('.redio-child-options').on('click', function () {
        /*设备可控项隐藏与显示*/
        $(this).parent().addClass('selected');
        $(this).parent().siblings('.choose-redio').removeClass('selected').children().prop('checked', false);
        if ($(this).siblings('span').text() == '是') {
            $('.omara-control-options-box').show();
        } else {
            $('.omara-control-options-box').hide();
        }
    });

    /**设备管理-告警描述设置**/
    $(document).on('click', '.eps-alarm-des-set', function () {
        var that = $(this);
        omara_func.ajax_data({
            url: $('.equit-alarm-set-box .set-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"","type_id":"' + that.attr('data-type_id') + '","spec":"' + that.attr('data-spec') + '"}'
            },
            callback: function (data) {
                $('.equit-alarm-set-box').attr('data-arrfield', data.arrField);
                $('.equit-alarm-set-box').show();
                $('.equit-alarm-set-box').attr('data-type_id', that.attr('data-type_id'));
                $('.equit-alarm-set-box').attr('data-spec', that.attr('data-spec'));
                var html = '';
                var vtype = ['范围内', '范围外', '小于小值', '大于大值', '通路检测'];
                var arrfield = JSON.parse(data.arrField);
                $.each(data.data, function (i, res) {
                    /*添加柱状图设置参数*/
                    var fhtml = '';
                    var vtypehtml = '';
                    var describe = JSON.parse(res.describe);
                    $.each(arrfield, function (a, val) {
                        fhtml += '<option value="' + val + '" ' + (res.alert_item == val ? 'selected' : '') + '>' + val + '</option>';
                    });
                    $.each(vtype, function (vt, val) {
                        vtypehtml += '<option value="' + vt + '" ' + (res.vtype == vt ? 'selected' : '') + '>' + val + '</option>';
                    });
                    html += '<tr>' +
                        '<td class="omara-textcenter">' +
                        '    <select name="alert_level" class="input-select eqs-field-list">' +
                        fhtml +
                        '    </select>' +
                        '</td>' +
                        '<td class="omara-textcenter">' +
                        '    <select name="alert_level" class="input-select eqs-field-type">' +
                        vtypehtml +
                        '    </select>' +
                        '</td>' +
                        '<td class="omara-textcenter alarm-input-content-box" width="300">' +
                        '    <div class="input-box input-box-0 ' + (res.vtype == '0' ? 'selected' : 'hidden') + '" data-index="0">' +
                        '        <input type="text" class="input-text" size="6" value="' + describe[0] + '">' +
                        '        <span>最大值~最小值</span>' +
                        '        <input type="text" class="input-text" size="6" value="' + (res.vtype == '0' ? describe[1] : '') + '">' +
                        '    </div>' +
                        '    <div class="input-box input-box-1 ' + (res.vtype == '1' ? 'selected' : 'hidden') + '" data-index="1">' +
                        '        <span>~最小值</span>' +
                        '        <input type="text" class="input-text" size="6" value="' + describe[0] + '">' +
                        '        <span>最大值~</span>' +
                        '    </div>' +
                        '    <div class="input-box input-box-2 ' + (res.vtype == '2' ? 'selected' : 'hidden') + '" data-index="2">' +
                        '        <span>~最小值</span>' +
                        '        <input type="text" class="input-text" size="6" value="' + describe[0] + '">' +
                        '    </div>' +
                        '    <div class="input-box input-box-3 ' + (res.vtype == '3' ? 'selected' : 'hidden') + '" data-index="3">' +
                        '        <input type="text" class="input-text" size="6" value="' + describe[0] + '">' +
                        '        <span>最大值~</span>' +
                        '    </div>' +
                        '    <div class="input-box input-box-4 ' + (res.vtype == '4' ? 'selected' : 'hidden') + '" data-index="4" >' +
                        '        <input type="text" class="input-text" size="6" value="' + describe[0] + '">' +
                        '    </div>' +
                        '</td>' +
                        '<td width="50">' +
                        '    <a href="javascript:void (0);" class="iconfont icon-reduce omara-middle omara-fsize-24 omara-mleft-10 remove-alarm-attr-box"></a>' +
                        '</td>' +
                        '</tr>';

                });
                $('.mdevice_type.omara-parameter-setting tbody').html(html);

            },
            error: function () {

            }
        });

    });
    $(document).on('click', '.alarm-dialog-close', function () {
        $('.equit-alarm-set-box').hide();
    });
    $(document).on('click', '.alarm-attr-tr-row', function () {
        /*添加柱状图设置参数*/
        var arrfield = JSON.parse($('.equit-alarm-set-box').attr('data-arrfield'));
        var fhtml = '';
        $.each(arrfield, function (i, val) {
            fhtml += '<option value="' + val + '">' + val + '</option>';
        });
        var html = '<tr>' +
            '<td class="omara-textcenter">' +
            '    <select name="alert_level" class="input-select eqs-field-list">' +
            fhtml +
            '    </select>' +
            '</td>' +
            '<td class="omara-textcenter">' +
            '    <select name="alert_level" class="input-select eqs-field-type">' +
            '        <option value="0">范围内</option>' +
            '        <option value="1">范围外</option>' +
            '        <option value="2">小于小值</option>' +
            '        <option value="3">大于大值</option>' +
            '        <option value="4">通路检测</option>' +
            '    </select>' +
            '</td>' +
            '<td class="omara-textcenter alarm-input-content-box" width="300">' +
            '    <div class="input-box input-box-0 selected" data-index="0">' +
            '        <input type="text" class="input-text required" size="6">' +
            '        <span>最大值~最小值</span>' +
            '        <input type="text" class="input-text required" size="6">' +
            '    </div>' +
            '    <div class="input-box input-box-1 hidden" data-index="1">' +
            '        <span>~最小值</span>' +
            '        <input type="text" class="input-text" size="6">' +
            '        <span>最大值~</span>' +
            '    </div>' +
            '    <div class="input-box input-box-2 hidden" data-index="2">' +
            '        <span>~最小值</span>' +
            '        <input type="text" class="input-text" size="6">' +
            '    </div>' +
            '    <div class="input-box input-box-3 hidden" data-index="3">' +
            '        <input type="text" class="input-text" size="6">' +
            '        <span>最大值~</span>' +
            '    </div>' +
            '    <div class="input-box input-box-4 hidden" data-index="4" >' +
            '        <input type="text" class="input-text" size="6">' +
            '    </div>' +
            '</td>' +
            '<td width="50">' +
            '    <a href="javascript:void (0);" class="iconfont icon-reduce omara-middle omara-fsize-24 omara-mleft-10 remove-alarm-attr-box"></a>' +
            '</td>' +
            '</tr>';
        $('.mdevice_type.omara-parameter-setting tbody').append(html);
    });
    $(document).on('click', '.remove-alarm-attr-box', function () {
        /*删除属性*/
        $(this).parent().parent().remove();
    });
    $(document).on('change', '.eqs-field-type', function () {
        var that = $(this);
        that.parent().parent().find('.input-box').removeClass('selected').addClass('hidden');
        that.parent().parent().find('.input-box .input-text').removeClass('required');
        that.parent().parent().find('.input-box-' + that.children('option:selected').val()).addClass('selected').removeClass('hidden');
        that.parent().parent().find('.input-box-' + that.children('option:selected').val() + ' .input-text').addClass('required');
    });

    $(document).on('click', '.equit-alarm-set-save', function () {
        $('.equit-alarm-set-box .input-box.selected').find('.input-text').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 20
            });
        });
        if ($('.equit-alarm-set-box .mdevice_type tr').length == 0) {
            omara_func.dialog_tips({show_text: '请添加行', show_time: 2000});
        } else if ($('.equit-alarm-set-box .error').length > 0 && $('.equit-alarm-set-box .regerr').length === 0) {
            $('.equit-alarm-set-box .error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var datas = '';
            var type_id = $('.equit-alarm-set-box').attr('data-type_id');
            var spec = $('.equit-alarm-set-box').attr('data-spec');
            $('.equit-alarm-set-box .mdevice_type tr').each(function (i) {
                var thistr = $(this);
                if (i > 0) {
                    datas += ',';
                }
                var alert_item = thistr.find('.eqs-field-list option:selected').val();
                var vtype = thistr.find('.eqs-field-type option:selected').val();
                var describe = '"' + thistr.find('.input-box.selected .input-text').eq(0).val() + '"';
                if (thistr.find('.input-box.selected .input-text').length > 1) {
                    describe = (describe + ',"' + thistr.find('.input-box.selected .input-text').eq(1).val() + '"');
                }
                datas += '{"type_id":"' + type_id + '","spec":"' + spec + '","alert_item":"' + alert_item + '","vtype":"' + vtype + '","describe":[' + describe + ']}';
            });

            omara_func.ajax_data({
                url: $('.equit-alarm-set-box .set-form').attr('action'),
                data: {a: 'save', info: '{"json":[' + datas + ']}'},
                callback: function (data) {
                    $('.equit-alarm-set-box').hide();
                    $('.equit-alarm-set-box .mdevice_type tbody').html('');
                },
                error: function () {

                }
            });
        }
    });
    /**批量删除设备*/
    $('.omara-equip-batch-del').on('click', function () {
        var that = $(this);
        if ($('.omara-system-box .checkbox-child:checked').length > 0) {
            omara_func.dialog_confirm({
                show_text: '确定批量删除吗？',
                dialog_id: 'batch-del-confirm'
            });
        } else {
            omara_func.dialog_tips({show_text: '请选择操作记录', show_time: 2000});
        }
    });
    /*!点击确定按钮 进行功能操作*/
    $(document).on('click', "#batch-del-confirm .btn-confirm", function () {
        var id = '';
        $('.omara-system-box .checkbox-child:checked').each(function (i) {
            if (i > 0) {
                id += ',';
            }
            id += $(this).val();
        });
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'delete', info: '{"id":"' + id + '"}'},
            callback: function (data) {
                $('.omara-system-box .checkbox-child:checked').each(function (i) {
                    var tr = $('#tr-' + $(this).val());
                    tr.remove();
                });

            },
            error: function () {
            }
        });
        $('.dialog-confirm').remove();
    });

    /**设备读取父属性*/
    $('.omara-equip-read-attribute').on('click', function () {
        var that = $(this);

        if ($('.omara-system-box .checkbox-child:checked').length > 0) {
            omara_func.dialog_confirm({
                show_text: '确定读取父属性吗？',
                dialog_id: 'read-attribute-confirm'
            });
        } else {
            omara_func.dialog_tips({show_text: '请选择操作记录', show_time: 2000});
        }
    });
    /*!点击确定按钮 进行功能操作*/
    $(document).on('click', "#read-attribute-confirm .btn-confirm", function () {
        var id = '';
        var that = $('.omara-equip-read-attribute');
        var type_id = (typeof that.attr('data-type_id') != undefined) ? ',"type_id":"' + that.attr('data-type_id') + '"' : '';
        var spec = (typeof that.attr('data-spec') != undefined) ? ',"spec":"' + that.attr('data-spec') + '"' : '';
        $('.omara-system-box .checkbox-child:checked').each(function (i) {
            if (i > 0) {
                id += ',';
            }
            id += $(this).val();
        });
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'readAttribute', info: '{"id":"' + id + '"' + type_id + spec + '}'},
            callback: function (data) {
                $('.omara-system-box .checkbox-child:checked').each(function (i) {
                    $(this).prop('checked', false).parent().removeClass('selected');
                });

            },
            error: function () {
            }
        });
        $('.dialog-confirm').remove();
    });


    /**组权限、我的分组，系统分组添加/编辑*/
    var my_group = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td width="30%">' + o.name + '</td>' +
            '                        <td class="' + (o.type == '1' ? '' : 'hidden') + '">' + o.s_type_value + '</td>' +
            '                        <td width="40%">' + o.eq_name + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' +
            (o.type == '1' ? '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-view group-view omara-room-set" data-id="' + o.ID + '"></a>' +
                '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-map2 omara-room-map"  data-id="' + o.ID + '"></a>' : '') +
            '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-modify group-permissions-modify" data-id="' + o.ID + '"></a>' +
            (o.type == '1' ? '<a href="javascript:void (0);"' + 'class="iconfont omara-middle icon-toggle omara-fsize-32 omara-mleft-10 icon-25 equip-elec-set"\n' +
                '                                data-id="' + o.ID + '" title="能耗统计设置"></a>' +
                '<a href="javascript:void (0);"' + 'class="iconfont omara-middle icon-toggle omara-fsize-32 omara-mleft-10 icon-19 room-haikang-set"\n' +
                '                                data-id="' + o.ID + '" title="海康视频设置"></a>' : '') +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-idtype="gid" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var group_permissions = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td class="omara-textcenter">' + o.number + '</td>' +
            '                        <td width="30%">' + o.priv_name + '</td>' +
            '                        <td class="omara-textcenter" width="50%">' + o.eq_name + '</td>' +
            '                        <td class="omara-textcenter" width="15%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify group-permissions-modify" data-id="' + o.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var my_group_list = function (o) {
        var data = omara_func.info_data({
            form: $('.omara-art-dialog .set-form').find('select,input:text,input[name=g_type],input[name=s_type]'),
            type: 'name'
        });
        var type = $('input[name=g_type]').val();
        var info = '{' +
            '"limits":"' + data + '",' +
            '"g_type":"' + type + '",' +
            '"cp":"' + o.page + '",' +
            '"ps":"' + o.ps + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (d) {
                var data = d.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += my_group({
                        ID: result.ID,
                        name: result.name,
                        type: type,
                        s_type_value: result.s_type_value,
                        eq_name: result.eq_name
                    });
                });
                var page = omara_func.page_list({total: d.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-sys-groupadd').length > 0) {
        /*我的分组-列表*/
        my_group_list({
            page: 1,
            ps: 20
        });
    }

    var group_permissions_list = function (o) {
        var data = omara_func.info_data({
            form: $('.omara-art-dialog .set-form').find('input,select,textarea'),
            type: 'name'
        });
        var info = '{' +
            '"limits":"' + data + '",' +
            '"cp":"' + o.page + '",' +
            '"ps":"' + o.ps + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (d) {
                var data = d.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += group_permissions({
                        ID: result.ID,
                        number: i,
                        priv_name: result.priv_name,
                        eq_name: result.eq_name
                    });
                });
                var page = omara_func.page_list({total: d.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.add-group-permissions').length > 0) {
        /*列表*/
        group_permissions_list({
            ps: 20,
            page: 1,
        });
    }
    $('.omara-refresh').on('click', function () {
        var that = $(this);
        /*分组刷新设备*/
        $('.left-group').toggleClass('mark');
        var html = '', html2 = '';
        var innerhtml = '';
        var r_data = $('.new-list .show').length;
        $.each(r_data, function (i) {
            var thatc = $(this);
            $('#equipments_' + thatc.attr('data-id')).addClass('hide');
        });
        setTimeout(function () {
            $('.data-list.left-group').toggleClass('mark');
        }, 1000);

    });
    $('.omara-sys-groupadd').on('click', function () {
        $('.g-type-choose').show();
        $('.authority-host-list').css({
            width: "auto"
        });
    });
    $(document).on('click', '.left-group .fist-name span', function () {
        var that = $(this).parent();
        that.toggleClass('selected');
        var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
        for (var i = 0; i < $('.' + that.attr('data-child')).length; i++) {
            if (that.hasClass('selected')) {
                if (!$('.left-group .' + that.attr('data-child')).eq(i).hasClass('none')) {
                    $('.left-group .' + that.attr('data-child')).eq(i).addClass('selected');
                }
                if (type == 'jurisdiction') {
                    $('.left-group .' + that.attr('data-child')).eq(i).addClass('selected');
                }
            } else {
                that.siblings('.' + that.attr('data-child')).removeClass('selected');
            }
        }
    });
    $(document).on('click', '.new-list .fist-name span', function () {
        var that = $(this).parent();
        that.toggleClass('selected');
        for (var i = 0; i < $('.' + that.attr('data-child')).length; i++) {
            if (that.hasClass('selected')) {
                if ($('.new-list .' + that.attr('data-child')).eq(i).hasClass('show')) {
                    $('.new-list .' + that.attr('data-child')).eq(i).addClass('selected');
                }
            } else {
                that.siblings('.' + that.attr('data-child')).removeClass('selected');
            }
        }
    });
    $(document).on('click', '.left-group .list-toggle-menu', function () {
        var that = $(this).parent();
        that.toggleClass('open');
        var thatc = that.siblings('.' + that.attr('data-child'));
        for (var i = 0; i < thatc.length; i++) {
            if (that.hasClass('open')) {
                if (!thatc.eq(i).hasClass('none')) {
                    thatc.eq(i).show();
                }
            } else {
                thatc.hide();
            }
            if (type == 'jurisdiction') {
                $('.left-group .' + that.attr('data-child')).eq(i).addClass('selected');
            }
        }
    });
    $(document).on('click', '.new-list .list-toggle-menu', function () {
        var that = $(this).parent();
        that.toggleClass('open');
        var thatc = that.siblings('.' + that.attr('data-child'));
        for (var i = 0; i < thatc.length; i++) {
            if (that.hasClass('open')) {
                if (thatc.eq(i).hasClass('show')) {
                    thatc.eq(i).show();
                }
            } else {
                thatc.hide();
            }
            if (type == 'jurisdiction') {
                $('.left-group .' + that.attr('data-child')).eq(i).addClass('selected');
            }
        }
    });
    $(document).on('click', '.data-list .second-name', function () {
        $(this).toggleClass('selected');
    });
    $('.add-extra-msg').on('click', function () {
        /*添加新属性*/
        $(this).parent().before(additem(50, '', 67, '', '', 'omara-mbotom-10'));
    });
    $(document).on('click', '.group-permissions-modify', function () {
        /*编辑弹窗显示、数据显示*/
        var that = $(this);
        var titlebar = $('.omara-art-dialog .titlebar .name');
        var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
        var dis_type = $('input[name=dispose_type]').val() == undefined ? '' : $('input[name=dispose_type]').val();
        $('.omara-art-dialog').show();
        $('.data-list.left-group').children('.fist-name').removeClass('open');
        $('.data-list.left-group').children('.second-name').hide();
        titlebar.text(titlebar.attr('data-art-modify'));
        $('.data-ID').val(that.attr('data-id'));
        $('.authority-host-list').css({
            width: "auto"
        });
        var data = omara_func.info_data({
            form: $('.omara-art-dialog .set-form').find('input:text,select,input[name=g_type],input[name=s_type]'),
            type: 'name'
        });
        var info = '{' +
            '"limits":"' + data + ($('.new-extra-msg').length > 0 ? ',' + $('.new-extra-msg').attr('name') : '') + '",' +
            '"id":"' + that.attr('data-id') + '",' +
            '"dispose_type":"' + dis_type + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (datas) {
                var data = datas.data;
                $('.omara-groupname').val(data.name || data.priv_name);
                $('input[name=g_type]').val(data.g_type);
                omara_func.select_checked({
                    select: 'select[name=parent_g]',
                    parameter: data.parent_g
                });
                $('.authority-host-list .choose-redio').removeClass('selected').find('.redio-child').prop('checked', false);
                if (data.s_type == '0') {
                    $('.g-type-choose').show();
                } else {
                    $('.g-type-choose').hide();
                }
                omara_func.checkbox_checked({checkbox_box: '.authority-host-list', data: data.s_type});
                var info = typeof data.equipment_types != "undefined" ? data.equipment_types : [];
                var connt = 0;
                var attr_item = '';
                if ($('.new-extra-msg').length > 0) {
                    var extra_msg = JSON.parse(data.extra_msg);
                    $.each(extra_msg, function (name, result) {
                        var res = result.split('：');
                        attr_item += additem(50, '', 67, res[0], res[1], 'omara-mbotom-10');
                    });
                    $('.add-extra-msg').parent().before(attr_item);
                }

                $.each(info, function (i, result) {
                    $.each(result, function (i2, result2) {
                        switch (type) {
                            case 'myGroup':
                                $('#' + i).show().addClass('open');
                                $('#' + result2.ID).show().addClass('show');
                                $('#equipments_' + result2.ID).addClass('none');
                                $('#' + result2.ID).attr('data-icon', result2.icon).attr('data-pos', result2.pos);
                                break;
                            case 'sysGroup':
                                $('#' + result.type_id).show().addClass('show');
                                $('#equipment_types_' + result.type_id).addClass('hide none');
                                $('.new-list .' + $('#' + result.ID).attr('data-child')).addClass('show');
                                break;
                            case 'jurisdiction':
                                $('#' + result2.ID).show().addClass('show');
                                $('#' + $('#' + result2.ID).attr('data-parent-id')).show().addClass('show');
                                break;
                        }
                    });
                });

            },
            error: function () {

            }
        });
    });
    $('.push-new-equip').on('click', function () {
        /*加入设备*/
        var innerhtml = '';
        var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
        if ($('.data-list.left-group .second-name.selected').length < 1 && type == 'myGroup') {
            omara_func.dialog_tips({show_text: '请选择设备', show_time: 2000});
            return;
        }
        if ($('.data-list.left-group .fist-name.selected').length < 1 && type == 'sysGroup') {
            omara_func.dialog_tips({show_text: '请选择设备', show_time: 2000});
            return;
        } else {
            var fist = $('.data-list.left-group .fist-name');
            var sencond = $('.data-list.left-group .second-name');
            var c = 0;
            for (var i = 0; i < fist.length; i++) {
                var child = $('.data-list.left-group .' + fist.eq(i).attr('data-child'));
                switch (type) {
                    case 'myGroup':
                        for (var ii = 0; ii < child.length; ii++) {
                            if (child.eq(ii).hasClass('selected')) {
                                $('#' + child.eq(ii).attr('data-id')).show().addClass('show').attr('data-pos', '%,%').attr('data-icon', child.eq(ii).attr('data-icon'));
                                child.eq(ii).hide().removeClass('selected').addClass('hide none');
                                $('#' + child.eq(ii).attr('data-parent-id')).show().addClass('open');
                                fist.eq(i).removeClass('selected');
                                c++;
                            }
                        }
                        break;
                    case 'sysGroup':
                        if (fist.eq(i).hasClass('selected')) {
                            $('#' + fist.eq(i).attr('data-id')).show().addClass('show');
                            fist.eq(i).removeClass('selected').addClass('hide').hide();
                            $('.new-list .' + fist.eq(i).attr('data-child')).addClass('show');
                        }
                        break;
                    case 'jurisdiction':
                        for (var ii = 0; ii < child.length; ii++) {
                            if (child.eq(ii).hasClass('selected')) {
                                $('#' + child.eq(ii).attr('data-id')).show().addClass('show');
                                $('#' + child.eq(ii).attr('data-parent-id')).show().addClass('show');
                            }
                        }
                        break;
                }

            }
        }
    });
    $('.remove-group-equip').on('click', function () {
        /*移除设备*/
        if ($('.data-list.new-list .selected').length === 0) {
            omara_func.dialog_tips({show_text: '请选择要移除的设备', show_time: 2000});
            return;
        } else {
            var fist = $('.data-list.new-list .fist-name');
            var sencond = $('.data-list.new-list .second-name');
            var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
            fist.each(function (index, result) {
                var first_name = $(this);
                var l_length = '';
                var r_length = '';
                var c = 0;

                switch (type) {
                    case 'myGroup':
                        $('.' + fist.eq(index).attr('data-child')).each(function (index2, result2) {
                            var sencond_name = $(this);
                            if (sencond_name.hasClass('selected') && sencond_name.hasClass('show')) {
                                $('#equipments_' + sencond_name.attr('data-id')).show().removeClass('hide none');
                                sencond_name.hide().removeClass('selected').removeClass('show').attr('data-pos', '%,%');
                                $('#equipment_types_' + sencond_name.attr('data-parent-id')).show();
                                fist.eq(index).removeClass('selected');
                            }
                        });
                        break;
                    case 'sysGroup':
                        if (first_name.hasClass('selected')) {
                            fist.eq(index).hide().removeClass('selected').removeClass('show');
                            $('.new-list .' + fist.eq(index).attr('data-child')).removeClass('show');
                            $('#equipment_types_' + first_name.attr('data-id')).show().removeClass('hide');
                        }
                        break;
                    case 'jurisdiction':
                        $('.' + fist.eq(index).attr('data-child')).each(function (index2, result2) {
                            var sencond_name = $(this);
                            if (sencond_name.hasClass('selected')) {
                                $('#' + sencond_name.attr('data-id')).hide().removeClass('show selected');
                            }
                        });
                        break;
                }


            });
        }
    });
    $(document).on('click', '.choose-g-type', function () {
        /*分组类型选择*/
        var that = $(this);
        if ($(this).siblings('span').text() == '目录') {
            $('.g-type-choose').hide();
        } else {
            $('.g-type-choose').show();
        }
    });
    $('.group-permissions-save').on('click', function () {
        /*保存数据*/
        var value = '';
        var type = $('.omara-art-dialog .titlebar .name').attr('data-type');
        omara_func.is_validity({dom: '.omara-groupname', reg: false, reglength: true, length: 50});
        $('.new-attr').each(function () {
            var thatc = $(this);
            omara_func.is_validity_mul({
                dom: thatc, reg: false, reglength: true,
                length: 500
            });
        });
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return;
        } else if ($('.data-list.new-list').children('.show').length === 0 && $('.data-list.new-list').hasClass('verify-device-input')) {
            omara_func.dialog_tips({show_text: '请选择设备', show_time: 2000});
            return;
        } else {
            value = '';
            var that = (type == 'sysGroup') ? $('.data-list.new-list .fist-name.show') : $('.data-list.new-list .second-name.show');
            var id = $('.data-ID').val();
            for (var i = 0; i < that.length; i++) {
                if (i > 0) {
                    value += ',';
                }
                switch (type) {
                    case 'myGroup':
                        var icon = (that.eq(i).attr('data-icon') != '') ? that.eq(i).attr('data-icon') : $('.omara-art-dialog .set-form').attr('data-icon');
                        var pos = ((typeof that.eq(i).attr('data-pos')) != undefined) || (that.eq(i).attr('data-pos') != '') ? that.eq(i).attr('data-pos') : '%,%';
                        value += '{"ID":"' + that.eq(i).attr('data-id') + '","pos":"' + pos + '","icon":"' + icon + '"}';
                        break;
                    case 'sysGroup':
                        value += '{"ID":"' + that.eq(i).attr('data-id') + '"}';
                        break;
                    case 'jurisdiction':
                        value += that.eq(i).attr('data-id');
                        break;

                }
            }
            ;
            if ($('.omara-sys-groupadd').length > 0) {
                value = '[' + value + ']';
            } else {
                value = '"' + value + '"';
            }
            var room_attr = [];
            $('.new-attr-box').each(function (i) {
                room_attr[i] = $('.omara-attr-name').eq(i).val() + '：' + $('.omara-attr-value').eq(i).val();
            });

            omara_func.proccess({dom: that});
            var html = '';
            var data = omara_func.info_data({
                form: $('.omara-art-dialog .set-form').find('input:text,select,input[name=g_type],input[name=s_type]'),
                type: 'val+name'
            });
            var extra_msg = ($('.new-extra-msg').length > 0 ? ',"' + $('.new-extra-msg').attr('name') + '":' + JSON.stringify(room_attr) : '');
            var info = '{' + data + extra_msg + ',"' + $('.data-gropu-permissions').attr('name') + '":' + value + ',"id":"' + id + '"}';
            omara_func.ajax_data({
                url: $('.data-form').attr('action'),
                data: {a: 'save', info: info},
                callback: function (data) {
                    var data = data.data[0];
                    if (id == '') {
                        if ($('.add-group-permissions').length > 0) {
                            html = group_permissions({
                                ID: data.ID,
                                number: $('.omara-data-list tbody tr').length + 1,
                                priv_name: data.priv_name,
                                eq_name: data.eq_name
                            });
                        } else if ($('.omara-sys-groupadd').length > 0) {
                            html = my_group({
                                ID: data.ID,
                                name: data.name,
                                type: data.g_type,
                                s_type_value: data.s_type_value,
                                eq_name: data.eq_name
                            });
                        }

                        $('.omara-data-list tbody').append(html);
                    } else {
                        if ($('.add-group-permissions').length > 0) {
                            $('#tr-' + id + ' td').eq(1).html(data.priv_name);
                            $('#tr-' + id + ' td').eq(2).html(data.eq_name);
                        } else if ($('.omara-sys-groupadd').length > 0) {
                            $('#tr-' + id + ' td').eq(0).html(data.name);
                            $('#tr-' + id + ' td').eq(1).html(data.s_type_value);
                            $('#tr-' + id + ' td').eq(2).html(data.eq_name);
                        }
                    }

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });
    /**地图坐标点 拾取与保存*/
    var room_map_line;
    if ($('#omara-room-map-line').length > 0) {
        room_map_line = new BMap.Map("omara-room-map-line");
        var point = new BMap.Point(116.404, 39.915);
        room_map_line.centerAndZoom(point, 6);
        room_map_line.enableScrollWheelZoom();//启用滚轮放大缩小
        //单击获取点击的经纬度
        room_map_line.addEventListener("click", function (e) {
            removeOverlay({mapid: "omara-room-map-line", map: room_map_line});
            addOverlay({
                mapid: "omara-room-map-line",
                point: e.point,
                map: room_map_line,
                show: false,
                default_mark: true
            });
            $('.map-form').attr('data-maxtrix', e.point.lat + "," + e.point.lng);
        });
        $('.search-map-text').bind("input propertychange", function () {
            room_map_line.centerAndZoom($('.search-map-text').val(), 18);
        });
    }
    var removeOverlay = function (o) {
        if ($('#' + o.mapid).length > 0) {
            var allOverlay = o.map.getOverlays();
            for (var i = 0; i < allOverlay.length; i++) {
                //删除经度的点
                o.map.removeOverlay(allOverlay[i]);
            }
        }
    };
    var addOverlay = function (o) {
        if ($('#' + o.mapid).length > 0) {
            var pointArray = new Array();
            if (o.default_mark) {
                var mk = new BMap.Marker(new BMap.Point(o.point.lng, o.point.lat));  //基于定位的这个点的点位创建marker
                o.map.addOverlay(mk);     //  将marker作为覆盖物添加到map地图上
            }
            if (o.show) {
                pointArray[0] = new BMap.Point(o.point.lng, o.point.lat);
                o.map.centerAndZoom(pointArray[0], 6);
            }
        }
    };
    $(document).on('click', '.omara-room-map', function () {
        var that = $(this);
        $('.map-form').attr('data-id', that.attr('data-id'));
        var type = $('.map-form').attr('data-type');
        var re_type = type.replace(/'/g, '"');
        var limits = $('.map-form').attr('data-limits');
        omara_func.ajax_data({
            url: $('.map-form').attr('action'),
            data: {a: 'list', info: '{"limits":"' + limits + '",' + re_type + ',"id":"' + that.attr('data-id') + '"}'},
            callback: function (data) {
                $('.map-dialog').show();
                var maxtrix = data.data.maxtrix;
                if ($('.omara-room-map-offine').length > 0) {
                    // $('.omara-room-map-offine .off-line-map').attr('src',data.data.map_url).show();
                    $('.omara-room-map-offine .map-mark').remove();
                    if (maxtrix != null && maxtrix != '' && maxtrix.indexOf('%') < 0 && maxtrix.indexOf('$') > 0) {
                        var screenX = maxtrix.substring(0, maxtrix.indexOf('$,'));
                        var screenY = maxtrix.substring(maxtrix.indexOf(',') + 1, maxtrix.length - 1);
                        var Px = ($('.omara-room-map-offine').width() / 2);
                        var Ix = $('.omara-room-map-offine .off-line-map').width() / 2;
                        var Iy = $('.omara-room-map-offine').height() / 2;
                        var xx = (screenX * Ix) + Px;
                        var yy = Iy - (screenY * Iy);
                        $('.omara-room-map-offine').append('<img src="/static/images/fixed02.png" class="map-mark" alt="" style="position: absolute;left:' + xx + 'px;top:' + yy + 'px;"/>');
                    }
                } else {
                    var ponit;
                    var show = false;
                    removeOverlay({mapid: "omara-room-map-line", map: room_map_line});
                    if (maxtrix != null && maxtrix != '' && maxtrix.indexOf('%') < 0 && maxtrix.indexOf('$') < 0) {
                        $('.map-form').attr('data-maxtrix', maxtrix);
                        var lat = maxtrix.substring(0, maxtrix.indexOf(','));
                        var lng = maxtrix.substring(maxtrix.indexOf(',') + 1, maxtrix.length);
                        ponit = {
                            lng: lng,
                            lat: lat
                        };
                        show = true;
                    } else {
                        ponit = {
                            lng: 116.404,
                            lat: 39.915
                        };
                        show = false;
                        $('.map-form').attr('data-maxtrix', '');
                    }
                    setTimeout(function () {
                        addOverlay({
                            mapid: "omara-room-map-line",
                            point: ponit,
                            map: room_map_line,
                            show: show,
                            default_mark: show
                        });
                    }, 1000);
                }

            },
            error: function () {

            }
        });

    });
    $(document).on('click', '.map-dialog .default-dialog-close', function () {
        $('.map-dialog').hide();
    });
    $(document).on('click', '.omara-room-map-offine', function (e) {
        var oEvent = e || event;
        var screenX = oEvent.clientX - $(this).offset().left - 11;
        var screenY = oEvent.clientY - $(this).offset().top - 22;

        var t = oEvent.offsetTop,
            l = oEvent.offsetLeft;
        while (oEvent = oEvent.offsetParent) {
            t += oEvent.offsetTop;
            l += oEvent.offsetLeft;
        }
        console.log($(this).offset());
        $(this).find('.map-mark').remove();
        $(this).append('<img src="/static/images/fixed02.png" class="map-mark" alt="" style="position: absolute;left:' + screenX + 'px;top:' + screenY + 'px;"/>');
    });
    $('.fixed-map-save').on('click', function () {
        var that = $('.map-form');
        var mark = $('.map-mark');
        var maxtrix = '';
        if ($('.omara-room-map-line').length > 0) {
            maxtrix = that.attr('data-maxtrix');
        } else {
            if (mark.length > 0) {
                var Px = $('.omara-room-map-offine').width() / 2;
                var Ix = $('.off-line-map').width() / 2;
                var Iy = $('.off-line-map').height() / 2;
                var Ex = parseFloat(mark.css('left'));
                var Ey = parseFloat(mark.css('top'));
                var top = (mark.css('top') == '0px' || mark.css('top') == '0') ? '%' : ((Iy - Ey) / Iy).toFixed(5) + '$';
                var left = (mark.css('left') == '0px' || mark.css('left') == '0') ? '%' : ((Ex - Px) / Ix).toFixed(5) + '$';
                maxtrix = left + ',' + top;
            } else {
                maxtrix = '%,%';
            }
        }
        omara_func.ajax_data({
            url: that.attr('action'),
            data: {a: 'save', info: '{"id":"' + that.attr('data-id') + '","maxtrix":"' + maxtrix + '"}'},
            callback: function (data) {
                /*保存成功清除数据，关闭弹窗*/
                $('.map-dialog').hide();
                if ($('.omara-room-map-line').length > 0) {
                    removeOverlay({mapid: "omara-room-map-line", map: map});
                } else {
                    $('.omara-room-map-offine .map-mark').remove();
                }
            },
            error: function () {

            }
        });
    });

    /**系统管理员/机房管理员/联系人*/
    var sysadmin_html = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td class="omara-textcenter" width="100">' + o.number + '</td>' +
            '                        <td class="omara-textcenter' + (o.usertype == '2' ? ' none' : '') + '" width="20%">' + o.username + '</td>' +
            '                        <td class="omara-textcenter" width="25%">' + o.realname + '</td>' +
            '                        <td class="omara-textcenter" width="' + (o.usertype == '2' ? '20%' : '15%') + '">' + o.phone + '</td>' +
            '                        <td class="omara-textcenter" width="' + (o.usertype == '2' ? '30%' : '20%') + '">' + o.mail + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify sysadmin-modify ' + ($('.data-form').attr('data-usertype') == "1" ? "hidden" : "") + '" data-id="' + o.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete ' + (o.usertype != '2' ? "sys-admin-delete" : "contact-delete-single") + (o.usertype == "1" ? " hidden" : "") + '" data-id="' + o.ID + '" data-idtype="uid" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var room_admin_html = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td class="omara-textcenter">' + o.number + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' + o.username + '</td>' +
            '                        <td class="omara-textcenter" width="15%">' + o.realname + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' + o.phone + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' + o.mail + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' + o.priv_name + '</td>' +
            '                        <td class="omara-textcenter" width="10%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify sysadmin-modify ' + ($('.data-form').attr('data-usertype') == "1" ? "hidden" : "") + '" data-id="' + o.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete ' + ($('.omara-art-dialog input[name=usertype]') != '2' ? "sys-admin-delete" : "contact-delete-single") + ($('.data-form').attr('data-usertype') == "1" ? "hidden" : "") + '" data-id="' + o.ID + '" data-idtype="uid" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var sys_admin_list = function (o) {
        var p = o.page;
        var ps = o.ps;
        var data = omara_func.info_data({form: $('.omara-art-dialog .set-form'), type: 'name'});
        var re_data = data.replace(',password', '');
        var usertype = $('.omara-art-dialog .set-form input[name=usertype]').val();
        // if ($('.omara-sys-contact').length > 0) {
        //     usertype = '2';
        // } else if ($('.omara-sys-admin').length > 0) {
        //     usertype = '0';
        // }
        var info = '{' +
            '"limits":"' + re_data + ',ID",' +
            '"usertype":"' + usertype + '",' +
            '"cp":"' + p + '",' +
            '"ps":"' + ps + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += sysadmin_html({
                        ID: result.ID,
                        number: i,
                        username: result.username,
                        realname: result.realname,
                        phone: result.phone,
                        mail: result.mail,
                        usertype: usertype
                    });
                });
                var page = omara_func.page_list({total: datas.total, ps: ps, page: p});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-sys-admin,.omara-sys-contact').length > 0) {
        /*系统管理员列表*/
        sys_admin_list({
            page: 1,
            ps: 20
        });
    }

    var sys_room_admin_list = function (o) {
        var data = omara_func.info_data({form: $('.omara-art-dialog .set-form'), type: 'name'});
        var re_data = data.replace(',password', '');
        var info = '{' +
            '"limits":"' + re_data + ',ID,m_group",' +
            '"usertype":"' + $('.omara-art-dialog .set-form input[name=usertype]').val() + '",' +
            '"cp":"' + o.page + '",' +
            '"ps":"' + o.ps + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += room_admin_html({
                        ID: result.ID,
                        number: i,
                        username: result.username,
                        realname: result.realname,
                        phone: result.phone,
                        mail: result.mail,
                        priv_name: result.priv_name
                    });
                });
                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-sys-room').length > 0) {
        /*机房管理员列表*/
        sys_room_admin_list({
            page: 1,
            ps: 20
        });
    }
    $('.add-sysadmin-save').on('click', function () {
        var that = $(this);
        omara_func.is_validity({
            dom: 'input[name=login_pw]',
            reg: false,
            reglength: true,
            length: 20
        });
        omara_func.is_validity({
            dom: '.omara-sys-username',
            reg: false,
            reglength: true,
            length: 20
        });
        if ($('.data-ID').val() == '' || $('.omara-sys-pwd').val() != '') {
            omara_func.is_validity({
                dom: '.omara-sys-pwd',
                reg: !omara_func.reg.is_pwd($('.omara-sys-pwd').val()),
                reglength: true,
                length: 30
            });
        }
        omara_func.is_validity({dom: '.omara-sys-name', reg: false, reglength: true, length: 20});
        omara_func.is_validity({
            dom: '.omara-sys-mobile',
            reg: !omara_func.reg.is_mobile($('.omara-sys-mobile').val()), reglength: false, length: 20
        });
        omara_func.is_validity({
            dom: '.omara-sys-mail',
            reg: !omara_func.reg.is_email($('.omara-sys-mail').val()),
            reglength: false,
            length: 20
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
            $('.regerr').eq(0).focus();
            omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
            return false;
        } else if ($('.authority-host-list .choose-checkbox').length > 0 && $('.authority-host-list .checkbox-child:checked,.omara-sys-wxopenid').length < 1) {
            omara_func.dialog_tips({show_text: '请选择权限', show_time: 2000});
        } else if ($('.authority-alert-level .choose-checkbox').length > 0 && $('.authority-alert-level .checkbox-child:checked').length < 1) {
            omara_func.dialog_tips({show_text: '请选择报警等级', show_time: 2000});
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return false;
        } else {
            omara_func.proccess({dom: that});
            var data = omara_func.info_data({
                form: $('.omara-art-dialog .set-form').find('input:text,input:password,select,input[name=usertype]'),
                type: 'val+name'
            });
            var re_data = data.replace('"password":"",', '');
            var my_group = '';
            var m_alert_l = '';
            var id = $('.data-ID').val();

            $('.authority-host-list .checkbox-child:checked').each(function (i) {
                if (i > 0) {
                    my_group += ','
                }
                my_group += $(this).val();
            });
            $('.authority-alert-level .checkbox-child:checked').each(function (i) {
                if (i > 0) {
                    m_alert_l += ','
                }
                m_alert_l += $(this).val();
            });
            m_alert_l = '","m_alert_l":"' + m_alert_l + '"';
            var my_group_data = ',"m_group":"' + my_group + m_alert_l;
            var html = '';
            var number = $('.omara-data-list tbody tr').length + 1;
            omara_func.ajax_data({
                url: $('.data-form').attr('action'),
                data: {a: 'save', info: '{' + re_data + my_group_data + ',"id":"' + id + '"' + '}'},
                callback: function (data) {
                    var data = data.data[0];
                    if (id == '') {
                        if ($('.omara-sys-admin,.omara-sys-contact').length > 0) {
                            html = sysadmin_html({
                                ID: data.ID,
                                number: number,
                                username: data.username,
                                realname: data.realname,
                                phone: data.phone,
                                mail: data.mail,
                                usertype: data.usertype
                            });
                        } else if ($('.omara-sys-room').length > 0) {
                            html = room_admin_html({
                                ID: data.ID,
                                number: number,
                                username: data.username,
                                realname: data.realname,
                                phone: data.phone,
                                mail: data.mail,
                                priv_name: data.priv_name
                            });
                        }
                        $('.omara-data-list tbody').append(html);
                    } else {
                        $('#tr-' + id + ' td').eq(1).html(data.username);
                        $('#tr-' + id + ' td').eq(2).html(data.realname);
                        $('#tr-' + id + ' td').eq(3).html(data.phone);
                        $('#tr-' + id + ' td').eq(4).html(data.mail);
                        if ($('.omara-sys-room').length > 0) {
                            $('#tr-' + id + ' td').eq(5).html(data.priv_name);
                        }
                    }

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });
    $(document).on('click', '.sysadmin-modify', function () {
        var that = $(this);
        var titlebar = $('.omara-art-dialog .titlebar .name');
        $('.omara-art-dialog').show();
        titlebar.text(titlebar.attr('data-art-modify'));
        $('.data-ID').val(that.attr('data-id'));
        var data = omara_func.info_data({form: $('.omara-art-dialog .set-form'), type: 'name'});
        var re_data = data.replace(',password', '');
        var qianxian = $('input[name=usertype]').val() != '0' ? ',m_group' : '';
        var info = '{' +
            '"limits":"' + re_data + qianxian + ',m_alert_l",' +
            '"id":"' + that.attr('data-id') + '"' +
            '}';
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: info},
            callback: function (data) {
                var data = data.data;
                $('.omara-sys-username').val(data.username);
                $('.omara-sys-name').val(data.realname);
                $('.omara-sys-mobile').val(data.phone);
                $('.omara-sys-mail').val(data.mail);
                $('.omara-sys-wxopenid').val(data.wxopenid);
                if ($('.input-select[name=m_alert_t]').length > 0) {
                    omara_func.select_checked({
                        select: '.input-select',
                        parameter: data.m_alert_t
                    });
                }
                if ($('.omara-business-attribution').length > 0) {
                    omara_func.select_checked({
                        select: '.omara-business-attribution',
                        parameter: data.business
                    });
                }
                if ($('select[name=safety_report]').length > 0) {
                    omara_func.select_checked({
                        select: 'select[name=safety_report]',
                        parameter: data.safety_report
                    });
                }
                omara_func.checkbox_checked({checkbox_box: '.authority-host-list', data: data.m_group});
                omara_func.checkbox_checked({checkbox_box: '.authority-alert-level', data: data.arrAlertLevel});
            },
            error: function () {

            }
        });
    });
    $(document).on('click', '.sys-admin-delete', function () {
        var that = $(this);
        $('.sys-delete-box').show();
        $('.delete-data-ID').val(that.attr('data-id'));
        $('.sys-delete-box .input-text').removeClass('error');
    });
    $(document).on('click', '.sys-delete-box .dialog-close', function () {
        var that = $(this);
        $('.sys-delete-box').hide();
        $('.sys-delete-box input').val('');
        $('.sys-delete-box .input-text').removeClass('error');
    });
    $(document).on('click', '.sys-delete-set-save', function () {
        var that = $(this);
        omara_func.is_validity({
            dom: '.delete-pwd',
            reg: false,
            reglength: true,
            length: 20
        });
        if ($('.sys-delete-box .error').length > 0) {
            $('.sys-delete-box .error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.sys-delete-box  .set-form'), type: 'name+val'});

            omara_func.ajax_data({
                url: $('.sys-delete-box  .set-form').attr('action'),
                data: {a: 'delete', info: '{' + data + '}'},
                callback: function (data) {
                    $('#tr-' + $('.delete-data-ID').val()).remove();
                    $('.sys-delete-box').hide();
                    $('.sys-delete-box input').val('');
                    $('.sys-delete-box .input-text').removeClass('error');
                },
                error: function () {

                }
            });
        }
    });

    /**功能设置*/
    $('.redio-child').on('click', function () {
        if ($(this).siblings('span').text() == 'COM') {
            $('.newsletter-parameters').show().siblings('.newsletter-tcp').hide();
        } else {
            $('.newsletter-parameters').hide().siblings('.newsletter-tcp').show();
        }
    });
    $(document).on('click', 'input.switch-checkbox', function () {
        if ($(this).is(':checked')) {
            $('.report-week-args,.report-time').show();
            $('.toggle-report-setbox').removeClass('hidden');
        } else {
            $('.report-week-args,.report-time').hide();
            $('.toggle-report-setbox').addClass('hidden');
        }
    });
    $(document).on('change', '.report-week-args', function () {
        var val = $(this).find('option:selected').text();
        $('.toggle-report-setbox').removeClass('hidden');
        if (val == '每周') {
            $('.report-week').show();
            $('.report-week').siblings().hide();
        } else if (val == '每月') {
            $('.report-date').siblings().hide();
            $('.report-date, .report-date-unit').show();
        } else {
            $('.toggle-report-setbox').addClass('hidden');
        }
    });
    if ($('.report-date').length > 0) {
        var date = new Date();
        $.datetimepicker.setLocale('ch');
        $('.report-date').datetimepicker({
            format: 'd', timepicker: false
        });
    }

    if ($('.omara-alert-funcsave').length > 0) {
        var data_alert = omara_func.info_data({form: $('.set-form'), type: 'name'});
        var type = 'communication_type,report,';
        omara_func.ajax_data({
            url: $('.set-form').attr('action'),
            data: {a: 'list', info: '{"pvar":"' + type + data_alert + '"}'},
            callback: function (data) {
                var data = data.data;
                $('input[name="smtp_ip"]').val(data.smtp_ip);
                $('input[name="smtp_port"]').val(data.smtp_port);
                $('input[name="smtp_username"]').val(data.smtp_username);
                $('input[name="smtp_password"]').val(data.smtp_password);
                $('input[name="bn_times"]').val(data.bn_times);
                $('input[name="bn_interval"]').val(data.bn_interval);
                $('input[name="wx_AppID"]').val(data.wx_AppID);
                $('input[name="wx_AppSecret"]').val(data.wx_AppSecret);
                $('input[name="wx_TplID"]').val(data.wx_TplID);
                $('input[name="wx_TplID_safety_report"]').val(data.wx_TplID_safety_report);
                if (data.communication_type == '1') {
                    $('.newsletter-parameters').show().siblings('.newsletter-tcp').hide();
                    $('.choose-redio').removeClass('selected').children('.redio-child').prop('checked', false);
                    $('.choose-redio').eq(0).addClass('selected').children('.redio-child').prop('checked', true);
                    $('input[name="com_name"]').val(data.com_name);
                    $('input[name="com_baud_rate"]').val(data.com_baud_rate);
                    $('input[name="com_stop_bit"]').val(data.com_stop_bit);
                    $('input[name="com_parity_check"]').val(data.com_parity_check);
                    $('input[name="com_data_bits"]').val(data.com_data_bits);
                    $('input[name="smsc"]').val(data.smsc);
                } else {
                    $('.newsletter-parameters').hide().siblings('.newsletter-tcp').show();
                    $('.choose-redio').removeClass('selected').children('.redio-child').prop('checked', false);
                    $('.choose-redio').eq(1).addClass('selected').children('.redio-child').prop('checked', true);
                    $('input[name="tcp_ip"]').val(data.tcp_ip);
                    $('input[name="tcp_port"]').val(data.tcp_port);
                    $('input[name="tcp_username"]').val(data.tcp_username);
                    $('input[name="tcp_password"]').val(data.tcp_password);
                }
                if (data.report == '1') {
                    $('.report-week-args,.report-time').show();
                    $('.toggle-report-setbox').removeClass('hidden');
                    $('.switch-checkbox').addClass('selected').children('.switch-checkbox').prop('checked', true);
                    omara_func.select_checked({
                        select: '.report-week-args',
                        parameter: data.safety_report_cycle
                    });
                    omara_func.select_checked({
                        select: '.report-time',
                        parameter: data.safety_report_time
                    });
                    if (data.safety_report_cycle == '每周') {
                        omara_func.select_checked({
                            select: '.report-week',
                            parameter: data.safety_report_week
                        });
                        $('.report-week').show();
                    } else if (data.safety_report_cycle == '每月') {
                        $('.report-date, .report-date-unit').show();
                        // $('textarea[name="report_template"]').val(data.report_template);
                        $('.report-date').val(data.safety_report_date);
                    } else {

                    }
                } else {
                    $('.report-week-args,.report-time').hide();
                    $('.toggle-report-setbox').addClass('hidden');
                    $('.switch-checkbox').removeClass('selected').children('.switch-checkbox').prop('checked', false);
                }

                var alerttype = [128, 64, 32, 16, 8];
                var bn_type = parseFloat(data.bn_type);
                var checkbox = $('.authority-host-list .choose-checkbox');
                $.each(alerttype, function (i) {
                    if ((bn_type & alerttype[i])) {
                        checkbox.eq(i).addClass('selected').find('.checkbox-child').prop('checked', true);
                    }
                });
            },
            error: function () {

            }
        });

        $('.omara-alert-funcsave').on('click', function () {
            var that = $(this);
            $('.omara-system-box').find('input:text,input:password').each(function () {
                var thatc = $(this);
                // if(!thatc.parent().is(':hidden')){
                //     omara_func.is_validity_mul({
                //         dom: thatc, reg: false,
                //         reglength: true,
                //         length: 20
                //     });
                // }

            });
            omara_func.is_validity({dom: 'textarea[name=report_template]', reg: false, reglength: true, length: 1000});
            if ($('.error').length > 0 && $('.regerr').length === 0) {
                $('.error').eq(0).focus();
                omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
                return false;
            } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
                $('.regerr').eq(0).focus();
                omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
                return false;
            } else if ($('.regerrlength').length > 0) {
                $('.regerrlength').eq(0).focus();
                omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
                return false;
            } else {
                var report = $('#switch-shelves').is(':checked') ? '' : ',"report":"0"';
                var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
                omara_func.proccess({dom: that});
                omara_func.ajax_data({
                    url: $('.set-form').attr('action'),
                    data: {a: 'save', info: '{' + data + report + '}'},
                    callback: function (data) {

                    },
                    error: function () {

                    }
                });
            }
        });
    }

    /**余额查询*/
    $('.omara-query-balance').on('click', function () {
        omara_func.proccess({dom: $(this)});
        omara_func.ajax_data({
            url: $('.set-form').attr('data-balance'),
            data: {a: 'balance', info: '{}'},
            callback: function (data) {
                $('.omara-query-balance-value').text(data.data.balance);
            },
            error: function () {

            }
        });
        omara_func.ajax_data({
            url: $('.set-form').attr('data-signal'),
            data: {a: 'signal', info: '{}'},
            callback: function (data) {
                for (var i = 0; i < data.data.signal; i++) {
                    $('.sim-signal').children().eq(i).attr('fill', '#f30');
                }
            },
            error: function () {

            }
        });
    });
    $('.query-balance-save,.query-balance').on('click', function () {
        $('.query-balance-form .required').each(function (i) {
            var that = $(this);
            omara_func.is_validity_mul({dom: that, reg: true, reglength: true, length: 500});
        });
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            $('.query-balance-form').submit();
        }
    });

    /**报警模板添加、编辑*/
    var alarm_html = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td class="omara-textcenter">' + o.number + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' + o.tpl_name + '</td>' +
            '                        <td class="omara-textcenter" width="50%">' + o.icon + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify alarm-modify" data-id="' + o.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var alarm_modal_list = function (o) {
        var data_alert = omara_func.info_data({form: $('.set-form').find('input:text,textarea'), type: 'name'});
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,' + data_alert + '","cp":"' + o.page + '","ps":"' + o.ps + '"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                $.each(data, function (i, result) {
                    var icon = omara_func.alarm_type(result.notify_mode);
                    html += alarm_html({ID: result.ID, number: i, tpl_name: result.tpl_name, icon: icon});
                });
                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-sys-alarmadd').length > 0) {
        alarm_modal_list({
            page: 1,
            ps: 20
        });
    }
    $('.add-alarm-save').on('click', function () {
        var that = $(this);
        var textarea = ['.omara-alarm-app', '.omara-alarm-msg', '.omara-alarm-aduio', '.omara-alarm-mail', '.omara-alarm-wx'];
        omara_func.is_validity({dom: '.omara-alarm-name', reg: false, reglength: true, length: 50});
        $('.authority-host-list .checkbox-child').each(function (i) {
            if ($(this).is(':checked')) {
                omara_func.is_validity({dom: textarea[i], reg: false, reglength: true, length: 500});
            }
        });
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.choose-checkbox').length > 0 && $('.checkbox-child:checked').length < 1) {
            omara_func.dialog_tips({show_text: '请选择报警方式', show_time: 2000});
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return false;
        } else {
            var my_group = '';
            var textarea = '';
            var id = $('.data-ID').val();
            $('.checkbox-child').each(function (i) {
                if ($(this).is(':checked')) {
                    my_group += '1';
                } else {
                    my_group += '0';
                }
            });
            $('.omara-art-dialog .set-form').find('textarea').each(function (i) {
                var val = $(this).val();
                textarea += ',"' + $(this).attr('name') + '":' + JSON.stringify(val) + '';
            });
            var my_group_data = ',"notify_mode":"' + parseInt(my_group + "000", 2) + '"';
            var data = omara_func.info_data({
                form: $('.omara-art-dialog .set-form').find('input:text'),
                type: 'val+name'
            });
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.data-form').attr('action'),
                data: {a: 'save', info: '{' + data + my_group_data + ',"id":"' + id + '"' + textarea + '}'},
                callback: function (data) {
                    var datas = data.data[0];
                    var icon = omara_func.alarm_type(datas.notify_mode);
                    if (id == '') {
                        var html = alarm_html({
                            ID: datas.ID,
                            number: $('.omara-data-list tbody tr').length + 1,
                            tpl_name: datas.tpl_name,
                            icon: icon
                        });
                        $('.omara-data-list tbody').append(html);
                    } else {
                        $('#tr-' + id + ' td').eq(1).text(datas.tpl_name);
                        $('#tr-' + id + ' td').eq(2).html(icon);
                    }

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });
    $(document).on('click', '.alarm-modify', function () {
        var that = $(this);
        var titlebar = $('.omara-art-dialog .titlebar .name');
        $('.omara-art-dialog').show();
        titlebar.text(titlebar.attr('data-art-modify'));
        $('.data-ID').val(that.attr('data-id'));
        var data_alert = omara_func.info_data({
            form: $('.dialog-content .set-form').find('input:text,textarea'),
            type: 'name'
        });
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"' + data_alert + '","id":"' + that.attr('data-id') + '"}'},
            callback: function (data) {
                var data = data.data;
                $('.omara-alarm-name').val(data.tpl_name);
                $('.omara-alarm-app').val(data.tpl_app);
                $('.omara-alarm-msg').val(data.tpl_msg);
                $('.omara-alarm-aduio').val(data.tpl_phone);
                $('.omara-alarm-mail').val(data.tpl_mail);
                $('.omara-alarm-wx').val(data.tpl_wx);
                var checkbox = $('.authority-host-list').children();
                var type = [128, 64, 32, 16, 8];
                var val = data.notify_mode;
                $.each(type, function (i) {
                    if (val & type[i]) {
                        checkbox.eq(i).addClass('selected').children('.checkbox-child').prop('checked', true);
                    }
                });
            },
            error: function () {

            }
        });
    });

    /**报警等级添加、编辑*/
    var alarm_rankhtml = function (o) {
        var html = '<tr id="tr-' + o.ID + '">' +
            '                        <td class="omara-textcenter">' + o.number + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' + o.level_name + '</td>' +
            '                        <td class="omara-textcenter" width="50%">' + o.type_name + '</td>' +
            '                        <td class="omara-textcenter" width="20%">' +
            '                            <a href="javascript:void (0);" class="iconfont icon-toggle omara-middle omara-fsize-28 icon-modify alarm-rank-modify" data-id="' + o.ID + '"></a>' +
            '                            <a href="javascript:void (0);" class="iconfont icon-toggle omara-middle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + o.ID + '" data-pid="tr-' + o.ID + '"></a>' +
            '                        </td>' +
            '                    </tr>';
        return html;
    };
    var alarm_rank_list = function (o) {
        var data_alert = omara_func.info_data({form: $('.set-form').find('input:text'), type: 'name'});
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"ID,' + data_alert + '","cp":"' + o.page + '","ps":"' + o.ps + '"}'},
            callback: function (datas) {
                var data = datas.data;
                var html = '';
                $.each(data, function (i, result) {
                    html += alarm_rankhtml({
                        ID: result.ID,
                        number: i,
                        level_name: result.level_name,
                        type_name: result.type_name
                    });
                });
                var page = omara_func.page_list({total: datas.total, ps: o.ps, page: o.page});
                $('.omara-page').html(page);
                $('.omara-data-list tbody').html(html);
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };
    if ($('.omara-alarm-rankadd').length > 0) {
        alarm_rank_list({
            page: 1,
            ps: 20
        });
    }
    $('.add-alarmrank-save').on('click', function () {
        var that = $(this);
        omara_func.is_validity({dom: '.omara-alarm-rankname', reg: false, reglength: true, length: 50});
        if ($('.error').length > 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.choose-checkbox').length > 0 && $('.checkbox-child:checked').length < 1) {
            omara_func.dialog_tips({show_text: '请选择设备类型', show_time: 2000});
        } else if ($('.regerrlength').length > 0) {
            $('.regerrlength').eq(0).focus();
            omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 2000});
            return false;
        } else {
            var my_group = '';
            $('.checkbox-child:checked').each(function (i) {
                if (i > 0) {
                    my_group += ',';
                }
                my_group += $(this).val();
            });
            $('input[name=equip_types]').val(my_group);
            var data = omara_func.info_data({
                form: $('.omara-art-dialog .set-form').find('input:text'),
                type: 'val+name'
            });
            var id = $('.data-ID').val();
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.data-form').attr('action'),
                data: {a: 'save', info: '{' + data + ',"id":"' + id + '"' + '}'},
                callback: function (data) {
                    var data = data.data[0];
                    if (id == '') {
                        var html = alarm_rankhtml({
                            ID: data.ID,
                            number: $('.omara-data-list tbody tr').length + 1,
                            level_name: data.level_name,
                            type_name: data.type_name
                        });
                        $('.omara-data-list tbody').append(html);
                    } else {
                        $('#tr-' + id + ' td').eq(1).text(data.level_name);
                        $('#tr-' + id + ' td').eq(2).text(data.type_name);
                    }
                    $('.checkbox-child').each(function (i) {
                        if ($(this).is(':checked')) {
                            $(this).parent().addClass('none').removeClass('hide').hide();
                        } else if (!$(this).is(':checked') && $(this).parent().hasClass('hide')) {
                            $(this).parent().removeClass('hide none').show();
                        }
                    });

                    /*保存成功清除数据，关闭弹窗*/
                    dialog_close_callback();
                },
                error: function () {

                }
            });
        }
    });
    $(document).on('click', '.alarm-rank-modify', function () {
        var that = $(this);
        var titlebar = $('.omara-art-dialog .titlebar .name');
        $('.omara-art-dialog').show();
        titlebar.text(titlebar.attr('data-art-modify'));
        $('.data-ID').val(that.attr('data-id'));
        var data_alert = omara_func.info_data({form: $('.set-form').find('input:text'), type: 'name'});
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {a: 'list', info: '{"limits":"' + data_alert + '","id":"' + that.attr('data-id') + '"}'},
            callback: function (data) {
                var data = data.data;
                $('.omara-alarm-rankname').val(data.level_name);
                omara_func.checkbox_checked({checkbox_box: '.authority-host-list', data: data.equip_types});
                $('.choose-checkbox.selected').show().addClass('hide');
            },
            error: function () {

            }
        });
    });

    /**数据管理*/
    if ($('.omara-auto-backup-save').length > 0) {
        var data = omara_func.info_data({form: $('.set-form'), type: 'name'});
        omara_func.ajax_data({
            url: $('.set-form').attr('action'),
            data: {a: 'list', info: '{"pvar":"' + data + '"}'},
            callback: function (data) {
                var data = data.data;
                $('input[name="backups_ip"]').val(data.backups_ip);
                $('input[name="backups_port"]').val(data.backups_port);
                $('input[name="backups_username"]').val(data.backups_username);
                $('input[name="backups_password"]').val(data.backups_password);
                omara_func.select_checked({
                    select: 'select[name="backups_cycle"]',
                    parameter: data.backups_cycle
                });
                omara_func.select_checked({
                    select: 'select[name="backups_time"]',
                    parameter: data.backups_time
                });
            },
            error: function () {

            }
        });

    }
    $("#up-data-revert").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.reg.isup_db(that.val()),
            errtypemsg: '格式有误，仅支持压缩格式为rar、gz的文件'
        });
        if (!that.hasClass('err')) {
            that.siblings('span').text('正在处理');
            that.before('<img src="/static/images/loading.svg" width="18" class="omara-middle omara-mleft-5"/>');
            omara_func.update_ajaxform({
                dom: '.set-form',
                updom: 'up-data-revert',
                url: that.attr('data-post'),
                callback: function (data) {
                    $('.data-revert').val(that.val());
                    that.siblings('span').text('还原');
                    that.siblings('img').remove();
                }
            });
        }
    });
    $("#up-data-revert2").on('change', function () {
        var that = $(this);
        omara_func.is_file({
            dom: that,
            reg: !omara_func.reg.isup_ini(that.val()),
            errtypemsg: '格式有误，仅支持ini格式的文件'
        });
        if (!that.hasClass('err')) {
            that.siblings('span').text('正在处理');
            that.before('<img src="/static/images/loading.svg" width="18" class="omara-middle omara-mleft-5"/>');
            omara_func.update_ajaxform({
                dom: '.set-form',
                updom: 'up-data-revert2',
                url: that.attr('data-post'),
                callback: function (data) {
                    $('.data-revert2').val(that.val());
                    that.siblings('span').text('还原');
                    that.siblings('img').remove();
                }
            });
        }
    });
    $('.omara-auto-backup-save').on('click', function () {
        var that = $(this);
        omara_func.is_validity({
            dom: '.omara-ftp',
            reg: !omara_func.reg.is_ip($('.omara-ftp').val()),
            reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.omara-port',
            reg: !omara_func.reg.is_post($('.omara-port').val()),
            reglength: false,
            length: 20
        });
        omara_func.is_validity({dom: '.omara-user', reg: false, reglength: true, length: 50});
        omara_func.is_validity({
            dom: '.omara-pwd',
            reg: !omara_func.reg.is_pwd($('.omara-pwd').val()),
            reglength: false,
            length: 20
        });
        if ($('.error').length > 0 && $('.regerr').length === 0) {
            $('.error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else if ($('.regerr').length > 0 && $('.error').length >= 0) {
            $('.regerr').eq(0).focus();
            omara_func.dialog_tips({show_text: '格式有误', show_time: 2000});
            return false;
        } else {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            omara_func.proccess({dom: that});
            omara_func.ajax_data({
                url: $('.set-form').attr('action'),
                data: {a: 'save', info: '{' + data + '}'},
                callback: function (data) {

                },
                error: function () {

                }
            });
        }
    });
    /**参数设置*/
    if ($('#up-logo').length > 0) {
        var data = omara_func.info_data({form: $('.set-form'), type: 'name'});
        omara_func.ajax_data({
            url: $('.set-form').attr('action'),
            data: {a: 'list', info: '{"pvar":"' + data + '"}'},
            callback: function (d) {
                var data = d.data;
                $('.omara-logo-thumb').css({'background-image': 'url("' + data.logo + '")'});
                $('#up-logo-detail').val(data.logo);
                $('.omara-map-thumb').css({'background-image': 'url("' + data.map_url + '")'});
                $('#up-map-detail').val(data.map_url);
                $('#up-login-background-detail').val(data.login_background);
                $('.omara-login-background-thumb').css({'background-image': 'url("' + data.login_background + '")'});
                $('#up-login-logo-detail').val(data.login_logo);
                $('.omara-login-logo-thumb').css({'background-image': 'url("' + data.login_logo + '")'});
                $('input[name=login_corporate_name]').val(data.login_corporate_name);
                $('input[name=login_phone]').val(data.login_phone);
                $('input[name=login_qq]').val(data.login_qq);
                $('input[name=login_email]').val(data.login_email);
                $('#up-login-qr-code-detail').val(data.login_qr_code);
                $('.omara-login-qr-code-thumb').css({'background-image': 'url("' + data.login_qr_code + '")'});
                $('input[name="login_attempt_limit"]').val(data.login_attempt_limit);
                $('input[name="login_locking"]').val(data.login_locking);
                $('input[name=clear_data]').val(data.clear_data);
                $('input[name=session_time]').val(data.session_time);
                $('input[name=authorization_code]').val(data.authorization_code);
                $('input[name=site_name]').val(data.site_name);
                $('input[name=sms_content]').val(data.sms_content);
                $('input[name=alarm_msg_num]').val(data.alarm_msg_num);
                $('input[name=bn_interval]').val(data.bn_interval);
                $('input[name=ys7_appKey]').val(data.ys7_appKey);
                $('input[name=ys7_appSecret]').val(data.ys7_appSecret);
                $('input[name=ums_SpCode]').val(data.ums_SpCode);
                $('input[name=ums_LoginName]').val(data.ums_LoginName);
                $('input[name=ums_Password]').val(data.ums_Password);
                if (data.map_type == '0') {
                    $('.up-map-box').show();
                    $('.choose-map').eq(0).prop('checked', false).parent().removeClass('selected');
                    $('.choose-map').eq(1).prop('checked', true).parent().addClass('selected');
                } else {
                    $('.choose-map').eq(1).prop('checked', false).parent().removeClass('selected');
                    $('.choose-map').eq(0).prop('checked', true).parent().addClass('selected');
                    $('.up-map-box').hide();
                }
                if (data.alarm_popup == '1') {
                    $('.choose-alarm-popup').eq(0).prop('checked', false).parent().removeClass('selected');
                    $('.choose-alarm-popup').eq(1).prop('checked', true).parent().addClass('selected');
                } else {
                    $('.choose-alarm-popup').eq(1).prop('checked', false).parent().removeClass('selected');
                    $('.choose-alarm-popup').eq(0).prop('checked', true).parent().addClass('selected');
                }
                omara_func.select_checked({
                    select: 'select[name=theme]',
                    parameter: data.theme
                });
                omara_func.select_checked({
                    select: 'select[name=equipments_type]',
                    parameter: data.equipments_type
                });
                omara_func.select_checked({
                    select: '.parameters-shielding-alarm',
                    parameter: data.shielding_alarm
                });
                omara_func.select_checked({
                    select: '.parameters-icon-type',
                    parameter: data.icon_type
                });
            },
            error: function () {

            }
        });
        $("#up-logo").on('change', function () {
            var that = $(this);
            omara_func.is_file({
                dom: that,
                reg: !omara_func.isup_img(that.val()),
                errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
            });
            if (!that.hasClass('err')) {
                omara_func.update_ajaxform({
                    dom: '.set-form',
                    updom: 'up-logo',
                    url: that.attr('data-post'),
                    callback: function (data) {
                        $('#up-logo-detail').val(data);
                        $('.omara-logo-thumb').css({'background-image': 'url("' + data + '")'});
                    }
                });
            }
        });
        $('.choose-map').on('click', function () {
            if ($(this).attr('id') == 'offline-map') {
                $('.up-map-box').show();
            } else {
                $('.up-map-box').hide();
            }
        });
        $("#up-map").on('change', function () {
            var that = $(this);
            omara_func.is_file({
                dom: that,
                reg: !omara_func.isup_img(that.val()),
                errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
            });
            if (!that.hasClass('err')) {
                omara_func.update_ajaxform({
                    dom: '.set-form',
                    updom: 'up-map',
                    url: that.attr('data-post'),
                    callback: function (data) {
                        $('#up-map-detail').val(data);
                        $('.omara-map-thumb').css({'background-image': 'url("' + data + '")'});
                    }
                });
            }
        });
        $("#up-login-background").on('change', function () {
            var that = $(this);
            omara_func.is_file({
                dom: that,
                reg: !omara_func.isup_img(that.val()),
                errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
            });
            if (!that.hasClass('err')) {
                omara_func.update_ajaxform({
                    dom: '.set-form',
                    updom: 'up-login-background',
                    url: that.attr('data-post'),
                    callback: function (data) {
                        $('#up-login-background-detail').val(data);
                        $('.omara-login-background-thumb').css({'background-image': 'url("' + data + '")'});
                    }
                });
            }
        });
        $("#up-login-logo").on('change', function () {
            var that = $(this);
            omara_func.is_file({
                dom: that,
                reg: !omara_func.isup_img(that.val()),
                errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
            });
            if (!that.hasClass('err')) {
                omara_func.update_ajaxform({
                    dom: '.set-form',
                    updom: 'up-login-logo',
                    url: that.attr('data-post'),
                    callback: function (data) {
                        $('#up-login-logo-detail').val(data);
                        $('.omara-login-logo-thumb').css({'background-image': 'url("' + data + '")'});
                    }
                });
            }
        });
        $("#up-login-qr-code").on('change', function () {
            var that = $(this);
            omara_func.is_file({
                dom: that,
                reg: !omara_func.isup_img(that.val()),
                errtypemsg: '图片格式有误，仅支持jpg,png,gif格式的图片'
            });
            if (!that.hasClass('err')) {
                omara_func.update_ajaxform({
                    dom: '.set-form',
                    updom: 'up-login-qr-code',
                    url: that.attr('data-post'),
                    callback: function (data) {
                        $('#up-login-qr-code-detail').val(data);
                        $('.omara-login-qr-code-thumb').css({'background-image': 'url("' + data + '")'});
                    }
                });
            }
        });
        $('.parameter-tabs .tabs-items').on('click', function (i) {
            $(this).addClass('active').siblings().removeClass('active');
            var index = $(this).index();
            $('.parameter-tcontent').eq(index).show().siblings('.parameter-tcontent').hide();
        });
        $('.omara-system-parameter').on('click', function () {
            var data = omara_func.info_data({form: $('.set-form'), type: 'val+name'});
            if ($('input[name=site_name]').val().length > 50) {
                omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 1000});
                $('input[name=site_name]').focus();
                return;
            } else if ($('.choose-map:checked').attr('id') == 'offline-map' && $('#up-map-detail').val() == '') {
                omara_func.dialog_tips({show_text: '请上传地图', show_time: 1000});
                return;
            }
            if ($('input[name=authorization_code]').val().length > 200) {
                omara_func.dialog_tips({show_text: '您输入的字符过长，请修改', show_time: 1000});
                $('input[name=authorization_code]').focus();
                return;
            } else {
                omara_func.ajax_data({
                    url: $('.set-form').attr('action'),
                    data: {
                        a: 'save',
                        info: '{' + data + ',"' + $('.choose-map:checked').attr('name') + '":"' + $('.choose-map:checked').val() + '"}'
                    },
                    callback: function (data) {
                    },
                    error: function () {

                    }
                });
            }

        });
    }
    /*系统设置 end*/


    /*告警弹窗**/
    var alarm_data = function (o) {
        $('.new-alarm-submit').attr('data-disabled', true).removeClass('input-btn-disabled');
        var total = 0;

        omara_func.ajax_data({
            url: $('.new-alarm-form').attr('action'),
            data: {
                a: 'alarm_popup',
                info: '{"limits":"ID,eq_sn,eq_no,alert_item,alert_value,pubdate,alert_level,alert_status,is_confirmed,alm_img,relieve_type","ps":"1","cp":"' + o.cp + '"}'
            },
            callback: function (data) {
                var datas = data.data[0];
                total = parseInt(data.total);
                $('.new-alarm-art .alarm-name').text(datas.name);
                $('.new-alarm-art .alarm-equip').text(datas.eq_name);
                $('.new-alarm-art .alarm-item').text(datas.alert_item + (datas.alert_value == '' ? '' : '（' + datas.alert_value + '）'));
                $('.new-alarm-art .alarm-status').text(datas.alert_status == '0' ? '告警' : '故障');
                $('.new-alarm-art  .details-alarm-submit').attr('href', datas.urlEquipments);
                $('.new-alarm-art .current-num').text(o.cp + '/' + total + '条');

                $('.new-alarm-art .art-titlebar .name').text('共有' + (total > 999 ? '999+' : total) + '条告警信息');
                if (o.firstLoad) {
                    if (total > 0) {
                        $('.new-alarm-art').addClass('active').removeClass('min-art');
                        $('.new-alarm-art .icon-alarm-tips').addClass('active');
                    } else {
                        $('.new-alarm-art').addClass('min-art').removeClass('active');
                        $('.new-alarm-art .icon-alarm-tips').removeClass('active');
                    }
                } else {
                    if (total < 1) {
                        $('.new-alarm-art').addClass('min-art').removeClass('active');
                        $('.new-alarm-art .icon-alarm-tips').removeClass('active');
                    } else {
                        if ($('.new-alarm-art').hasClass('min-art')) {
                            $('.new-alarm-art .icon-alarm-tips').addClass('active');
                        }
                    }
                }

                setTimeout(function () {
                    if (total > 0) {
                        document.getElementById('alarm-audio').load();
                        document.getElementById('alarm-audio').play();

                    } else {
                        document.getElementById('alarm-audio').pause();
                    }
                }, 1000);
                $('.new-alarm-art').attr('data-total', total);
                $('.new-alarm-art').attr('data-id', datas.ID);
            },
            error: function () {
                $('.new-alarm-art .art-titlebar .name').text('共有0条告警信息');
                $('.new-alarm-art .current-num').text(0 + '/' + 0 + '条');
                $('.new-alarm-art').addClass('min-art').removeClass('active');
                $('.new-alarm-art').attr('data-id', '');
                $('.new-alarm-art').attr('data-total', 0);
                $('.new-alarm-art .icon-alarm-tips').removeClass('active');
                document.getElementById('alarm-audio').pause();
            }
        });

    };

    window.onload = function () {
        if (document.readyState == "complete") {
            if ($('.new-alarm-art').length > 0) {
                alarm_data({
                    cp: 1,
                    firstLoad: true
                });


                setInterval(function () {
                    alarm_data({
                        cp: alarm_num,
                        firstLoad: false
                    });
                }, 15000);
            }
        }
    };

    /*上一条，下一条*/
    var alarm_num = 1;
    $(document).on('click', '.alarm-prev-page', function () {

        if (alarm_num > 1) {
            alarm_num--;
            alarm_data({
                cp: alarm_num,
                firstLoad: false
            })
        }

    });
    $(document).on('click', '.alarm-next-page', function () {
        var total = parseInt($('.new-alarm-art').attr('data-total'));
        if (alarm_num < total) {
            alarm_num++;
            alarm_data({
                cp: alarm_num,
                firstLoad: false
            });
        }
    });
    /*确认单条告警信息*/
    $(document).on('click', '.new-alarm-submit', function () {
        var that = $(this);
        if (that.attr('data-disabled') == 'true') {
            omara_func.ajax_data({
                url: $('.new-alarm-form').attr('action'),
                data: {
                    a: 'confirm',
                    info: '{"id":"' + $('.new-alarm-art').attr('data-id') + '"}'
                },
                callback: function (data) {
                    that.attr('data-disabled', false).addClass('input-btn-disabled');
                    var total = parseInt($('.new-alarm-art').attr('data-total'));
                    // $('.new-alarm-art .art-titlebar .name').text('共有'+((total-1) > 999 ?'999+':(total-1))+'条告警信息');
                    // $('.new-alarm-art .current-num').text(alarm_num+'/'+(total-1)+'条');
                    if ((total - 1) > 0) {
                        $('.new-alarm-art').addClass('active').removeClass('min-art');
                    } else {
                        $('.new-alarm-art').addClass('min-art').removeClass('active');
                        $('.new-alarm-art').attr('data-id', '');
                        $('.new-alarm-art .icon-alarm-tips').removeClass('active');
                        document.getElementById('alarm-audio').pause();
                    }

                },
                error: function () {
                    that.attr('data-disabled', true).removeClass('input-btn-disabled');
                }
            });
        }
    });

    $('.all-alarm-submit').on('click', function () {
        var that = $(this);
        omara_func.dialog_confirm({
            show_text: '确定确认全部告警信息吗？',
            dialog_id: 'all-alert-confirm'
        });
    });

    /*!点击确定按钮 进行功能操作*/
    $(document).on('click', "#all-alert-confirm .btn-confirm", function () {
        var that = $(this);
        omara_func.ajax_data({
            url: $('.new-alarm-form').attr('action'),
            data: {
                a: 'allConfirm',
                info: '{}'
            },
            callback: function (data) {
                $('.new-alarm-art .art-titlebar .name').text('共有0条告警信息');
                $('.new-alarm-art .current-num').text(0 + '/' + 0 + '条');
                $('.new-alarm-art').addClass('min-art').removeClass('active');
                $('.new-alarm-art').attr('data-id', '');
                $('.new-alarm-art').attr('data-total', 0);
                $('.new-alarm-art .icon-alarm-tips').removeClass('active');
                document.getElementById('alarm-audio').pause();
            },
            error: function () {

            }
        });
        $('.dialog-confirm').remove();
    });
    /*缩小弹窗*/
    $(document).on('click', '.art-window-close', function () {
        $('.art-shaow').toggle();
        $(this).toggleClass('active');

        $('.new-alarm-art').toggleClass('active');
        if ($(this).hasClass('active')) {
            $('.new-alarm-art').toggleClass('min-art');
        } else {
            $('.new-alarm-art').toggleClass('min-art');
        }
    });
    /*显示弹窗*/
    $(document).on('click', '.new-alarm-art.min-art .art-titlebar', function () {
        var total = parseInt($('.new-alarm-art').attr('data-total'));
        if (total > 0) {
            $('.art-shaow').toggle();
            $('.new-alarm-art').toggleClass('active');
            $('.art-window-close').toggleClass('active');
            $('.new-alarm-art').toggleClass('min-art');
        }
    });

    /*萤石视频 按钮控制start*/
    $('.ysControl').on('mousedown', function () {
        var that = $(this);
        var type = that.attr('data-stype');
        var id = that.attr('data-cid');
        var data = {a: 'control', info: '{"type":"' + type + '","cid":"' + id + '"}'};
        omara_func.ajax_data({
            url: $('#operate').attr('data-yscontrol'),
            data: data,
            callback: function (data) {

            },
            error: function () {

            }
        });
    });
    $('.ysControl').on('mouseup', function () {
        var that = $(this);
        var type = that.attr('data-etype');
        var id = that.attr('data-cid');
        var data = {a: 'control', info: '{"type":"' + type + '","cid":"' + id + '"}'};
        omara_func.ajax_data({
            url: $('#operate').attr('data-yscontrol'),
            data: data,
            callback: function (data) {

            },
            error: function () {

            }
        });
    });
    $('.ysControl-turn').on('click', function () {
        var that = $(this);
        var type = that.attr('data-type');
        var id = that.attr('data-cid');
        var data = {a: 'control', info: '{"type":"' + type + '","cid":"' + id + '"}'};
        omara_func.ajax_data({
            url: $('#operate').attr('data-yscontrol'),
            data: data,
            callback: function (data) {

            },
            error: function () {

            }
        });
    });
    /*萤石视频 按钮控制end*/

    /*我的分组-能耗统计设置 start*/
    $(document).on('click', '.equip-elec-set', function () {
        var that = $(this);
        $('.equit-elec-set-box,.omara-parameter-setting.room-energy-type').show();
        $('.omara-parameter-setting.room-energy-type tbody tr').remove();
        var type = $('.equit-elec-set-box').attr('data-type');
        var retype = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"' + $('.equit-elec-set-box').attr('data-limits') + '","id":"' + that.attr('data-id') + '",' + retype + '}'
            },
            callback: function (data) {
                var datas = data.data;
                var energy = (datas.energy == '' ? [] : JSON.parse(datas.energy));
                $('.equit-elec-set-box .data-ID').val(that.attr('data-id'));
                $('.equit-elec-set-box').attr('data-arrEquipments', datas.arrEquipments);
                var html = '';
                var td = '';
                var option1 = '';
                var option2 = '';
                var arrEquipments = JSON.parse(datas.arrEquipments);
                $.each(energy, function (i, res) {
                    td = '';
                    $.each(res.variable, function (m, rmes) {
                        option1 = '';
                        $.each(arrEquipments, function (a, resa) {
                            if (resa.eq_no == rmes.eq_no) {
                                option2 = '';
                                $.each(resa.arrMonitor, function (ra, rmesm) {
                                    option2 += '<option value="' + rmesm.field_name + '" ' + (rmes.field_name == rmesm.field_name ? 'selected' : '') + '>' + rmesm.field_name + '</option>';
                                });
                            }
                            option1 += '<option value="' + resa.eq_sn + '" ' + (rmes.eq_no == resa.eq_no ? 'selected' : '') + ' data-sn="' + resa.eq_sn + '" data-no="' + resa.eq_no + '" data-spec="' + resa.spec + '" data-type_id="' + resa.type_id + '" data-index="' + a + '">' + resa.eq_name + '</option>';
                        });
                        td += '<div class="input-box new-elec-attr-box omara-mbotom-10 omara-displayblock">' +
                            '<span>变量：</span>' +
                            '<span class="args-name">' + rmes.name + '</span>' +
                            ' - ' +
                            '<select class="input-select args-type">' +
                            option1 +
                            '</select>' +
                            ' - ' +
                            '<select class="input-select args-type-name">' +
                            option2 +
                            '</select>' +
                            '<i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle" data-tr_i="' + i + '" title="删除本行"></i>' +
                            '</div>';

                    });
                    html += '<tr>' +
                        '<td width="500">' +
                        '<span class="input-name omara-textright omara-mbotom-10">名称：</span>' +
                        '<input type="text" class="input-text elec-name omara-mbotom-10" name="elec-name"' +
                        'size="46" value="' + res.name + '">' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10">公式：</span>' +
                        '<input type="text" class="input-text elec-formula omara-mbotom-10" name="elec-formula" size="46" value="' + res.formula + '">' +
                        '</div>' +
                        '<div class="unit-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10">单位：</span>' +
                        '<input type="text" class="input-text elec-unit omara-mbotom-10" name="elec-unit" size="46" value="' + res.unit + '">' +
                        '</div>' +
                        '<div class="elec-attr-box omara-mbotom-10 omara-displayblock">' +
                        td +
                        '<i class="iconfont icon-add new-elec-attr omara-middle omara-fsize-24 omara-displayline" title="添加一行" data-tr_i="' + i + '"></i>' +
                        '</div>' +
                        '</td>' +
                        '<td class="omara-textcenter">' +
                        '<i class="iconfont icon-reduce remove-tr-row-box omara-fsize-24 omara-mleft-5 omara-middle pu-right" title="删除行"></i>' +
                        '</td>' +
                        '</tr>';
                });
                $('.omara-parameter-setting.room-energy-type tbody ').html(html);

            },
            error: function () {

            }
        });
    });
    $(document).on('click', '.equit-elec-set-box .elec-dialog-close', function () {
        $('.equit-elec-set-box').hide();
    });
    $(document).on('click', '.remove-tr-row-box', function () {
        $(this).parent().parent().remove();
    });
    $(document).on('click', '.add-elec-attr-tr-row', function () {
        var length = $('.omara-parameter-setting.room-energy-type tbody tr').length;
        var character = omara_func.character(length);
        var html = '<tr>' +
            '<td width="500">' +
            '<span class="input-name omara-textright omara-mbotom-10">名称：</span>' +
            '<input type="text" class="input-text elec-name omara-mbotom-10" name="elec-name"' +
            'size="46">' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10">公式：</span>' +
            '<input type="text" class="input-text elec-formula omara-mbotom-10" name="elec-formula" size="46">' +
            '</div>' +
            '<div class="unit-box">' +
            '<span class="input-name omara-textright omara-mbotom-10">单位：</span>' +
            '<input type="text" class="input-text elec-unit omara-mbotom-10" name="elec-unit" size="46">' +
            '</div>' +
            '<div class="elec-attr-box omara-mbotom-10 omara-displayblock">' +
            '<i class="iconfont icon-add new-elec-attr omara-middle omara-fsize-24 omara-displayblock" title="添加一行" data-tr_i="' + length + '"></i>' +
            '</div>' +
            '</td>' +
            '<td class="omara-textcenter">' +
            '<i class="iconfont icon-reduce remove-tr-row-box omara-fsize-24 omara-mleft-5 omara-middle pu-right" title="删除行"></i>' +
            '</td>' +
            '</tr>';
        $('.omara-parameter-setting.room-energy-type tbody').append(html);
    });
    $(document).on('click', '.new-elec-attr', function () {
        var length = $(this).siblings('.new-elec-attr-box').length;
        var arrEquipments = JSON.parse($('.equit-elec-set-box').attr('data-arrEquipments'));
        var option1 = '';
        var option2 = '';
        $.each(arrEquipments, function (i, res) {
            if (i == 0) {
                $.each(res.arrMonitor, function (m, rmes) {
                    option2 += '<option value="' + rmes.field_name + '">' + rmes.field_name + '</option>';
                });
            }
            option1 += '<option value="' + res.eq_sn + '" data-sn="' + res.eq_sn + '" data-no="' + res.eq_no + '" data-spec="' + res.spec + '" data-type_id="' + res.type_id + '" data-index="' + i + '">' + res.eq_name + '</option>';
            console.log(res);
        });
        var character = omara_func.character(length);
        var html = '<div class="input-box new-elec-attr-box omara-mbotom-10 omara-displayblock">' +
            '<span>变量：</span>' +
            '<span class="args-name">' + character.toLowerCase() + '</span>' +
            ' - ' +
            '<select class="input-select args-type">' +
            option1 +
            '</select>' +
            ' - ' +
            '<select class="input-select args-type-name">' +
            option2 +
            '</select>' +
            '<i class="iconfont icon-reduce remove-attr-box omara-fsize-24 omara-mleft-5 omara-middle" data-tr_i="' + $(this).attr('data-tr_i') + '" title="删除本行"></i>' +
            '</div>';

        $(this).before(html);
    });
    $(document).on('click', '.remove-attr-box', function () {
        var that = $(this);
        var tr_index = parseInt(that.attr('data-tr_i'));
        $('.omara-parameter-setting.room-energy-type tbody tr').eq(tr_index).find('.new-elec-attr-box').each(function (i) {
            var spanthat = $(this);
            spanthat.find('.args-name').text(omara_func.character(i).toLowerCase());
        })
    });
    $(document).on('change', '.args-type', function () {
        var that = $(this);
        var option1 = '';
        var arrEquipments = JSON.parse($('.equit-elec-set-box').attr('data-arrEquipments'));
        var index = parseInt(that.children('option:selected').attr('data-index'));
        $.each(arrEquipments[index].arrMonitor, function (i, res) {
            option1 += '<option value="' + res.field_name + '">' + res.field_name + '</option>';
        });
        console.log(option1);
        that.siblings('.args-type-name').html(option1);
    });
    $(document).on('click', '.remove-tr-row-box', function () {
        $(this).parent().parent().remove();
    });
    $(document).on('click', '.equit-elec-set-save', function () {
        var val = '';
        $('.omara-parameter-setting.room-energy-type .input-text').each(function (t) {
            var inputthat = $(this);
            omara_func.is_validity_mul({
                dom: inputthat, reg: false, reglength: false,
                length: 20
            });
        });
        if ($('.omara-parameter-setting.room-energy-type tbody tr').length == 0) {
            omara_func.dialog_tips({show_text: '请添加属性行', show_time: 2000});
            return false;
        } else if ($('.omara-parameter-setting.room-energy-type .error').length > 0) {
            $('.omara-parameter-setting.room-energy-type .error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var args = '';
            $('.omara-parameter-setting.room-energy-type tbody tr').each(function (t) {
                var that = $(this);
                var variable = '';

                that.find('.new-elec-attr-box').each(function (i) {
                    var th = $(this);
                    if (i > 0) {
                        variable += ',';
                    }
                    variable += '{' +
                        '"name": "' + th.find('.args-name').text() + '", ' +
                        '"eq_sn": "' + th.find('.args-type option:selected').val() + '", ' +
                        '"eq_no": "' + th.find('.args-type option:selected').attr('data-no') + '", ' +
                        '"field_name": "' + th.find('.args-type-name option:selected').val() + '",' +
                        '"type_id":"' + th.find('.args-type option:selected').attr('data-type_id') +
                        '","spec":"' + th.find('.args-type option:selected').attr('data-spec') + '"' +
                        '}';
                });
                args += (t > 0 ? ',' : '') + '{' +
                    '"name": "' + that.find('.elec-name').val() + '", ' +
                    '"formula": "' + that.find('.elec-formula').val() + '",' +
                    '"unit": "' + that.find('.elec-unit').val() + '",' +
                    '"variable": [' + variable + ']}';
            });
            omara_func.ajax_data({
                url: $('.equit-elec-set-box .set-form').attr('action'),
                data: {
                    a: 'save',
                    info: '{"id":"' + $('.equit-elec-set-box .data-ID').val() + '","energy":[' + args + ']}'
                },
                callback: function (data) {
                    $('.omara-parameter-setting.room-energy-type tbody tr').remove();
                    $('.equit-elec-set-box').hide();
                },
                error: function () {

                }
            });
        }

    });
    /*我的分组-能耗统计设置 end*/

    /*我的分组-海康视频设置 start*/
    $(document).on('click', '.room-haikang-set', function () {
        var that = $(this);
        $('.room-haikang-set-box,.omara-parameter-setting.room-haikang-type').show();
        $('.omara-parameter-setting.room-haikang-type tbody tr').remove();
        var type = $('.room-haikang-set-box').attr('data-type');
        var retype = type.replace(/'/g, '"');
        omara_func.ajax_data({
            url: $('.data-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"' + $('.room-haikang-set-box').attr('data-limits') + '","id":"' + that.attr('data-id') + '",' + retype + '}'
            },
            callback: function (data) {
                var datas = data.data;
                $('.room-haikang-set-box .data-ID').val(that.attr('data-id'));
                var html = '';
                var td = '';
                var hikvision = (datas.hikvision == '' ? [] : JSON.parse(datas.hikvision));
                $.each(hikvision, function (i, res) {
                    td = '';
                    html += '<tr>' +
                        '<td width="500">' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">名称：</span>' +
                        '<input type="text" class="input-text haikang-name omara-mbotom-10" name="haikang-name"' +
                        'size="46" value="' + res.name + '">' +
                        '</div>' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">IP地址：</span>' +
                        '<input type="text" class="input-text haikang-ip omara-mbotom-10" name="haikang-ip" size="46" value="' + res.szIP + '">' +
                        '</div>' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">端口：</span>' +
                        '<input type="text" class="input-text haikang-port omara-mbotom-10" name="haikang-port" size="46" value="' + res.szPort + '">' +
                        '</div>' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">用户名：</span>' +
                        '<input type="text" class="input-text haikang-user omara-mbotom-10" name="haikang-user" size="46" value="' + res.szUsername + '">' +
                        '</div>' +
                        '<div class="formula-box">' +
                        '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">密码：</span>' +
                        '<input type="password" class="input-text haikang-pwd omara-mbotom-10" name="haikang-pwd" size="46" value="' + res.szPassword + '">' +
                        '</div>' +
                        '</td>' +
                        '<td class="omara-textcenter">' +
                        '<i class="iconfont icon-reduce remove-haikang-row-box omara-fsize-24 omara-mleft-5 omara-middle pu-right" title="删除行"></i>' +
                        '</td>' +
                        '</tr>';
                });
                $('.omara-parameter-setting.room-haikang-type tbody ').html(html);

            },
            error: function () {

            }
        });
    });
    $(document).on('click', '.room-haikang-set-box .elec-dialog-close', function () {
        $('.room-haikang-set-box').hide();
    });
    $(document).on('click', '.remove-haikang-row-box', function () {
        $(this).parent().parent().remove();
    });
    $(document).on('click', '.add-room-haikang-tr-row', function () {
        var character = omara_func.character(length);
        var html = '<tr>' +
            '<td width="500">' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">名称：</span>' +
            '<input type="text" class="input-text haikang-name omara-mbotom-10" name="haikang-name" size="46" value="">' +
            '</div>' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">IP地址：</span>' +
            '<input type="text" class="input-text haikang-ip omara-mbotom-10" name="haikang-ip" size="46" value="">' +
            '</div>' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">端口：</span>' +
            '<input type="text" class="input-text haikang-port omara-mbotom-10" name="haikang-port" size="46" value="">' +
            '</div>' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">用户名：</span>' +
            '<input type="text" class="input-text haikang-user omara-mbotom-10" name="haikang-user" size="46" value="">' +
            '</div>' +
            '<div class="formula-box">' +
            '<span class="input-name omara-textright omara-mbotom-10 width100 omara-displayline">密码：</span>' +
            '<input type="password" class="input-text haikang-pwd omara-mbotom-10" name="haikang-pwd" size="46" value="">' +
            '</div>' +
            '</td>' +
            '<td class="omara-textcenter">' +
            '<i class="iconfont icon-reduce remove-tr-row-box omara-fsize-24 omara-mleft-5 omara-middle pu-right" title="删除行"></i>' +
            '</td>' +
            '</tr>';
        $('.omara-parameter-setting.mdevice_type tbody').append(html);
    });
    $(document).on('click', '.room-haikang-set-save', function () {
        var val = '';
        $('.omara-parameter-setting.room-haikang-type .input-text').each(function (t) {
            var inputthat = $(this);
            omara_func.is_validity_mul({
                dom: inputthat, reg: false, reglength: false,
                length: 20
            });
        });
        if ($('.omara-parameter-setting.room-haikang-type tbody tr').length == 0) {
            omara_func.dialog_tips({show_text: '请添加属性行', show_time: 2000});
            return false;
        } else if ($('.omara-parameter-setting.room-haikang-type .error').length > 0) {
            $('.omara-parameter-setting.room-haikang-type .error').eq(0).focus();
            omara_func.dialog_tips({show_text: '请填写此项', show_time: 2000});
            return false;
        } else {
            var args = '';
            $('.omara-parameter-setting.room-haikang-type tbody tr').each(function (t) {
                var that = $(this);
                if (t > 0) {
                    args += ',';
                }
                args += '{' +
                    '"name": "' + that.find('.haikang-name').val() + '", ' +
                    '"szIP": "' + that.find('.haikang-ip').val() + '",' +
                    '"szPort": "' + that.find('.haikang-port').val() + '",' +
                    '"szUsername": "' + that.find('.haikang-user').val() + '",' +
                    '"szPassword": "' + that.find('.haikang-pwd').val() + '"}';
            });
            omara_func.ajax_data({
                url: $('.room-haikang-set-box .set-form').attr('action'),
                data: {
                    a: 'save',
                    info: '{"id":"' + $('.room-haikang-set-box .data-ID').val() + '","hikvision":[' + args + ']}'
                },
                callback: function (data) {
                    $('.omara-parameter-setting.room-haikang-type tbody tr').remove();
                    $('.room-haikang-set-box').hide();
                },
                error: function () {

                }
            });
        }

    });
    /*我的分组-海康视频设置 start*/

    /*机房-健康度统计 start*/
    var group_statistics = function (o) {
        var fdate = $('.start-date').val();
        var edate = $('.end-date').val();
        var date_type = $('.query-data-select option:selected').val();
        var data = omara_func.info_data({form: $('.data-health-inquire'), type: 'val+name'});
        var id = omara_func.getQueryVariable('id');
        var exceldata = ('id=' + id + '&date_type=' + date_type + '&fdate=' + fdate + '&edate=' + edate);
        $('.export-excel').attr('href', $('.export-excel').attr('data-url') + exceldata);
        omara_func.ajax_data({
            url: $('.data-health-inquire').attr('action'),
            data: {
                a: 'statistics',
                info: '{' + data + ',"id":"' + id + '"}'
            },
            callback: function (data) {
                var html = '';
                var alert_html = '';
                $.each(data.data, function (i, res) {
                    html += ' <tr>' +
                        '                    <td class="omara-textcenter">' + res.index + '</td>' +
                        '                    <td>' + res.eq_name + '</td>' +
                        '                    <td class="omara-textcenter">' + res.number + '</td>' +
                        '                </tr>';
                });
                $.each(data.alerts, function (i, res) {
                    alert_html += '<div class="width20p omara-displayline">' + res.name + '：' + res.value + '</div>';
                });
                $('.omara-data-list tbody').html(html);
                $('.data-health-res').html(alert_html);

            },
            error: function () {

            }
        });
    };
    if ($('.data-health-inquire').length > 0) {
        group_statistics();
        $('.omara-data-health').on('click', function () {
            var that = $(this);
            omara_func.proccess({dom: that});
            group_statistics();
        });
    }

    /*机房-健康度统计 end*/

    /*门禁 start*/

    var menjin_list = function (o) {
        var data = omara_func.info_data({
            form: $('.entrance-guard-dialog .entrance-guard-set-form'),
            type: 'name'
        });
        omara_func.ajax_data({
            url: $('.data-form').attr('action')||$('.entrance-guard-form').attr('data-url'),
            data: {
                a: 'list',
                info: '{"limits":"' + data+o.data + '","ps":"' + o.ps + '","cp":"' + o.page + '"}'
            },
            callback: function (d) {
                var data = d.data;
                var html = '';
                var html2 = '';

                $.each(data, function (i, res) {
                    html2 += '<option value="' + res.login + '" data-user="'+res.username+'" data-pwd="'+res.pwd+'" data-logid="'+res.logId+'">'+res.name+'</option>';
                    html += '<tr id="tr-' + res.ID + '">' + '<td width="30%">' + res.name + '</td>\n' + '<td width="50%">' + res.login + '</td>\n' + '<td class="omara-textcenter" width="20%">\n' + '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify entrance-guard-set"  data-id="' + res.ID + '"></a>\n' + '<a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + res.ID + '" data-pid="tr-' + res.ID + '"></a>' + '</td>\n' + ' </tr>';
                });
                if ($('.entrance-guard-dialog').length > 0) {
                    var page = omara_func.page_list({
                        total: d.total,
                        ps: o.ps,
                        page: o.page
                    });
                    $('.omara-page').html(page);
                    $('.omara-data-list tbody').html(html);
                }
                if ($('.entrance-guard-iframe').length > 0) {
                    $(".entrance-guard").html(html2);
                    if(data.length >0){
                        $('.entrance-guard-form').attr('action',data[0].login);
                        $('.entrance-guard-form .username').val(data[0].username);
                        $('.entrance-guard-form .pwd').val(data[0].pwd);
                        $('.entrance-guard-form .logId').val(data[0].logId);
                        $(".entrance-guard-form").submit();
                    }
                }
            },
            error: function () {
                $('.omara-page').html('');
            }
        });
    };

    if ($('.entrance-guard-dialog').length > 0) {
        menjin_list({
            ps: 20,
            page: 1,
            data:''
        });
    }
    if ($('.entrance-guard-iframe').length > 0) {
        menjin_list({
            ps: 999999,
            page: 1,
            data:'ID,name,login,username,pwd,logId'
        });
    }

    $('.new-entrance-guard').on('click', function () {
        $('.entrance-guard-dialog').show();
        $('.entrance-guard-dialog input').val('');
    });
    $(document).on('click', '.entrance-guard-dialog .default-dialog-close', function () {
        $('.entrance-guard-dialog').hide();
        $('.entrance-guard-dialog input').val('');
    });
    $('.entrance-guard-save').on('click', function () {
        var that = $(this);
        omara_func.is_validity({
            dom: '.entrance-guard-name',
            reg: false,
            reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.entrance-guard-addr',
            reg: false,
            reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.entrance-guard-user',
            reg: false,
            reglength: true,
            length: 50
        });
        omara_func.is_validity({
            dom: '.entrance-guard-pwd',
            reg: false,
            reglength: false,
            length: 20
        });
        omara_func.is_validity({
            dom: '.entrance-guard-id',
            reg: false,
            reglength: false,
            length: 20
        });

        if ($('.entrance-guard-dialog .error').length) {
            $('.entrance-guard-dialog .error').eq(0).focus();
            omara_func.dialog_tips({
                show_text: '请填写此项',
                show_time: 2000
            });
            return false;
        } else {
            var data = omara_func.info_data({
                form: $('.entrance-guard-dialog .entrance-guard-set-form'),
                type: 'val+name'
            });
            omara_func.proccess({
                dom: that
            });
            var id = $('.entrance-guard-dialog .data-ID').val();
            omara_func.ajax_data({
                url: $('.entrance-guard-dialog .entrance-guard-set-form').attr('action'),
                data: {
                    a: 'save',
                    info: '{' + data + '}'
                },
                callback: function (d) {
                    $('.entrance-guard-dialog').hide();
                    $('.entrance-guard-dialog input').val('');
                    var data = d.data[0];

                    if (id == '') {
                        var html = '<tr id="tr-' + data.ID + '">' + '                        <td width="30%">' + data.name + '</td>\n' + '                        <td width="50%">' + data.login + '</td>\n' + '                        <td class="omara-textcenter" width="20%">\n' + '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 icon-modify entrance-guard-set"  data-id="' + data.ID + '"></a>\n' + '                            <a href="javascript:void (0);" class="iconfont omara-middle icon-toggle omara-fsize-28 omara-mleft-10 icon-delete delete-single" data-id="' + data.ID + '" data-pid="tr-' + data.ID + '"></a>' + '                        </td>\n' + '                    </tr>';
                        $('.omara-data-list tbody').append(html);
                    } else {
                        $('#tr-' + id + ' td').eq(0).html(data.name);
                        $('#tr-' + id + ' td').eq(1).html(data.login);
                    }
                },
                error: function () {
                }
            });
        }
    });
    $(document).on('click', '.entrance-guard-set', function () {
        var that = $(this);
        var data = omara_func.info_data({
            form: $('.entrance-guard-dialog .entrance-guard-set-form'),
            type: 'name'
        });
        omara_func.ajax_data({
            url: $('.entrance-guard-dialog .entrance-guard-set-form').attr('action'),
            data: {
                a: 'list',
                info: '{"limits":"' + data + '","id":"' + that.attr('data-id') + '"}'
            },
            callback: function (d) {
                var data = d.data;
                $('.entrance-guard-dialog').show();
                $('.entrance-guard-dialog .data-ID').val(that.attr('data-id'));
                $('.entrance-guard-dialog .entrance-guard-name').val(data.name);
                $('.entrance-guard-dialog .entrance-guard-addr').val(data.login);
                $('.entrance-guard-dialog .entrance-guard-user').val(data.username);
                $('.entrance-guard-dialog .entrance-guard-pwd').val(data.pwd);
                $('.entrance-guard-dialog .entrance-guard-id').val(data.logId);
            },
            error: function () {
            }
        });
    });
    $('.entrance-guard-iframe').css({
        height: $(window).height() - 160 + 'px'
    });

    $(".entrance-guard").on('change', function () {
        var that = $(this);
        $('.entrance-guard-form .username').val(that.find('option:selected').attr('data-user'));
        $('.entrance-guard-form .pwd').val(that.find('option:selected').attr('data-pwd'));
        $('.entrance-guard-form .logId').val(that.find('option:selected').attr('data-logid'));
        $(".entrance-guard-form").attr("action", that.find('option:selected').val());
        $(".entrance-guard-form").submit();
    });
    /*门禁 end*/
})(jQuery);